C     **********************************************

C     3D AIR FLOW MODEL  -  PREPROCESSOR FOR MODFLOW

C     == === ==== =====     ============ === =======

C

C     DEVELOPED BY       -  ARTHUR BAEHR

C                           810 BEAR TAVERN RD.

C                           WEST TRENTON, NJ 08628

C

C                        -  CRAIG JOSS

C                           P.O. BOX 943

C                           BALA CYNWYD, PA 19004

C

C     ***********************************************

C

C1----VERSION 1.1 06JUL1994

C

C     PROGRAM NAME ON PERSONAL COMPUTER :  PREAIR.FOR

C                  ON MAINFRAME         :  PREAIR.F77

C

C     DATE OF LAST REVISION             :  07/06/94

C

C2----NOTES  :

C

C     1. PREAIR TAKES DATA FROM THE INPUT FILE Dxxx.PRE AND

C        TRANSFORMS IT INTO FORMATTED INPUT FILES REQUIRED TO

C        RUN THE 3D MODULAR AIR FLOW MODEL MODFLOW.  NOTE :

C        - STEADY STATE AND TRANSIENT RUNS ARE AVAILABLE.

C        - BOUNDARY EFFECTS MAY BE STUDIED BY PERFORMING

C          SEPARATE MODEL RUNS.

C

C     2. FILES NEEDED TO RUN 3D PREPROCESSOR  :

C

C           -  INxx.PRE

C           -  Dxxx.PRE

C

C        WHERE,

C              INxx.PRE CONTAINS UNIT #s, FILE NAMES FOR

C                        INPUT AND OUTPUT FROM PREAIR.

C        AND   Dxxx.PRE CONTAINS DISCRETIZATION, PNEUMATIC,

C                        AND GEOLOGIC DATA USED IN SET UP

C                        MODFLOW INPUT FILE BY PREAIR.

C        NOTE,

C              Dxxx.PRE IS SPECIFIED IN INFILEx.PRE.

C              INxx.PRE MUST BE SPECIFIED INTERACTIVELY.

C

C3----SPECIFICATIONS:

C

      PARAMETER(LENX=500000,LENI=50000) 

      COMMON XX(LENX),IX(LENI)

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/IVALUE/IV(100)

      COMMON/XVALUE/XV(100)

      COMMON/AVALUE/FNAME(20)

      CHARACTER*12 FNAME,IU3*6

C-----INITIALIZE COMMON ARRAYS /IVALUE/, /XVALUE/, /AVALUE/

      DO 101 I = 1,100

       IV(I) = 0

 101  CONTINUE

      DO 102 I = 1,100

       XV(I)   = 0.0

 102  CONTINUE

      DO 103 I=1,20

       FNAME(I)  = ' '

 103  CONTINUE

C

C4----ASSIGN INPUT UNIT AND PRINTER UNIT

C

C     SET  :  IV(81) = INBAS = 5 WHEN USING IBM PC OR MAC

C     SET  :  IV(81) = INBAS = 1 WHEN USING MAINFRAME

C

C     SET  :  IV(82) = IOUT  = 6 WHEN USING IBM PC OR MAC

C     SET  :  IV(82) = IOUT  = 1 WHEN USING MAINFRAME

C

      INBAS = 5

      IOUT  = 6

C-----SAVE DATA

      IV(81) = INBAS

      IV(82) = IOUT

      IV(83) = LENX

      IV(84) = LENI

C

C5---DEFINE UNIT NUMBER FOR BASIC PACKAGE

C

C     SET  :  LOCAT = 1 WHEN USING PERSONAL COMPUTER

C     SET  :  LOCAT = 5 WHEN USING MAINFRAME OR MAC

C

      LOCAT = 1

C-----SAVE DATA

      IV(85) = LOCAT

C

C6----SETUP MODEL

C

      CALL SETUP

C

C7----DETERMINE MEMORY STORAGE REQUIREMENTS

C

      CALL STOR

C

C8----GENERATE MODFLOW BCF FILE

C

      CALL MODBAS(XX(IV(11)),XX(IV(12)),XX(IV(13)),IX(IV(41)),

     2 IX(IV(42)),IX(IV(43)),IX(IV(44)),IV(1),IV(2),IV(3),IV(4),

     3 IV(5),IV(6),IV(95),IV(96))

C

C9----GENERATE MODFLOW OUTPUT CONTROL FILE

C

      CALL MODOC

C

C10---GENERATE MODFLOW MATRIX SOLVE FILE

C

      CALL MODSIP

C

C11---GENERATE MODFLOW BCF FILE

C

      CALL MODBCF(XX(IV(11)),XX(IV(12)),XX(IV(13)),XX(IV(15)),

     2 XX(IV(16)),XX(IV(17)),XX(IV(18)),XX(IV(19)),XX(IV(20)),

     3 XX(IV(21)),XX(IV(22)),XX(IV(23)),XX(IV(24)),XX(IV(25)),

     4 XX(IV(26)),XX(IV(27)),IX(IV(41)),IX(IV(42)),IX(IV(43)),

     5 IX(IV(45)),IV(1),IV(2),IV(3),IV(4),IV(5),IV(91),IV(92),

     6 IV(95),IV(96))

C

C9----WRITE MESSAGE TO USER

C

      CALL AIREND

C

C10---END

C

      STOP

      END

C

C     ****************

      SUBROUTINE SETUP

C     ****************

C

C1----NOTES :

C

C     1. USE THIS ROUTINE TO SETUP MODEL AND ENTER FILE NAMES

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/AVALUE/FNAME(20)

      CHARACTER*12 FNAME,IU3*6

C-----INITIALIZE VARIABLES

      IV(86)  = 0

      INBAS  = IV(81)

      IOUT   = IV(82)

C

C3----SET UP UNIT ARRAYS

C

C     NOTES :

C     1. IU1() STORES UNIT SYSTEM SELECTED BY USER

C        IU1(1)  -  FOR LENGTH UNIT SYSTEM

C        IU1(2)  -  FOR VOLUME UNIT SYSTEM

C        IU1(3)  -  FOR TIME UNIT SYSTEM

C        IU1(4)  -  FOR PRESSURE UNIT SYSTEM

C        IU1(5)  -  FOR TEMPERATURE UNIT SYSTEM

C        IU1(6)  -  FOR MASS UNIT SYSTEM

C        IU1(7)  -  FOR PERMEABILITY UNIT SYSTEM

C

C     2. XU2() STORES UNIT CONVERTIONS

C        XU2(1,1) - XU2(1,10) :  FOR LENGTH UNITS

C        XU2(2,1) - XU2(2,10) :  FOR VOLUME UNITS

C        XU2(3,1) - XU2(3,10) :  FOR TIME UNITS 

C        XU2(4,1) - XU2(4,10) :  FOR PRESSURE UNITS

C        XU2(5,1) - XU2(5,10) :  FOR TEMPERATURE UNITS

C        XU2(6,1) - XU2(6,10) :  FOR MASS UNITS

C        XU2(7,1) - XU2(7,10) :  FOR PERMEABILITY UNITS

C

C     3. IU3() STORES UNIT DESCRIPTIONS

C        IU3(1,1) - IU3(1,10) :  FOR LENGTH UNITS

C        IU3(2,1) - IU3(2,10) :  FOR VOLUME UNITS

C        IU3(3,1) - IU3(3,10) :  FOR TIME UNITS 

C        IU3(4,1) - IU3(4,10) :  FOR PRESSURE UNITS

C        IU3(5,1) - IU3(5,10) :  FOR TEMPERATURE UNITS

C        IU3(6,1) - IU3(6,10) :  FOR MASS UNITS

C        IU3(7,1) - IU3(7,10) :  FOR PERMEABILITY UNITS

C

C3a---DEFAULT ARRAYS TO BLANK FIELDS

C

      DO 51 I=1,7

       IU1(I)=0

 51   CONTINUE

      DO 52 I=1,7

       DO 53 J =1,10

        XU2(I,J)=0.0

        IU3(I,J)='    '

 53    CONTINUE

 52   CONTINUE

C

C3b---SPECIFY CONVERTION FACTORS IN ARRAY XU2(I,J)

C

C-----SPECIFY LENGTH CONVERTION FACTORS IN ARRAY XU2(1,x)

C

C-----CM TO CM, DIVIDE INPUT BY XU2(1,1)

      XU2(1,1) = 1.0

C-----DM TO CM, DIVIDE INPUT BY XU2(1,2)

      XU2(1,2) = 1.0E-01

C-----M TO CM, DIVIDE INPUT BY XU2(1,3)

      XU2(1,3) = 1.0E-02

C-----IN TO CM, DIVIDE INPUT BY XU2(1,4)

      XU2(1,4) = 3.937E-01

C-----FT TO CM, DIVIDE INPUT BY XU2(1,5)

      XU2(1,5) = 3.281E-02

C-----YD TO CM, DIVIDE INPUT BY XU2(1,5)

      XU2(1,6) = 1.0936E-02

C

C-----SPECIFY VOLUME CONVERTION FACTORS IN ARRAY XU2(2,x)

C

C-----CM^3 TO CM^3, DIVIDE INPUT BY XU2(2,1)

      XU2(2,1) = 1.0

C-----LITERS TO CM^3, DIVIDE INPUT BY XU2(2,2)

      XU2(2,2) = 1.0E-03

C-----M^3 TO CM^3, DIVIDE INPUT BY XU2(2,3)

      XU2(2,3) = 1.0E-06

C-----IN^3 TO CM^3, DIVIDE INPUT BY XU2(2,4)

      XU2(2,4) = 6.1024E-02

C-----FT^3 TO CM^3, DIVIDE INPUT BY XU2(2,5)

      XU2(2,5) = 3.5315E-05

C-----YD^3 TO CM^3, DIVIDE INPUT BY XU2(2,6)

      XU2(2,6) = 1.3080E-06

C-----GAL TO CM^3, DIVIDE INPUT BY XU2(2,7)

      XU2(2,7) = 2.6417E-04

C

C-----SPECIFY TIME CONVERTION FACTORS IN ARRAY XU2(3,x)

C

C-----SECONDS TO SECONDS, DIVIDE INPUT BY XU2(3,1)

      XU2(3,1) = 1.0

C-----MINUTES TO SECONDS, DIVIDE INPUT BY XU2(3,2)

      XU2(3,2) = 1.6667E-02

C-----HOURS TO SECONDS, DIVIDE INPUT BY XU2(3,3)

      XU2(3,3) = 2.7778E-04

C-----DAYS TO SECONDS, DIVIDE INPUT BY XU2(3,4)

      XU2(3,4) = 1.1574E-05

C-----YEARS TO SECONDS, DIVIDE INPUT BY XU2(3,5)

      XU2(3,5) = 3.1688E-08

C

C-----SPECIFY PRESSURE CONVERTION FACTORS IN ARRAY XU2(4,x)

C

C-----ATMOSPHERES TO ATMOSPHERES, DIVIDE INPUT BY XU2(4,1)

      XU2(4,1) = 1.0

C-----MM MERCURY TO ATMOSPHERES, DIVIDE INPUT BY XU2(4,2)

      XU2(4,2) = 760.0

C-----INCHES OF WATER TO ATMOSPHERES, DIVIDE INPUT BY XU2(4,3)

      XU2(4,3) = 406.794

C-----KILOPASCALS TO ATMOSPHERES, DIVIDE INPUT BY XU2(4,4)

      XU2(4,4) = 101.325

C-----POUNDS PER SQ INCH TO ATMOSPHERES, DIVIDE INPUT BY XU2(4,5)

      XU2(4,5) = 14.696

C

C-----SPECIFY TEMPERTURE CONVERTION FACTORS IN ARRAY XU2(5,x)

C

C-----DEGREES CELSIUS TO DEGREES CELSIUS, SUBRACT XU2(5,1) FROM INPUT

      XU2(5,1) = 0.0

C       AND DIVIDE BY XU2(5,6)

      XU2(5,6) = 1.0

C-----KELVIN TO DEGREES CELSIUS, SUBTRACT XU2(5,2) FROM INPUT

      XU2(5,2) = 273.15

C       AND DIVIDE BY XU2(5,7)

      XU2(5,7) = 1.0

C-----DEGREES FAHRENHEIT TO DEGREES CELSIUS, SUBTRACT XU2(5,3)

      XU2(5,3) = 32.0

C       AND DIVIDE BY XU2(5,8)

      XU2(5,8) = 1.8

C

C-----SPECIFY MASS CONVERTION FACTORS IN ARRAY XU2(6,x)

C

C-----GRAMS TO GRAMS, DIVIDE INPUT BY XU2(6,1)

      XU2(6,1) = 1.0

C-----KILOGRAMS TO GRAMS, DIVIDE INPUT BY XU2(6,2)

      XU2(6,2) = 1.0E-03

C-----POUNDS TO GRAMS, DIVIDE INPUT BY XU2(6,3)

      XU2(6,3) = 2.2046E-03

C

C-----SPECIFY PERMEABILITY CONVERTION FACTORS IN ARRAY XU2(7,x)

C

C-----CM^2 TO CM^2, DIVIDE INPUT BY XU2(7,1)

      XU2(7,1) = 1.0

C-----DM^2 TO CM^3, DIVIDE INPUT BY XU2(7,2)

      XU2(7,2) = 1.0E-02

C-----M^2 TO CM^2, DIVIDE INPUT BY XU2(7,3)

      XU2(7,3) = 1.0E-04

C-----IN^2 TO CM^2, DIVIDE INPUT BY XU2(7,4)

      XU2(7,4) = 1.5500E-01

C-----FT^2 TO CM^2, DIVIDE INPUT BY XU2(7,5)

      XU2(7,5) = 1.0764E-03

C-----YD^2 TO CM^2, DIVIDE INPUT BY XU2(7,6)

      XU2(7,6) = 1.1960E-04

C-----DARCY TO CM^2, DIVIDE INPUT BY XU2(7,7)

      XU2(7,7) = 1.0E+08

C

C3c---SPECIFY UNIT DESCRIPTIONS IN ARRAY IU3(I,J)

C

C-----SPECIFY LENGTH DESCRIPTIONS IN ARRAY IU3(1,x)

C

      IU3(1,1) = 'cm'

      IU3(1,2) = 'dm'

      IU3(1,3) = 'm'

      IU3(1,4) = 'in'

      IU3(1,5) = 'ft'

      IU3(1,6) = 'yd'

C

C-----SPECIFY VOLUME DESCRIPTIONS IN ARRAY IU3(2,x)

C

      IU3(2,1) = 'cm^3'

      IU3(2,2) = 'lit'

      IU3(2,3) = 'm^3'

      IU3(2,4) = 'in^3'

      IU3(2,5) = 'ft^3'

      IU3(2,6) = 'yd^3'

      IU3(2,7) = 'gal'

C

C-----SPECIFY TIME DESCRIPTIONS IN ARRAY IU3(3,x)

C

      IU3(3,1) = 'sec'

      IU3(3,2) = 'min'

      IU3(3,3) = 'hr'

      IU3(3,4) = 'day'

      IU3(3,5) = 'yr'

C

C-----SPECIFY PRESSURE DESCRIPTIONS IN ARRAY IU3(4,x)

C

      IU3(4,1) = 'atm'

      IU3(4,2) = 'mmHg'

      IU3(4,3) = '"H2O'

      IU3(4,4) = 'kPa'

      IU3(4,5) = 'psi'

C

C-----SPECIFY TEMPERTURE DESCRIPTIONS IN ARRAY IU3(5,x)

C

      IU3(5,1) = 'degC'

      IU3(5,2) = 'K'

      IU3(5,3) = 'degF'

C

C-----SPECIFY MASS DESCRIPTIONS IN ARRAY IU3(6,x)

C

      IU3(6,1) = ' g'

      IU3(6,2) = 'kg'

      IU3(6,3) = 'lb'

C

C-----SPECIFY PERMEABILITY DESCRIPTIONS IN ARRAY IU3(7,x)

C

      IU3(7,1) = 'cm^2'

      IU3(7,2) = 'dm^2'

      IU3(7,3) = 'm^2'

      IU3(7,4) = 'in^2'

      IU3(7,5) = 'ft^2'

      IU3(7,6) = 'yd^2'

      IU3(7,7) = 'drcy'

C

C4----DISPLAY HEADING

C

 800  CONTINUE

      WRITE(IOUT,201)

      WRITE(IOUT,202)

      WRITE(IOUT,203)

      WRITE(IOUT,204)

      WRITE(IOUT,205)

      WRITE(IOUT,206)

      WRITE(IOUT,207)

      WRITE(IOUT,208)

      WRITE(IOUT,209)

      WRITE(IOUT,210)

      READ(INBAS,211,ERR=800)IV(86)

C-----END PROGRAM

      IF (IV(86).EQ.4) THEN

       STOP

      END IF

C-----TEST USER INPUT

 801  CONTINUE

      IF ((IV(86).NE.1).AND.(IV(86).NE.2).AND.(IV(86).NE.3)) THEN

       IV(86) = 0

       GO TO 800

      END IF

 201  FORMAT(////////////////////////,T20,'PREAIR - AN AIRFLOW',

     1   ' PREPROCESSOR (Ver 1.1)')

 202  FORMAT(T20,'======   == ======= ============')

 203  FORMAT(/,T10,'DEVELOPED BY :  ARTHUR L. BAEHR')

 204  FORMAT(/,T26,'CRAIG J. JOSS')

 205  FORMAT(//,T10,'SELECT  :')

 206  FORMAT(/,T10,'1.  TO RUN PREAIR WITH AN EXISTING INPUT FILE')

 207  FORMAT(/,T10,'2.  TO MODIFY AN EXISTING INPUT FILE')

 208  FORMAT(/,T10,'3.  TO CREATE A NEW DATA-INPUT FILE')

 209  FORMAT(//,T10,'4.  TO EXIT PREAIR')

 210  FORMAT(//,T10,'PLEASE SELECT NUMBER  1, 2, 3,  OR  4  :  ')

 211  FORMAT(I3)

C

C5----ENTER NAME OF INPUT FILE (EG INFILEx.PRE)

C

C-----DIRECT ENTRY

      IF (IV(86).EQ.1) THEN

       WRITE(IOUT,201)

       WRITE(IOUT,202)

       IF(FNAME(1).EQ.' ') FNAME(18)='INFILE.PRE'

       IF(FNAME(1).NE.' ') FNAME(18)=FNAME(1)

       WRITE(IOUT,221)FNAME(18)

       READ(INBAS,225)FNAME(18)

       IF(FNAME(18).NE.' ') FNAME(1)=FNAME(18)

       OPEN(UNIT=11,FILE=FNAME(1),STATUS='OLD')

       REWIND 11

      END IF

C-----MODIFY FILE

      IF (IV(86).EQ.2) THEN

       WRITE(IOUT,201)

       WRITE(IOUT,202)

       IF(FNAME(1).EQ.' ') FNAME(18)='INFILE.PRE'

       IF(FNAME(1).NE.' ') FNAME(18)=FNAME(1)

       WRITE(IOUT,222)FNAME(18)

       READ(INBAS,225)FNAME(18)

       IF(FNAME(18).NE.' ') FNAME(1)=FNAME(18)

       OPEN(UNIT=11,FILE=FNAME(1),STATUS='UNKNOWN')

       REWIND 11

      END IF

C-----SET UP FILE

      IF (IV(86).EQ.3) THEN

       WRITE(IOUT,201)

       WRITE(IOUT,202)

       WRITE(IOUT,223)

       READ(INBAS,225)FNAME(1)

       OPEN(UNIT=11,FILE=FNAME(1),STATUS='UNKNOWN')

       REWIND 11

      END IF

 221  FORMAT(//////,T10,'PLEASE ENTER NAME OF INPUT FILE',

     1      '  EG ',A12,' :  ')

 222  FORMAT(//////,T10,'PLEASE ENTER NAME OF FILE TO MODIFY',

     1      ' EG ',A12,' :  ')

 223  FORMAT(//////,T10,'PLEASE ENTER NAME OF FILE TO SET UP',

     1      ' EG INFILE.PRE  :  ')

 225  FORMAT(A12)

C

C6----ENTER FILE NAMES DIRECTLY

C

      IF((IV(86).EQ.1).OR.(IV(86).EQ.2)) THEN

C------DATAIRx.PRE

       READ(11,225)FNAME(2)

C------BASAIRx.PRN

       READ(11,225)FNAME(3)

       IF(FNAME(3).EQ.' ') FNAME(3) = 'BASAIR.PRN'

C------OCAIRx.PRN

       READ(11,225)FNAME(4)

       IF(FNAME(4).EQ.' ') FNAME(4) = 'OCAIR.PRN'

C------BCFAIRx.PRN

       READ(11,225)FNAME(5)

       IF(FNAME(5).EQ.' ') FNAME(5) = 'BCFAIR.PRN'

C------SPAIRx.PRN

       READ(11,225)FNAME(6)

       IF(FNAME(6).EQ.' ') FNAME(6) = 'SPAIR.PRN'

C------HEADx.BIN

       READ(11,225)FNAME(7)

       IF(FNAME(7).EQ.' ') FNAME(7) = 'HEAD.BIN'

C------FLUXx.BIN

       READ(11,225)FNAME(8)

       IF(FNAME(8).EQ.' ') FNAME(8) = 'FLOW.BIN'

C------MODEL.DAT

       READ(11,225)FNAME(9)

       IF(FNAME(9).EQ.' ') FNAME(9) ='MODEL.DAT'

C------INFILE.MOD

       FNAME(10)='INFILE.MOD'

C------INFILE.POS

       READ(11,225)FNAME(11)

       IF(FNAME(11).EQ.' ') FNAME(11) = 'INFILE.POS'

C------MODAIR.PRN

       FNAME(12)='MODAIR.PRN'

      END IF

C

C7----ENTER FILE NAMES INTERACTIVEY

C

      IF((IV(86).EQ.2).OR.(IV(86).EQ.3)) THEN

C------SPECIFY NAME OF PREAIR INPUT FILE (EG DATAIR.PRE)

 830   CONTINUE

       FNAME(18) = 'DATAIR.PRE'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(2)

       WRITE(IOUT,230)FNAME(18)

 230   FORMAT(//,T10,'ENTER NAME OF PREAIR INPUT FILE ',

     1       ' EG ',A12,' :  ')

       READ(INBAS,225,ERR=830)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(2) = FNAME(18)

       END IF

C------SPECIFY NAME OF MODFLOW BASIC FILE (EG BASAIR.PRN)

 840   CONTINUE

       FNAME(18) = 'BASAIR.PRN'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(3)

       WRITE(IOUT,240)FNAME(18)

 240   FORMAT(//,T10,'ENTER NAME OF MODFLOW BASIC FILE ',

     1       ' EG ',A12,' :  ')

       READ(INBAS,225,ERR=840)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(3) = FNAME(18)

       END IF

C------SPECIFY NAME OF MODFLOW OC FILE (EG OCAIR.PRN)

 850   CONTINUE

       FNAME(18) = 'OCAIR.PRN'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(4)

       WRITE(IOUT,250)FNAME(18)

 250   FORMAT(//,T10,'ENTER NAME OF MODFLOW OC FILE ',

     1       ' EG ',A12,' :  ')

       READ(INBAS,225,ERR=850)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(4) = FNAME(18)

       END IF

C------SPECIFY NAME OF MODFLOW BCF FILE (EG BCFAIR.PRN)

 860   CONTINUE

       FNAME(18) = 'BCFAIR.PRN'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(5)

       WRITE(IOUT,260)FNAME(18)

 260   FORMAT(//,T10,'ENTER NAME OF MODFLOW BCF FILE ',

     1       ' EG ',A12,' :  ')

       READ(INBAS,225,ERR=860)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(5) = FNAME(18)

       END IF

C------SPECIFY NAME OF MODFLOW SIP FILE (EG SIPAIR.PRN)

 870   CONTINUE

       FNAME(18) = 'SIPAIR.PRN'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(6)

       WRITE(IOUT,270)FNAME(18)

 270   FORMAT(//,T10,'ENTER NAME OF MODFLOW SIP FILE ',

     1       ' EG ',A12,' :  ')

       READ(INBAS,225,ERR=870)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(6) = FNAME(18)

       END IF

C------SPECIFY NAME OF MODFLOW BINARY HEAD FILE (EG HEAD.BIN)

 880   CONTINUE

       FNAME(18) = 'HEAD.BIN'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(7)

       WRITE(IOUT,280)FNAME(18)

 280   FORMAT(//,T10,'ENTER NAME OF MODFLOW BINARY HEAD FILE ',

     1       ' EG ',A12,' :  ')

       READ(INBAS,225,ERR=880)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(7) = FNAME(18)

       END IF

C------SPECIFY NAME OF MODFLOW BINARY FLOW FILE (EG FLOW.BIN)

 890   CONTINUE

       FNAME(18) = 'FLOW.BIN'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(8)

       WRITE(IOUT,290)FNAME(18)

 290   FORMAT(//,T10,'ENTER NAME OF MODFLOW BINARY FLOW FILE',

     1       ' EG ',A12,' :  ')

       READ(INBAS,225,ERR=890)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(8) = FNAME(18)

       END IF

C------SPECIFY NAME OF MODEL TRANSFER FILE (EG MODEL.DAT)

 895   CONTINUE

       FNAME(18) = 'MODEL.DAT'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(9)

       WRITE(IOUT,295)FNAME(18)

 295   FORMAT(//,T10,'ENTER NAME OF FILE TO TRANSFER MODEL DATA ',

     1       ' EG ',A12,' :  ')

       READ(INBAS,225,ERR=895)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(9) = FNAME(18)

       END IF

C------SPECIFY NAME OF POSTMOD INPUT FILE (EG INFILE.POS)

 900   CONTINUE

       FNAME(18) = 'INFILE.POS'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(11)

       WRITE(IOUT,300)FNAME(18)

 300   FORMAT(//,T10,'ENTER NAME OF POSTMOD INPUT FILE',

     1       ' EG ',A12,' :  ')

       READ(INBAS,225,ERR=900)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(11) = FNAME(18)

       END IF

C------SET UP INFILE.PRE FILE

       REWIND 11

       WRITE(11,225) FNAME(2)

       WRITE(11,225) FNAME(3)

       WRITE(11,225) FNAME(4)

       WRITE(11,225) FNAME(5)

       WRITE(11,225) FNAME(6)

       WRITE(11,225) FNAME(7)

       WRITE(11,225) FNAME(8)

       WRITE(11,225) FNAME(9)

       WRITE(11,225) FNAME(11)

C------MESSAGE TO USER

       WRITE(IOUT,201)

       WRITE(IOUT,202)

       IF(IV(86).EQ.2) WRITE(IOUT,310)FNAME(1)

       IF(IV(86).EQ.3) WRITE(IOUT,311)FNAME(1)

       WRITE(IOUT,205)

       WRITE(IOUT,206)

       WRITE(IOUT,207)

       WRITE(IOUT,208)

       WRITE(IOUT,209)

       WRITE(IOUT,210)

       READ(INBAS,211,ERR=800)IV(86)

       IF (IV(86).EQ.4) THEN

        STOP

       END IF

C------RETURN TO MENU

       GO TO 801

 310   FORMAT(///,T10,A12,' HAS BEEN MODIFIED')

 311   FORMAT(///,T10,A12,' HAS BEEN CREATED')

      END IF

C

C8----OPEN DATA FILES USED IN PREAIR

C

C-----DATAIR.PRE

      OPEN(UNIT=12,FILE=FNAME(2),STATUS='OLD')

C-----BASAIR.PRN

      OPEN(UNIT=13,FILE=FNAME(3),STATUS='UNKNOWN')

C-----OCAIR.PRN

      OPEN(UNIT=14,FILE=FNAME(4),STATUS='UNKNOWN')

C-----BCFAIR.PRN

      OPEN(UNIT=15,FILE=FNAME(5),STATUS='UNKNOWN')

C-----SPAIR.PRN

      OPEN(UNIT=16,FILE=FNAME(6),STATUS='UNKNOWN')

C-----MODEL.DAT

      OPEN(UNIT=19,FILE=FNAME(9),STATUS='UNKNOWN')

C-----INFILE.MOD

      OPEN(UNIT=20,FILE=FNAME(10),STATUS='UNKNOWN')

C-----INFILE.POS

      OPEN(UNIT=21,FILE=FNAME(11),STATUS='UNKNOWN')

C-----SCRATCH FILE

      OPEN(UNIT=23,STATUS='SCRATCH')

C

C9----REWIND FILES

C

      REWIND 12

      REWIND 13

      REWIND 14

      REWIND 15

      REWIND 16

      REWIND 19

      REWIND 20

      REWIND 21

      REWIND 23

C

C10---SET UP INFILE.MOD

C

      WRITE(20,225) FNAME(12)

      WRITE(20,225) FNAME(3)

      WRITE(20,225) FNAME(5)

      WRITE(20,225) FNAME(6)

      WRITE(20,225) FNAME(4)

      WRITE(20,225) FNAME(7)

      WRITE(20,225) FNAME(8)

C

C11---SET UP INFILE.POS

C

      WRITE(21,350) 2,1,1,2,1,1,1,1,0

      WRITE(21,225) FNAME(3)

      WRITE(21,225) FNAME(4)

      WRITE(21,225) FNAME(5)

      WRITE(21,225) FNAME(7)

      WRITE(21,225) FNAME(8)

      WRITE(21,225) FNAME(9)

 350  FORMAT(8I2,I4)

C

C12---END

C

      RETURN

      END

C

C     ***************

      SUBROUTINE STOR

C     ***************

C

C1----NOTES :

C

C     1. PRELIMINARY MODEL DATA IS INPUT SO THAT ARRAY

C        STORAGE REQUIREMENTS MAY BE DETERMINED.

C

C     2. VARIABLES :

C         IV(1) = NROW  = NUMBER OF ROWS

C         IV(2) = NCOL  = NUMBER OF COLUMNS

C         IV(3) = NLAY  = NUMBER OF LAYERS

C         IV(4) = NWELL = NUMBER OF WELLS

C         IV(5) = NTRCH = NUMBER OF TRENCHES

C         IV(6) = NPER  = NUMBER OF STRESS PERIODS

C         IV(11) THRU IV(28) = STORAGE MARKER FOR XX ARRAY

C         IV(41) THRU IV(60) = STORAGE MARKER FOR IX ARRAY

C

C     3. THE MODEL SUPERIMPOSES AN ADDITIONAL LAYER ON

C        THE USER DEFINED DOMAIN TO REPRESENT AIR

C        RECHARGE FROM THE ATMOSPHERE. HENCE,

C        NLAY  = NUMBER OF LAYERS DEFINED BY THE USER + 1

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/AVALUE/FNAME(20)

      CHARACTER*12 FNAME,IU3*6

      CHARACTER*4 HEAD1(20),HEAD2(12)

C-----INITIALIZE VARIABLES

      IOUT = IV(82)

      LENX = IV(83)

      LENI = IV(84)

C

C3----START WITH SET UP OF BASIC PACKAGE FOR 3D-AIR FLOW MODEL

C     ===== ==== === == == ===== ======= === == === ==== =====

C

C3a---SIMULATION HEADING

C

      READ(12,201)HEAD1

      READ(12,202)HEAD2

      WRITE(13,201)HEAD1

      WRITE(13,202)HEAD2

 201  FORMAT(20A4)

 202  FORMAT(12A4)

C

C3b---UNIT SYSTEM

C

      READ(12,211)IU1(1),IU1(2),IU1(3),IU1(4),IU1(5),IU1(6),IU1(7)

 211  FORMAT(7I5)

C-----SET UNITS TO DEFAULT SYSTEM IF NO ENTRY MADE

      IF((IU1(1).LT.2).OR.(IU1(1).GT.6)) IU1(1)=1

      IF((IU1(2).LT.2).OR.(IU1(2).GT.7)) IU1(2)=1

      IF((IU1(3).LT.2).OR.(IU1(3).GT.5)) IU1(3)=1

      IF((IU1(4).LT.2).OR.(IU1(4).GT.5)) IU1(4)=1

      IF((IU1(5).LT.2).OR.(IU1(5).GT.3)) IU1(5)=1

      IF((IU1(6).LT.2).OR.(IU1(6).GT.3)) IU1(6)=1

      IF((IU1(7).LT.2).OR.(IU1(7).GT.7)) IU1(7)=1

C

C3c---INPUT # OF ROWS,COLUMNS,LAYERS,WELLS,TRENCHES FROM DATAIR.PRE

C

      READ(12,221)NLAY,NROW,NCOL,NPER

      READ(12,222)LTYPE,NWELL,NTRCH

 221  FORMAT(4I10)

 222  FORMAT(3I10)

C-----REDEFINE NUMBER OF LAYERS TO INCLUDE SUPERIMPOSED ATMOS LAYER

      NLAY=NLAY+1

C-----DEFINE TIME UNITS (ITMUNI=1 FOR SECONDS)

      ITMUNI=1

C

C-----ASSIGN DIMENSION VARIABLES TO ARRAYS

C

      IV(1)=NROW

      IV(2)=NCOL

      IV(3)=NLAY

      IV(4)=NWELL

      IV(5)=NTRCH

      IV(6)=NPER

      IF(LTYPE.NE.2) LTYPE=1

      IV(7)=LTYPE

C

C-----OUTPUT LAYER, ROW, COLUMN, PERIOD, TIME UNITS

C

      WRITE(13,225) NLAY,NROW,NCOL,NPER,ITMUNI

 225  FORMAT(5I10)

C

C-----OUTPUT UNITS AND WELL/TRENCH INFO TO MODEL.DAT FILE

C

      WRITE(19,226)IU1(1),IU1(2),IU1(3),IU1(4),IU1(5),IU1(6),

     1             IU1(7),NWELL,NTRCH

 226  FORMAT(10I5)

C

C4----SET UP ARRAY STORAGE AREAS FOR XX ARRAY

C

C-----STORAGE REQUIREMENTS FOR BASIC INPUT

C

C-----START OF PRESSURE IN WELLS (SHW)

      IV(11)=1

C-----MINIMUM STORAGE FOR NUMBER OF WELLS MUST BE > 0

      NWC=IV(4)

      IF(NWC.LT.1) NWC = 1

      IV(95)=NWC

C-----START OF PRESSURE IN TRENCHES (TSHD)

      IV(12)=IV(11)+NWC

C-----MINIMUM STORAGE FOR NUMBER OF TRENCHES MUST BE > 0

      NTC=IV(5)

      IF(NTC.LT.1) NTC = 1

C-----START OF START PRESSURE IN EACH CELL LAYER (SHEAD)

      IV(13)=IV(12)+NTC

      IV(96)=NTC

C

C-----STORAGE REQUIREMENTS FOR BCF INPUT (REUSE BASIC ARRAY SPACE)

C

C-----START OF TRANSMISSIVITY IN EACH LAYER (XTRAN)

C     IV(13)

C-----START OF X-Y ANISOTROPY RATIOS IN EACH LAYER (TRPY)

      IV(15)=IV(13)+NLAY

C-----START OF PNEUMATIC STORAGE COEFFICIENT IN EACH LAY (THAP)

      IV(16)=IV(15)+NLAY

C-----START OF VERTICAL PERMEABILITY IN EACH LAYER (XXKZ)

      IV(17)=IV(16)+NLAY

C-----START OF VERTICAL NODAL SPACING IN EACH LAYER (BBB)

      IV(18)=IV(17)+NLAY

C-----START OF VERTICAL CONDUCTANCE IN EACH LAYER (VCT)

      IV(19)=IV(18)+NLAY

C-----START OF VERTICAL CONDUCTANCE IN CELL (X-Y) (VCONT)

      IV(20)=IV(19)+NLAY

C-----START OF NODAL SPACING ALONG COLUMNS (DELC)

      IV(21)=IV(20)+(NCOL*NROW)

C-----START OF NODAL SPACING ALONG ROWS (DELR)

      IV(22)=IV(21)+NROW

C-----START OF TRANSMISSIVITY IN CELLS (X-Y) (TRAN)

      IV(23)=IV(22)+NCOL

C-----START OF PNEUMATIC STORAGE COEFFICIENT IN CELLS (X-Y) (SF1)

      IV(24)=IV(23)+(NCOL*NROW)

C-----ALLOCATE MEMORY DEPENDING ON LTYPE

      IF(IV(7).EQ.1) THEN

       NRC=1

       NCC=1

      END IF

      IF(IV(7).EQ.2) THEN

       NRC=NROW

       NCC=NCOL

      END IF

C-----START OF HORIZ PERM OF CELLS (X-Y) (XPERM)

      IV(25)=IV(24)+(NCC*NRC)

C-----START OF VERT PERM OF CELLS IN I (VPERM1)

      IV(26)=IV(25)+(NCC*NRC)

C-----START OF VERT PERM OF CELLS IN I+1 (VPERM2)

      IV(27)=IV(26)+(NCC*NRC)

C-----END OF VERT PERM OF CELLS IN I+1 (VPERM2)

      IV(28)=IV(27)+(NCC*NRC)

C-----STORE VARIABLE

      IV(91)=NRC

      IV(92)=NCC

C

C5----TEST MEMORY ALLOCATION AREA FOR XX ARRAY

C

      IF (IV(28).GT.LENX) THEN

        WRITE(IOUT,250)

        WRITE(IOUT,251)IV(28)+1

        WRITE(IOUT,252)

        STOP

      END IF

 250  FORMAT(///////////////////////////////)

 251  FORMAT(T10,'REDIMENSION XX ARRAY TO LENX = ',I10)

 252  FORMAT(//,T10,'AND RECOMPILE PROGRAM')

C

C6----SET UP ARRAY STORAGE AREAS FOR IX ARRAY

C

C-----START OF WELL NUMBERS (IWELL)

      IV(41)=1

      IV(42)=IV(41)+(7*NWC)

C-----START OF CELL TYPE DESIGNATION (IE ACTIVE) (IBOUND)

      IV(43)=IV(42)+(7*NTC)

C-----ARRAY FOR MODBAS ROUTINE

C-----START OF UNIT NUMBERS (IUNIT)

      IV(44)=IV(43)+(NCOL*NROW)

C-----ARRAY FOR MODBCF ROUTINE

C-----START OF LAYER TYPE DESIGNATION (IE CONFINED) (ILAYCO)

C     USE IV(43)

C-----START OF LAYER NUMBER AT BOTTOM OF GEOLOGICAL UNIT (NMLB)

      IV(45)=IV(43)+(NLAY)

C-----END OF LAYER NUMBER AT BOTTOM OF GEOLOGICAL UNIT (NMLB)

      IV(46)=IV(45)+(NLAY)

C

C7----TEST MEMORY ALLOCATION AREA FOR IX ARRAY

C

      IMMX = IV(44)

      IF (IMMX.LT.IV(46)) IMMX = IV(46)

      IF (IMMX.GT.LENI) THEN

        WRITE(IOUT,261)

        WRITE(IOUT,262)IMMX+1

        WRITE(IOUT,263)

        STOP

      END IF

 261  FORMAT(///////////////////////////////)

 262  FORMAT(T10,'REDIMENSION IX ARRAY TO LENI = ',I10)

 263  FORMAT(//,T10,'AND RECOMPILE PROGRAM')

      RETURN

      END

C

C     *****************

      SUBROUTINE MODBAS(SHW,TSHD,SHEAD,IWELL,ITRCH,IBOUND,IUNIT,

C     *****************

     2 NROW,NCOL,NLAY,NWELL,NTRCH,NPER,NWC,NTC)

C

C1----NOTES :

C

C     1. USE THIS ROTUINE TO SET UP MODFLOW BASIC FILE

C

C     2. ARRAYS STORING REAL VARIABLES  :

C

C        SHW     =  PRESSURE IN WELLS SQUARED (g/cm-sec**2)**2

C        TSHD    =  PRESSURE IN TRENCHES SQUARED (g/cm-sec**2)**2

C        SHEAD   =  STARTING HEAD (PRESSURE SQUARED) IN EACH CELL

C

C     3. ARRAYS STORING INTEGER VARIABLES  :

C

C        IUNIT   =  UNIT NUMBER FOR OPTION PACKAGES

C        IWELL   =  WELL INFORMATION

C        ITRCH   =  TRENCH INFORMATION

C        IBOUND  =  CELL TYPE (CONSTANT HEAD, ACTIVE, INACTIVE)

C

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/AVALUE/FNAME(20)

      CHARACTER*12 FNAME,IU3*6

      CHARACTER*4 FMTIN(5)

      DIMENSION SHW(NWC),TSHD(NTC),SHEAD(NCOL,NROW)

      DIMENSION IWELL(NWC,7),ITRCH(NTC,7),IBOUND(NCOL,NROW),

     1          IUNIT(12)

C-----ASSIGN VARIABLES

      LOCAT = IV(85)  

C 

C3----INPUT SOLVER TYPE SIP (NSOLV=1) OR SOR (NSOLV=2)

C

      READ(12,215)NSOLV

 215  FORMAT(I10)

C-----CHECK USER INPUT AND DEFAULT TO SIP IF ERROR PRESENT

      IF ((NSOLV.NE.1).AND.(NSOLV.NE.2)) THEN

       NSOLV = 1

      END IF

      NSOLV1=0

      NSOLV2=0

      IF (NSOLV.EQ.1)NSOLV1=1

      IF (NSOLV.EQ.2)NSOLV2=1

      IV(89)=NSOLV2

C

C4----INPUT MODULAR PROGRAM INPUT FILE #S

C

      IUNIT(1)=7

      IUNIT(2)=0

      IUNIT(3)=0

      IUNIT(4)=0

      IUNIT(5)=0

      IUNIT(6)=0

      IUNIT(7)=0

      IUNIT(8)=0

      IF (NSOLV1.NE.0)IUNIT(9)=8

      IF (NSOLV1.EQ.0)IUNIT(9)=0

      IUNIT(10)=0

      IF (NSOLV2.NE.0)IUNIT(11)=9

      IF (NSOLV2.EQ.0)IUNIT(11)=0

      IUNIT(12)=11

      WRITE(13,218)(IUNIT(JJ),JJ=1,12)

 218  FORMAT(24I3)

C

C5----PREVAILING ATMOSPHERIC PRESSURE (g/cm-sec**2)

C

      READ(12,220)ATM

 220  FORMAT(F10.0)

C-----UNIT CORRECTION

      ATM=ATM/XU2(4,IU1(4))

      STDATM = 1013250.0

      PATM   = ATM*STDATM

C

C6----ARRAY SPECIFICATION

C

      IAPART=0

C

C-----STARTING HEADS (ISTRT = 0 -> NOT SAVED, ISTRT > 0 -> SAVED)

C

      ISTRT=0

      WRITE(13,225)IAPART,ISTRT

 225  FORMAT(2I10)

C

C7----SET WELL PARAMETERS

C

      IF (NWELL.NE.0) THEN

       DO 100 IW=1,NWELL

        READ(12,230)IWELL(IW,1),IWELL(IW,2),IWELL(IW,3),IWELL(IW,4),

     1  IWELL(IW,5),IWELL(IW,6),IWELL(IW,7),SHW(IW)

        IF(IWELL(IW,1).EQ.0) IWELL(IW,1)=IW

C-------CONVERT STARTING HEAD TO (atm) UNITS

        SHW(IW)=SHW(IW)/XU2(4,IU1(4))

C-------CONVERT STARTING HEAD TO (g/cm-sec**2)**2 UNITS

        SHW(IW)=(SHW(IW)*STDATM)*(SHW(IW)*STDATM)

C-------CORRECT USER SPECIFIED LAYER FOR MODEL LAYER #1 (BC)

        IWELL(IW,6)=IWELL(IW,6)+1

        IWELL(IW,7)=IWELL(IW,7)+1

 100   CONTINUE

      END IF

 230  FORMAT(7I5,F10.0)

C

C8----SET TRENCH PARAMETERS

C

      IF (NTRCH.NE.0)THEN

       DO 101 IT=1,NTRCH

        READ(12,230)ITRCH(IT,1),ITRCH(IT,2),ITRCH(IT,3),ITRCH(IT,4),

     1  ITRCH(IT,5),ITRCH(IT,6),ITRCH(IT,7),TSHD(IT)

        IF(ITRCH(IT,1).EQ.0) ITRCH(IT,1)=IT

C-------CONVERT STARTING HEAD TO (atm) UNITS

        TSHD(IT)=TSHD(IT)/XU2(4,IU1(4))

C-------CONVERT STARTING HEAD TO (g/cm-sec**2)**2 UNITS

        TSHD(IT)=(TSHD(IT)*STDATM)*(TSHD(IT)*STDATM)

C-------CORRECT USER SPECIFIED LAYER FOR MODEL LAYER #1 (BC)

        ITRCH(IT,6)=ITRCH(IT,6)+1

        ITRCH(IT,7)=ITRCH(IT,7)+1

 101   CONTINUE

      END IF

C

C9----SET HEAD TYPE AND STARTING HEAD FOR SIMULATION

C

C      - IBOUND(CELL TYPE)

C      - SHEAD(STARTING HEAD VALUE)

C

      ICONST=1

      FMTIN(1)='(20I'

      FMTIN(2)='3)  '

      FMTIN(3)='    '

      FMTIN(4)='    '

      FMTIN(5)='    '

C

C-----SPECIFY OUTPUT OPTION FOR HEAD TYPE (IPRN = 0 -> 10I11)

C

      IPRN=0

      IK=0

C-----REINITIALIZE ARRAY SHEAD TO PATM*PATM FOR EACH LAYER

      DO 105 IBL=1,NLAY

       IK=IK+1

       DO 106 IH=1,NCOL

        DO 107 IAH=1,NROW

         SHEAD(IH,IAH)=PATM*PATM

 107    CONTINUE

 106   CONTINUE

C

C------SET UP HEAD TYPE AND STARTING HEAD VALUE IN 

C      SUPERIMPOSED ATMOSPHERIC LAYER

C

C------HEADTYPE OPTIONS

C

C------FOR IBOUND < 0  CELL HAS A CONSTANT HEAD

C------FOR IBOUND = 0  CELL IS INACTIVE

C------FOR IBOUND > 0  CELL IS ACTIVE

C

       IF (IBL.EQ.1)THEN

        WRITE(13,240)LOCAT,ICONST,FMTIN,IPRN

 240    FORMAT(2I10,5A4,I10)

        DO 110 JL=1,NROW

         DO 111 JK=1,NCOL

C--------SPECIFY CELLS IN SUPERIMPOSED LAYER AS CONSTANT HEAD

          IBOUND(JK,JL)=-IK

 111     CONTINUE

C--------RECORD CELL TYPES OF SUPERIMPOSED LAYER

         WRITE(13,250)(IBOUND(JK1,JL),JK1=1,NCOL)

C--------TEMPORARILY STORE STARTING HEADS ON UNIT #23 FOR EXTRA LAYER

         WRITE(23,251)(SHEAD(JK1,JL),JK1=1,NCOL)

 110    CONTINUE

       END IF

       IF (IBL.NE.1)THEN

C

C-------SET UP HEAD TYPE IN USER DEFINED LAYERS

C

        DO 112 JKB=1,NCOL

         DO 112 JLB=1,NROW

C---------SPECIFY INTERIOR, USER DEFINED LAYERS AS ACTIVE

          IBOUND(JKB,JLB)=IK

          IF (JKB.EQ.1.OR.JKB.EQ.NCOL)IBOUND(JKB,JLB)= -IK

          IF (JLB.EQ.1.OR.JLB.EQ.NROW)IBOUND(JKB,JLB)= -IK

 112    CONTINUE

C

C-------SET CELL ABOVE WELLS TO INACTIVE CELLS

C

        IF (NWELL.GT.0) THEN

         DO 117 IW=1,NWELL

          DO 118 ICL=1,NCOL

           DO 119 IRW=1,NROW

            IF (IBL.GE.IWELL(IW,6))GO TO 524

            IF (ICL.LT.IWELL(IW,4))GO TO 525

            IF (ICL.GT.IWELL(IW,5))GO TO 525

            IF (IRW.LT.IWELL(IW,2))GO TO 526

            IF (IRW.GT.IWELL(IW,3))GO TO 526

C-----------SPECIFY CELLS ABOVE WELLS AS INACTIVE CELLS

            IBOUND(ICL,IRW)=0

 526        CONTINUE

 119       CONTINUE

 525       CONTINUE

 118      CONTINUE

 524      CONTINUE

 117     CONTINUE

        END IF

C

C-------SET HEAD TYPE AND STARTING HEAD IN WELL CELLS

C

        IF (NWELL.GT.0) THEN

         DO 114 IW=1,NWELL

          DO 115 ICL=1,NCOL

           DO 116 IRW=1,NROW

            IF (IBL.LT.IWELL(IW,6))GO TO 521

            IF (IBL.GT.IWELL(IW,7))GO TO 521

            IF (ICL.LT.IWELL(IW,4))GO TO 522

            IF (ICL.GT.IWELL(IW,5))GO TO 522

            IF (IRW.LT.IWELL(IW,2))GO TO 523

            IF (IRW.GT.IWELL(IW,3))GO TO 523

C-----------SPECIFY WELL CELLS AS CONSTANT HEAD

            IBOUND(ICL,IRW)=-IK

C-----------ASSIGN USER SPECIFIED WELL PRESSURE TO WELL CELLS

            SHEAD(ICL,IRW)=SHW(IW)

 523        CONTINUE

 116       CONTINUE

 522       CONTINUE

 115      CONTINUE

 521      CONTINUE

 114     CONTINUE

        END IF

C

C-------SET HEAD TYPE AND STARTING HEAD IN TRENCH CELLS

C

        IF (NTRCH.GT.0) THEN

         DO 120 IT=1,NTRCH

          DO 121 ITC=1,NCOL

           DO 122 ITO=1,NROW

            IF (IBL.LT.ITRCH(IT,6)) GO TO 531

            IF (IBL.GT.ITRCH(IT,7)) GO TO 531

            IF (ITC.LT.ITRCH(IT,4)) GO TO 532

            IF (ITC.GT.ITRCH(IT,5)) GO TO 532

            IF (ITO.LT.ITRCH(IT,2)) GO TO 533

            IF (ITO.GT.ITRCH(IT,3)) GO TO 533

C-----------SPECIFY TRENCH CELLS AS CONSTANT HEAD

            IBOUND(ITC,ITO)=-IK

C-----------ASSIGN USER SPECIFIED TRENCH PRESSURE TO TRENCH CELLS

            SHEAD(ITC,ITO)=TSHD(IT)

 533        CONTINUE

 122       CONTINUE

 532       CONTINUE

 121      CONTINUE

 531      CONTINUE

 120     CONTINUE

        END IF

C-------WRITE OUT IBOUND ARRAY FOR INTERMEDIATE CELLS

        WRITE(13,240)LOCAT,ICONST,FMTIN,IPRN

        DO 123 IRR=1,NROW

C--------RECORD CELL TYPES OF INTERMEDIATE LAYERS

         WRITE(13,250)(IBOUND(ICC,IRR),ICC=1,NCOL)

C--------TEMP. STORE STARTING HEADS ON UNIT #23 FOR INTERM. LAYER

         WRITE(23,251)(SHEAD(ICC,IRR),ICC=1,NCOL)

 123    CONTINUE

 250    FORMAT(20I3)

 251    FORMAT(E15.8)

       END IF

 105  CONTINUE

C

C10---WRITE OUT INACTIVE CELL ID

C

      HNOFLO=0.1027E+19

      WRITE(13,255)HNOFLO

 255  FORMAT(E10.4)

C

C11---REWRITE HEAD FILE FROM TEMP FILE 23

C

      CNSTNT=1.0

      FMTIN(1)='(4E1'

      FMTIN(2)='5.8)'

      FMTIN(3)='    '

      FMTIN(4)='    '

      FMTIN(5)='    '

C

C-----SPECIFY OUTPUT OPTION FOR STARTING HEAD (IPRN = 0 -> 10G11.4)

C

      IPRN=0

      REWIND 23

      DO 125 IL=1,NLAY

       WRITE(13,260)LOCAT,CNSTNT,FMTIN,IPRN

 260   FORMAT(I10,F10.3,5A4,I10)

       DO 126 IRA=1,NROW

        DO 127 ICA=1,NCOL

C--------READ IN STARTING HEAD FROM TEMPORARY STORAGE FILE

         READ(23,251) SHEAD(ICA,IRA)

 127    CONTINUE

C-------RECORD STARTING HEADS OF INTERMEDIATE LAYERS

        WRITE(13,261)(SHEAD(ICA,IRA),ICA=1,NCOL)

 126   CONTINUE

 125  CONTINUE

 261  FORMAT(4E15.8)

C-----CLOSE UNIT 23 TO SAVE DISK SPACE

      CLOSE(23)

C

C12---NUMBER OF STRESS PERIODS AND DURATION

C

      NSTPC=0

      DO 128 I = 1,NPER

       READ(12,265) PERLEN,NSTP,TSMULT

C------UNIT CORRECTION

       PERLEN=PERLEN/XU2(3,IU1(3))

C------COUNT TOTAL NUMBER OF TIME STEPS

       NSTPC=NSTPC+NSTP

       WRITE(13,266) PERLEN,NSTP,TSMULT

 128  CONTINUE

 265  FORMAT(F10.0,I10,F10.0)

 266  FORMAT(E10.3,I10,E10.3)

C-----SAVE NUMBER OF TIME STEPS

      IV(88)=NSTPC

C

C-----RETURN

C

      RETURN

      END

C

C     ****************

      SUBROUTINE MODOC

C     ****************

C

C1----NOTES :

C

C     1. USE THIS ROTUINE TO SET UP MODFLOW OUTPUT CONTROL FILE

C     2. THE OUTPUT DATA DEFAULTS TO THE FOLLOWING SETTINGS :

C        - SAVE HEAD VALUES IN EACH LAYER, FOR EACH TIME

C          STEP, TO UNIT #12 (BINARY FILE)

C        - DO NOT SAVE OR PRINT DRAW DOWN VALUES FOR ANY LAYER

C        - PRINT OVERALL VOLUMETRIC BUDGET

C        - RECORD CELL-BY-CELL FLOW TO DISK (UNIT #13 SPECIFIED

C          IN BCF PACKAGE)

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(20)

      CHARACTER*12 FNAME

C

C3----FORMAT FOR HEAD AND DRAW DOWN OUTPUT (IHEDFM = 0, 10G11.4)

C

      IHEDFM=0

      IDDNFM=0

C

C4----UNIT NUMBER FOR HEAD AND DRAW DOWN STORAGE 

C

      IHEDUN=12

      IDDNUN=0

      WRITE(14,270) IHEDFM,IDDNFM,IHEDUN,IDDNUN

 270  FORMAT(4I10)

C

C5----HEAD/DDN OUTPUT CODE (INCODE = 0, OUTPUT SAME FOR ALL LAYERS)

C

      INCODE=0

C

C6----DRAWDOWN OUTPUT FLAG (IHDDFL <> 0, HEAD AND DRAWDN PRINTED

C                         ACCORDING TO FLAGS (HDPR,DDPR,HDSV,DDSV))

C

      IHDDFL=1

C

C7----BUDGET OUTPUT FLAG (IBUDFL = 0, VOLUMETRIC BUDGETS NOT PRINTED)

C

      IBUDFL=0

C

C8----CELL-BY-CELL FLOW TERM FLAG (ICBCFL <> 0, FLOW TERMS PRINTED

C                          ACCORDING TO FLAGS SET IN BCF PACKAGE)

C

      ICBCFL=1

C

C9----OUTPUT FLAG FOR HEAD PRINTOUT (HDPR =  0, HEAD NOT PRINTED)

C

      IHDPR=0

C

C10---OUTPUT FLAG FOR DRAW DOWN PRINTOUT (DDPR =  0, DD NOT PRINTED)

C

      IDDPR=0

C

C11---OUTPUT FLAG FOR SAVING HEAD (HDSV <> 0, HEAD IS SAVED)

C

      IHDSV=1

C

C12---OUTPUT FLAG FOR SAVING DRAW DOWN (DDSV =  0, DD IS NOT SAVED)

C

      IDDSV=0

C

C-----RECORD OUTPUT CONTROL DATA FOR EACH TIME STEP

C

      DO 130 ITM=1,IV(88)

      WRITE(14,270)INCODE,IHDDFL,IBUDFL,ICBCFL

      WRITE(14,270)IHDPR,IDDPR,IHDSV,IDDSV

  130 CONTINUE

C

C-----RETURN

C

      RETURN

      END

C

C     *****************

      SUBROUTINE MODSIP

C     *****************

C

C1----NOTES :

C

C     1. USE THIS ROTUINE TO SET UP MODFLOW MATRIX SOLVER FILE

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(20)

      CHARACTER*12 FNAME

C

C3----SPECIFY SETTINGS FOR STRONGLY IMPLICIT PROCEDURE

C

      IF (IV(89).NE.1) THEN

       MXITER=100

       NPARM=5

       WRITE(16,280) MXITER,NPARM

 280   FORMAT(2I10)

       ACCL=1.0

C

C4----CLOSURE CRITRIA TO CEASE ITERATIONS

C

       HCLOSE=100.0

       IPCALC=1

       IPRSIP=100

       WRITE(16,281)ACCL,HCLOSE,IPCALC,IPRSIP

 281   FORMAT(F10.1,F10.1,I10,I20)

      END IF

C

C5----SPECIFY SETTINGS FOR SUCCESIVE OVERRELAXATION PROCEDURE

C

      IF (IV(89).EQ.1) THEN

       MXITER=100

       WRITE(16,282)MXITER

 282   FORMAT(I10)

       ACCL=1.4

C

C6----CLOSURE CRITRIA TO CEASE ITERATIONS

C

       HCLOSE=100.0

       IPRSOR=100

       WRITE(16,283)ACCL,HCLOSE,IPRSOR

 283   FORMAT(F10.1,F10.1,I10)

      END IF

C

C-----RETURN

C

      RETURN

      END

C

C     *****************

      SUBROUTINE MODBCF(SHW,TSHD,XTRAN,TRPY,THAP,XXKZ,BBB,VCT,VCONT,

C     *****************

C

     1 DELC,DELR,TRAN,SF1,XPERM,VPERM1,VPERM2,IWELL,ITRCH,ILAYCO,

     2 NMLB,NROW,NCOL,NLAY,NWELL,NTRCH,NRC,NCC,NWC,NTC)

C

C1----NOTES :

C

C     1. USE THIS ROTUINE TO SET UP MODFLOW BLOCK CENTERED FLOW FILE

C

C     2. ARRAYS STORING REAL VARIABLES  :

C

C        SHW     =  PRESSURE IN WELLS

C        TSHD    =  PRESSURE IN TRENCHES

C        XTRAN   =  PERMEABILITY * LAYER DEPTH (TRANSMISSIVITY)

C        TRPY    =  ANISOTROPY RATIO

C        THAP    =  PNEUMATIC EQUIVALENT OF STORAGE COEFFICIENT

C        XXKZ    =  VERTICAL PERMEABILITY

C        BBB     =  AVERAGE VERTICAL SPACING BETWEEN NODES

C        VCT     =  VERTICAL CONDUCTANCE IN CELL LAYERS

C        VCONT   =  VERTICAL CONDUCTANCE IN EACH CELL

C                   (ALSO USED TO STORE AIR PHASE POROSITIES

C                    IN LTYPE = 2 APPLICATIONS)

C        DELR    =  NODAL SPACING ALONG ROWS

C        DELC    =  NODAL SPACING ALONG COLUMNS

C        SF1     =  PNEUMATIC EQUIVALENT OF STORAGE COEFFICIENT

C        TRAN    =  PERMEABILITY * LAYER DEPTH (TRANSMISSIVITY)

C        XPERM   =  HORIZONTAL PERMEABILITY OF CELL LAYER I

C        VPERM1  =  VERTICAL PERMEABILITY OF CELL LAYER I

C        VPERM2  =  VERTICAL PERMEABILITY OF CELL LAYER I + 1

C

C     3. ARRAYS STORING INTEGER VARIABLES  :

C

C        ILAYCO  =  FLAG DESIGNATING LAYER AS CONFINED

C        NMLB    =  LAYER NUMBER AT BOTTOM OF GEOLOGIC UNIT

C

C     4. VARIABLE DEFINITIONS  :

C

C        NGEOL   =  NUMBER OF GEOLOGICAL UNITS

C        DTOT    =  TOTAL DEPTH OF GEOLOGIC UNITS IN MODEL

C        BSURF   =  SURFACE CONFINING UNIT DEPTH

C        XVKSRF  =  SURFACE CONFINING UNIT VERTICAL PERMEABILITY

C        GELEV   =  REFERENCE DATUM DEFINING GROUND SURFACE

C        XDD     =  RECORDS COMBINED DEPTH OF ALL GEOLOGIC LAYERS

C        NKT     =  COUNTER FOR CELL LAYER NUMBER

C

C        FOR EACH GEOLOGIC UNIT :

C        NGL     =  UNIT NUMBER OF FILE CONTAINING GEOLOGIC DATA

C        INMLB   =  MODEL LAYER NUMBER AT BASE OF GEOLOGIC UNIT

C        XDEEP   =  GEOLOGIC UNIT THICKNESS 

C        XKX     =  GEOLOGIC UNIT ROW PERMEABILITY

C        YKRAT   =  GEOLOGIC UNIT COLUMN ANISOTROPY RATIO

C        XKZ     =  GEOLOGIC UNIT VERTICAL PERMEABILITY

C        AIRP    =  GEOLOGIC UNIT AIR FILLED POROSITY

C

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/AVALUE/FNAME(20)

      CHARACTER*12 FNAME,IU3*6

      CHARACTER*4 FMTIN(5),FMTIN1(5),ANAME(6)

      LOGICAL OP

      DIMENSION SHW(NWC),TSHD(NTC),XTRAN(NLAY),TRPY(NLAY),

     2 THAP(NLAY),XXKZ(NLAY),BBB(NLAY),VCT(NLAY),VCONT(NCOL,NROW),

     3 DELC(NROW),DELR(NCOL),TRAN(NCOL,NROW),SF1(NCC,NRC),

     4 XPERM(NCC,NRC),VPERM1(NCC,NRC),VPERM2(NCC,NRC)

      DIMENSION IWELL(NWC,7),ITRCH(NTC,7),ILAYCO(NLAY),NMLB(NLAY)

C-----INITIALIZE VARIABLES

      LTYPE = IV(7)

      INBAS = IV(81)

      IOUT  = IV(82)

      LOCAT = IV(85)

C

C3----READ SIMULATION TYPE (TRANSIENT=0, STEADY STATE=1)

C

      READ(12,290)ISS

 290  FORMAT(I10)

C

C-----ASSIGN UNIT NUMBER FOR BINARY FLOW OUTPUT (IBCFCB=13)

C

      IBCFCB=13

      WRITE(15,291)ISS,IBCFCB

 291  FORMAT(2I10)

C

C4----SPECIFY LAYER TYPE (CONFINED=0)

C

      DO 132 IL=1,NLAY

       ILAYCO(IL)=0

  132 CONTINUE

      WRITE(15,295) (ILAYCO(ILL),ILL=1,NLAY)

 295  FORMAT(40I2)

C

C5----INPUT GRID DIMENSION DATA IN COL DIRN (0=UNIFORM, 1=VARIABLE)

C

      IVV1=0

      READ(12,300)CDIST,IVV1,FMTIN

 300  FORMAT(F10.0,I10,5A4)

C-----UNIT CORRECTION

      CDIST=CDIST/XU2(1,IU1(1))

C-----UNIFORM NODAL SPACING IN COLUMN DIRECTION

      IF (IVV1.NE.1) THEN

       COLSP=CDIST/REAL(NROW)

       DO 135 IC=1,NROW

        DELC(IC)=COLSP

 135   CONTINUE

      END IF

C-----NON-UNIFORM NODAL SPACING IN COLUMN DIRECTION

      IF (IVV1.EQ.1) THEN

       READ(12,FMTIN)(DELC(IC),IC=1,NROW)

C------CHECK CELL SPACING ALONG COLUMN

       CTOT=0.0

       DO 136 IC=1,NROW

C-------UNIT CORRECTION

        DELC(IC)=DELC(IC)/XU2(1,IU1(1))

        CTOT=CTOT+DELC(IC)

 136   CONTINUE

       IF ((CTOT.GT.CDIST+0.1).OR.(CTOT.LT.CDIST-0.1)) THEN

        WRITE(IOUT,302)

        WRITE(IOUT,303)CDIST*XU2(1,IU1(1)),IU3(1,IU1(1))

        STOP

 302    FORMAT(/////////////,T10,'ERROR IN SPECIFYING CELL WIDTHS')

 303    FORMAT(/////,T10,'INCREMENTS IN COLUMN DIRECTION DO',

     2   ' NOT ADD UP TO ',F7.1,A6,/////)

       END IF

      END IF

C

C6----INPUT GRID DIMENSION DATA IN ROW DIRN (0=UNIFORM, 1=VARIABLE)

C

      IVV2=0

      READ(12,300)RDIST,IVV2,FMTIN

C-----UNIT CORRECTION

      RDIST=RDIST/XU2(1,IU1(1))

C-----UNIFORM NODAL SPACING IN ROW DIRECTION

      IF (IVV2.NE.1) THEN

       ROWSP=RDIST/REAL(NCOL)

       DO 139 IR=1,NCOL

        DELR(IR)=ROWSP

 139   CONTINUE

      END IF

C-----NON-UNIFORM NODAL SPACING IN ROW DIRECTION

      IF (IVV2.EQ.1) THEN

       READ(12,FMTIN)(DELR(IR),IR=1,NCOL)

C------CHECK CELL SPACING ALONG ROW

       RTOT=0.0

       DO 138 IR=1,NCOL

C-------UNIT CORRECTION

        DELR(IR)=DELR(IR)/XU2(1,IU1(1))

        RTOT=RTOT+DELR(IR)

 138   CONTINUE

       IF ((RTOT.GT.RDIST+0.1).OR.(RTOT.LT.RDIST-0.1)) THEN

        WRITE(IOUT,302)

        WRITE(IOUT,305)RDIST*XU2(1,IU1(1)),IU3(1,IU1(1))

        STOP

 305    FORMAT(/////,T10,'INCREMENTS IN ROW DIRECTION DO',

     2   ' NOT ADD UP TO ',F7.1,A6)

       END IF

      END IF

C

C7----SET OR INPUT AIR PHASE PARAMETERS

C

C     NOTES :

C

C     1. GELEV  = REFERENCE DATUM DEFINING GROUND SURFACE

C        TAIR   = AVERAGE TEMPERATURE OF SOIL

C        BSURF  = THICKNESS OF SUPERIMPOSED ATMOSPHERIC LAYER

C        XVKSRF = VERTICAL PERMEABILITY OF ATMOSPHERIC LAYER

C        VAS    = AIR VISCOSITY AT STANDARD TEMPERATURE TVAS

C               = 1.76E-4 g/cm-sec

C        TVAS   = TEMPERATURE AT WHICH AIR VISCOSITY APPLIES

C               = 283.15 K

C

      VAS    = 1.76E-04

      TVAS   = 283.15

C

      READ(12,344)GELEV,TAIR,BSURF,XVKSRF

 344  FORMAT(3F10.0,E10.3)

C-----UNIT CORRECTION

      GELEV = GELEV/XU2(1,IU1(1))

      TAIR  = (TAIR-XU2(5,IU1(5)))/XU2(5,(IU1(5)+5))

      BSURF = BSURF/XU2(1,IU1(1))

      XVKSRF= XVKSRF/XU2(7,IU1(7))

C

C-----CALCULATE AIR PHASE VISCOSITY FOR DEFINED TEMPERATURE

C

C-----DEFAULT AIR TEMPERATURE TO 10 deg C IF NO ENTRY MADE

      IF((TAIR.GT.-0.00001).AND.(TAIR.LT.0.00001)) THEN

       TAIR=10.0

      END IF

C-----CONVERT TEMPERATURE FROM CELCIUS TO KELVIN

      TAIR=TAIR+273.15

C-----CORRECT VISCOSITY FOR TEMPERATURE EFFECTS

      VA=VAS*(TAIR/TVAS)**0.5

      STDATM = 1013250.0

C                          *

C                          *

C   ********************************************************

C   * PROGRAM INPUT BREAKS AT THIS JUNCTION, GIVING AN     *

C   * OPTION ON THE DEGREE OF COMPLEXITY OF THE DATA INPUT *

C   ********************************************************

C

C     ***************************************************

C8a---AIRFLOW SIMULATION IN UNIFORM CELL LAYERS (LTYPE=1)

C     ***************************************************

C

C     NOTES

C     1. THIS OPTION PROVIDES THE USER WITH THE ABILITY TO

C         DEFINE GEOLOGIC LAYERS WHICH ENCOMPASS SEVERAL

C         MODEL LAYERS.  HENCE INPUT PARAMETERS SUCH AS

C         PERMEABILITY, WHICH ARE SPECIFIED FOR A PARTICULAR 

C         GEOLOGIC LAYER, ARE ASSIGNED TO ALL MODEL LAYERS 

C         FALLING WITHIN THE GEOLOGIC LAYER.

C     2. THIS APPROACH HOWEVER, ASSUMES THAT EACH LAYER IS

C         HORIZONTAL AND THAT THE ASSIGNED PARAMETERS WITHIN

C         EACH GEOLOGIC LAYER DO NOT VARY (IE. HOMOGENEOUS

C         CELL LAYERS).

C     3. FOR MORE DETAILED MODEL SIMULATIONS, IE VARIATIONS

C         IN PHYSICAL PARAMETERS WITH A LAYER, THE USER MUST

C         INPUT SPECIFIC ARRAYS AS PERFORMED IN THE SECOND

C         OPTION (LTYPE=2) WHICH APPLIES TO HETEROGENEOUS

C         CELL LAYERS.

C

C

C9a---INPUT MODEL DIMENSIONS FOR GEOLOGIC LAYERS

C

      IF (LTYPE.EQ.1) THEN

       READ(12,310)NGEOL,DTOT

 310   FORMAT(I10,F10.0)

C------UNIT CORRECTION

       DTOT=DTOT/XU2(1,IU1(1))

C

C10a--SPECIFY PHYSICAL PARAMETERS FOR SUPERIMPOSED

C      ATMOSPHERIC BOUNDARY LAYER

C

       XDD=0.0

       XTRAN(1)=1.0

       TRPY(1)=1.0

       THAP(1)=1.0

       XXKZ(1)=1.0

       NKT=2

C

C11a---INPUT PHYSICAL PARAMETERS FOR GEOLOGIC LAYERS

C

       DO 140 IGEO=1,NGEOL

C-------ASSIGN CELL LAYER NUMBER (IE. AT TOP OF GEOLOGIC LAYER)

        IF (IGEO.NE.1) THEN

         NKT=NMLB(IGEO-1)+2

        END IF

        READ(12,311)NGL,INMLB,XDEEP,XKX,YKRAT,XKZ,AIRP

C-------UNIT CORRECTION

        NGL = NGL/1

        XDEEP=XDEEP/XU2(1,IU1(1))

        XKX=XKX/XU2(7,IU1(7))

        XKZ=XKZ/XU2(7,IU1(7))

C-------TRACK TOTAL DEPTH OF GEOLOGIC LAYERS

        XDD=XDD+XDEEP

 311    FORMAT(I10,I10,F10.0,E10.3,F5.0,E10.3,F5.0)

C-------STORE CELL LAYER NUMBER COINCIDENT WITH BOTTOM OF 

C       GEOLOGIC LAYER TO ARRAY

        NMLB(IGEO)=INMLB

C-------DETERMINE AVERAGE VERTICAL SPACING OF CELLS LYING

C       WITHIN THE GEOLOGIC LAYER

        IF (IGEO.EQ.1) THEN

         BB=XDEEP/REAL(NMLB(IGEO))

         BBB(IGEO)=BB

        END IF

        IF (IGEO.NE.1) THEN

         BB=XDEEP/REAL(NMLB(IGEO)-NMLB(IGEO-1))

         BBB(IGEO)=BB

        END IF

C

C-------ASSIGN ANISOTROPY RATIOS, 'TRANSMISSIVITY' AND 'STORAGE

C       COEFFICIENTS' TO ARRAY RECORDING PARAMETERS IN EACH

C       GEOLOGIC STRATA (NOTE ASSIGNED VALUES ARE USED FOR ALL

C       CELLS WITHIN GEOLOGIC LAYER).

C

        DO 141 IKT=NKT,NMLB(IGEO)+1

         TRPY(IKT)=YKRAT

         XTRAN(IKT)=XKX*BB

         THAP(IKT)=(AIRP*BB*VA)/STDATM

         XXKZ(IKT)=XKZ

 141    CONTINUE

 140   CONTINUE

C

C------CHECK THAT LAYER NUMBER SPECIFIED IN LOWEST GEOLOGIC

C      UNIT CORRESPONDS TO (NLAY-1)

C

       IF (NMLB(NGEOL).NE.(NLAY-1)) THEN

        WRITE(IOUT,315)

        WRITE(IOUT,316)NLAY-1

        WRITE(IOUT,317)NMLB(NGEOL)

        STOP

       END IF

 315   FORMAT(////////////////,T10,'THERE IS A DISCREPANCY IN THE',

     1 ' NUMBER OF LAYERS')

 316   FORMAT(/,T10,'NLAY WAS INPUT AS                : ',I4)

 317   FORMAT(/,T10,'LAYER IN LOWEST GEOLOGIC UNIT IS : ',I4)

C

C12a---DETERMINE THICKNESS OF SUPERIMPOSED ATMOSPHERIC LAYER

C

C      NOTES :

C      1. ONLY GENERATE VALUE FOR BSURF IF USER DID NOT ENTER

C         VALUE (IE. BSURF = 0)

C      2. IF NO VALUE FOR BSURF WAS SPECIFIED BY USER, THEN

C         SET BSURF = (0.2)(THICKNESS OF SURFACE CELL LAYER)

C         OR  BSURF = 5.0 cm (WHICH EVER IS GREATER)

C      3. IF FORMAT STATEMENT 319 IS CHANGED, THEN A SIMILAR

C         CHANGE MUST BE MADE IN THE POST PROCESSOR

C

       IF (BSURF.LT.1.0E-03) THEN

        BSURF = 0.2*BBB(1)

        IF (BSURF.LT.5.0) THEN

         BSURF = BBB(1)

        END IF

       END IF

C

C13a---GENERATE MODEL.DAT FILE CONTAINING DEPTHS OF CELL LAYERS

C

C------CONVERT BACK TO INPUT UNITS

       GELEVO = GELEV*XU2(1,IU1(1))

       BSURFO = BSURF*XU2(1,IU1(1))

       TAIRO=(TAIR-273.15)*XU2(5,(IU1(5)+5))+XU2(5,IU1(5))

C------OUTPUT SECOND LINE OF MODEL.DAT FILE

       WRITE(19,319)GELEVO,BSURFO,TAIRO

C------OUTPUT DISTANCES TO BOTTOM OF CELL LAYERS FROM DATUM

C      NOTE, ACTUAL DISTANCES REQUIRED NOT ELEVATIONS

       ZDEPTH = 0.0

       DO 145 I = 1,NGEOL

        IF (I.EQ.1) THEN

         IVARC1 = NMLB(I)

        END IF

        IF (I.NE.1) THEN

         IVARC1 = NMLB(I)-NMLB(I-1)

        END IF

        DO 146 J = 1,IVARC1

         ZDEPTH = ZDEPTH + BBB(I)

         WRITE(19,320)ZDEPTH*XU2(1,IU1(1))

 146    CONTINUE

 145   CONTINUE

 319   FORMAT(3F10.2)

 320   FORMAT(F10.2)

C------TEST DEPTH OUTPUT

       IF ((ZDEPTH.LT.DTOT-0.1).OR.(ZDEPTH.GT.DTOT+0.1)) THEN

        WRITE(IOUT,321)

        WRITE(IOUT,322)ZDEPTH*XU2(1,IU1(1)),' ',IU3(1,IU1(1))

        WRITE(IOUT,323)DTOT*XU2(1,IU1(1)),' ',IU3(1,IU1(1))

        STOP

       END IF

 321   FORMAT(///////////////,T5,'ERROR IN NODAL VERTICAL',

     2   ' SPACING INPUT')

 322   FORMAT(//////,T5,'CALCULATED DEPTH OF BOTTOM LAYER IN ',

     2  ' MODEL.DAT FILE,',F7.1,A1,A6)

 323   FORMAT(//,T5,'DOES NOT EQUAL INPUT DEPTH OF BOTTOM LAYER',

     2  ' IN DATAIRx.PRN FILE,',F7.1,A1,A6)

C

C------TEST GEOLOGIC LAYER THICKNESS TO ENSURE IT MATCHES

C      USER SPECIFIED MODEL THICKNESS

C

       IF ((XDD.GT.DTOT+0.1).OR.(XDD.LT.DTOT-0.1)) THEN

        WRITE(IOUT,324)

        STOP

       END IF

 324   FORMAT(///////,T10,'INPUT ERROR IN TOTAL/INDIVIDUAL',

     1 ' LAYER DEPTHS')

C

C14a---OUTPUT ANISOTROPY RATIO FOR EACH LAYER

C

C      USE UTILITY MODULE U1DREL

C------TEST FOR VARIATION IN TRPY VALUES

C

       IVARC2 = 1

       VARC2  = TRPY(1)

       DO 150 I = 2, NLAY

        IF ((TRPY(I).GT.VARC2-1.0E-04).AND.(TRPY(I).LT.

     1       VARC2+1.0E-04)) THEN

         IVARC2 = IVARC2 + 1

        END IF

        VARC2 = TRPY(I)

 150   CONTINUE

C

C      IF ALL VALUES IN TRPY ARE THE SAME, USE ABBREVIATED FORM

C      OF U1DREL (IE. IVARC2 WILL EQUAL NLAY IF SATISFIED)

C

       IF (IVARC2.EQ.NLAY) THEN

C-------ASSIGN OPTIONS FOR UTILITY MODULE U1DREL (UNIFORM)

        LOCAT=0

        CNSTNT=TRPY(2)

        WRITE(15,260) LOCAT,CNSTNT

       END IF

       IF (IVARC2.NE.NLAY) THEN

C-------ASSIGN OPTIONS FOR UTILITY MODULE U1DREL (NON-UNIFORM)

        LOCAT=7

        CNSTNT=1.0

        FMTIN(1)='(6F1'

        FMTIN(2)='0.3)'

        FMTIN(3)='    '

        FMTIN(4)='    '

        FMTIN(5)='    '

C-------FOR IPRN < 0 ARRAY WILL NOT BE PRINTED

C-------FOR IPRN = 0 ARRAY WILL BE PRINTED AS 10G12.5

        IPRN=0

        WRITE(15,260) LOCAT,CNSTNT,FMTIN,IPRN

        WRITE(15,326) (TRPY(ITY),ITY=1,NLAY)

       END IF

 260   FORMAT(I10,F10.3,5A4,I10)

 325   FORMAT(F10.3)

 326   FORMAT(6F10.3)

C

C15a---OUTPUT CELL SPACING ALONG ROW FOR EACH LAYER

C

C      USE UTILITY MODULE U1DREL

C      IF ALL VALUES IN DELR ARE THE SAME, USE ABBREVIATED FORM

C

       IF (IVV2.NE.1) THEN

C-------ASSIGN OPTIONS FOR UTILITY MODULE U1DREL (UNIFORM)

        LOCAT=0

        CNSTNT=DELR(1)

        WRITE(15,260) LOCAT,CNSTNT

       END IF

       IF (IVV2.EQ.1) THEN

C-------ASSIGN OPTIONS FOR UTILITY MODULE U1DREL (NON-UNIFORM)

        LOCAT=7

        CNSTNT=1.0

        FMTIN(1)='(6F1'

        FMTIN(2)='0.3)'

        FMTIN(3)='    '

        FMTIN(4)='    '

        FMTIN(5)='    '

C-------FOR IPRN < 0 ARRAY WILL NOT BE PRINTED

C-------FOR IPRN = 0 ARRAY WILL BE PRINTED AS 10G12.5

        IPRN=0

        WRITE(15,260) LOCAT,CNSTNT,FMTIN,IPRN

        WRITE(15,326) (DELR(IRR),IRR=1,NCOL)

       END IF

C

C16a---OUTPUT CELL SPACING ALONG COLUMN FOR EACH LAYER

C

C      USE UTILITY MODULE U1DREL

C      IF ALL VALUES IN DELC ARE THE SAME, USE ABBREVIATED FORM

C

       IF (IVV1.NE.1) THEN

C-------ASSIGN OPTIONS FOR UTILITY MODULE U1DREL (UNIFORM)

        LOCAT=0

        CNSTNT=DELC(1)

        WRITE(15,260) LOCAT,CNSTNT

       END IF

       IF (IVV1.EQ.1) THEN

C-------ASSIGN OPTIONS FOR UTILITY MODULE U1DREL (NON-UNIFORM)

        LOCAT=7

        CNSTNT=1.0

        FMTIN(1)='(6F1'

        FMTIN(2)='0.3)'

        FMTIN(3)='    '

        FMTIN(4)='    '

        FMTIN(5)='    '

C-------FOR IPRN < 0 ARRAY WILL NOT BE PRINTED

C-------FOR IPRN = 0 ARRAY WILL BE PRINTED AS 10G12.5

        IPRN=0

        WRITE(15,260) LOCAT,CNSTNT,FMTIN,IPRN

        WRITE(15,326) (DELC(ICC),ICC=1,NROW)

       END IF

C

C======SET UP 2-D ARRAY SUBSETS

C

C------ASSIGN OPTIONS FOR UTILITY MODULE U1DREL

C

C      NOTE :

C      1. OPTION TO ASSIGN VALUES USING LOCAT = 0 AND CNSTNT

C         IS LIMITED BY F10.0 FORMAT IN U1DREL AND U2DREL.

C         MANY OF THE OUTPUT VARIABLES ARE E15.8 FORMAT WHICH

C         CANNOT BE ACCOMODATED BY F10.0

C         THIS MEANS THE FULL ARRAY MUST BE OUTPUT

C

       IGEO=1

       LOCAT=7

       CNSTNT=1.0

       FMTIN(1)='(4E1'

       FMTIN(2)='5.8)'

       FMTIN(3)='    '

       FMTIN(4)='    '

       FMTIN(5)='    '

C

C------FOR IPRN = 0 PARAMETER WILL BE PRINTED AS 10G11.4

C

       IPRN=0

C------ASSIGN PARAMETERS FOR EACH LAYER

       DO 155 ICT=1,NLAY

C

C15a----WRITE 'STORAGE COEFFICIENT' FOR TRANSIENT 3D SIMULATIONS

C

        IF (ISS.EQ.0) THEN

         WRITE(15,260) LOCAT,CNSTNT,FMTIN,IPRN

         DO 160 IR=1,NROW

          DO 161 IC=1,NCOL

           SF1(IC,IR)=THAP(ICT)

 161      CONTINUE

          WRITE(15,330) (SF1(IC,IR),IC=1,NCOL)

 160     CONTINUE

 330     FORMAT(4E15.8)

        END IF

C

C16a----WRITE TRANSMISSIVITY ALONG ROWS FOR 3D SIMULATIONS

C

C       NOTES :

C       1. THIS WILL ALWAYS BE NEEDED SINCE LAYERS ARE ASSUMED

C           TO BEHAVE AS CONFINED IN PNEUMATIC ANALYSES

C

        WRITE(15,260) LOCAT,CNSTNT,FMTIN,IPRN

        DO 164 IR=1,NROW

         DO 165 IC=1,NCOL

          TRAN(IC,IR)=XTRAN(ICT)

 165     CONTINUE

         WRITE(15,330)(TRAN(IC,IR),IC=1,NCOL)

 164    CONTINUE

C

C17a----WRITE VERTICAL PERMEABILITY DIVIDED BY CELL LAYER

C        THICKNESS (IE. VERTICAL CONDUCTANCE)

C

C-------NOT REQUIRED FOR BOTTOM LAYER

        IF (ICT.LT.NLAY) THEN

C--------WRITE VALUE FOR LAYER #1 (BOUNDARY)

         IF (ICT.EQ.1) THEN

C---------CALCULATE VERTICAL CONDUCTANCE FOR SUPERIMPOSED 

C         ATMOSPHERIC UNIT

C

C         NOTES :

C         1. ONLY GENERATE VALUE FOR XVKSRF IF USER DID NOT ENTER

C            VALUE (IE. XVKSRF = 0.0)

C         2. IF NO VALUE FOR XVKSRF WAS SPECIFIED BY USER, THEN

C            SET XVKSRF = (100.0)(XKZ VALUE SPECIFIED FOR

C                                 SURFACE GEOLOGIC LAYER)

C         3. USE EQUATION 53 FROM MODFLOW MANUAL FOR VCONT IN 

C            ATMOSPHERIC LAYER

C---------TEST FOR USER ASSIGNED VALUE

          IF (XVKSRF.LT.1.0E-20) THEN

           XVKSRF=100.0*XXKZ(2)

          END IF

          VCT(ICT)=XVKSRF/BSURF

         END IF

         IF (ICT.NE.1) THEN

C---------CHECK IF CELL LAYER LIES IN THE NEXT GEOLOGIC LAYER

          IF (ICT.NE.(NMLB(IGEO)+1)) THEN

C----------SET UP DENOMINATOR IN VERTICAL CONDUCTANCE EQUATION

C          EQN (51) - MODFLOW MANUAL, FOR CELL LAYERS NOT

C          AT GEOLOGIC STRATA INTERFACES

           A=(BBB(IGEO)/XXKZ(ICT))+(BBB(IGEO)/XXKZ(ICT+1))

          END IF

          IF (ICT.EQ.(NMLB(IGEO)+1)) THEN

C----------SET UP DENOMINATOR IN VERTICAL CONDUCTANCE EQUATION

C          EQN (51) - MODFLOW MANUAL, FOR CELL LAYERS AT

C          GEOLOGIC STRATA INTERFACES

           A=(BBB(IGEO)/XXKZ(ICT))+(BBB(IGEO+1)/XXKZ(ICT+1))

           IGEO=IGEO+1

          END IF

C---------EVALUATE VERTICAL CONDUCTANCE TERM (EQN 51 - MANUAL)

          VCT(ICT)=2.0/A

         END IF

         WRITE(15,260) LOCAT,CNSTNT,FMTIN,IPRN

C--------ASSIGN VERTICAL CONDUCTANCE TO EACH CELL IN LAYER FOR 3D SIMS

         DO 168 IR=1,NROW

          DO 169 IC=1,NCOL

           VCONT(IC,IR)=VCT(ICT)

 169      CONTINUE

          WRITE(15,330) (VCONT(IC,IR),IC=1,NCOL)

 168     CONTINUE

C

        END IF

 155   CONTINUE

      END IF

C

C     *******************************************************

C8b---AIRFLOW SIMULATION IN NON-UNIFORM CELL LAYERS (LTYPE=2)

C     *******************************************************

C

C     NOTES

C     1. THIS OPTION PROVIDES THE USER WITH THE ABILITY TO

C         INPUT CELL SPECIFIC PARAMETERS IN THE MODEL

C         (IE. NON UNIFORM CELL PROPERTIES)

C     2. INPUT REQUIREMENTS ARE HOWEVER, CONSIDERABLY MORE

C         EXTENSIVE SINCE ARRAYS FOR EACH PARAMETER AND FOR

C         EACH CELL LAYER MUST BE GENERATED

C

C-----SKIP SECTION IF SIMPLE OPTION WAS INVOKED

      IF (LTYPE.EQ.2) THEN

C

C9b----ANISOTROPY

C

C------ANISOTROPY RATIO IN LAYER #1 (BOUNDARY)

C

C--------DESCRIPTION OF INPUT FOR ANISOTROPY RATIO

C

         ANAME(1) = 'ANIS'

         ANAME(2) = 'OTRO'

         ANAME(3) = 'PY R'

         ANAME(4) = 'ATIO'

         ANAME(5) = ' '

         ANAME(6) = ' '

C

C------SPECIFY RATIO IN LAYER #1 (BOUNDARY)

       TRPY(1)=1.0

C------INPUT ANISOTROPY RATIO FOR EACH CELL LAYER

C      NOTE : NLAY = NLAY (SPECIFIED BY USER) + 1

       READ(12,360) LOCAT,CNSTNT,FMTIN

C------IF LOCAT=0 THEN SET ALL TRPY TO CNSTNT

       IF (LOCAT.EQ.0) THEN

        DO 173 IRD=2,NLAY

         TRPY(IRD)=CNSTNT

 173    CONTINUE

       END IF

C------IF LOCAT>0 THEN INPUT VALUES OF TRPY

       IF ((LOCAT.GT.0).AND.(LOCAT.NE.12)) THEN

        INQUIRE (UNIT=LOCAT,OPENED=OP)

        IF (OP) GO TO 1555

C-------SET FLAG TO TEXT INPUT (IFG=0) AND SPECIFY FILE NAME &

C       NUMBER IN SUBROUTINE FILEDF

        IFG = 0

        CALL FILEDF(LOCAT,ANAME,IFG)

       END IF

 1555  CONTINUE

C------INPUT ANISOTRPY RATIO FROM REDEFINED FILE

       IF (LOCAT.GT.0) THEN

        READ(LOCAT,FMTIN)(TRPY(IRD),IRD=2,NLAY)

       END IF

C

C------LOCAT<0 THEN READ UNFORMATTED RECORD CONTAINING ARRAY VALUES

C

       IF (LOCAT.LT.0) THEN

        LOCAT=-LOCAT

C

C-------TEST TO MAKE SURE UNIT NUMBER CONFORMS TO A BINARY FILE

C

        IF (LOCAT.EQ.12) THEN

 1556    CONTINUE

         WRITE(IOUT,370)LOCAT

         WRITE(IOUT,371)

         WRITE(IOUT,372)

         READ(INBAS,373) LOCAT

         IF ((LOCAT.LT.20).OR.(LOCAT.GT.50)) GO TO 1556

        END IF

        IF (LOCAT.NE.12) THEN

         INQUIRE (UNIT=LOCAT,OPENED=OP)

         IF (OP) GO TO 1557

C--------SET FLAG TO BINARY INPUT (IFG=1) AND SPECIFY FILE NAME &

C        NUMBER IN SUBROUTINE FILEDF

         IFG = 1

         CALL FILEDF(LOCAT,ANAME,IFG)

 1557    CONTINUE

C--------READ AN UNFORMATTED DUMMY RECORD FIRST

         READ(LOCAT)

C--------READ AN UNFORMATTED VERTICAL PERMEABILITY ARRAY

         READ(LOCAT) TRPY

        END IF

       END IF

C

C------IF CNSTNT NOT ZERO THEN MULTIPLY ARRAY VALUES BY CNSTNT

C

       IF (((CNSTNT.GT.1.0E-20).OR.(CNSTNT.LT.-1.0E-20)).AND.

     1     (LOCAT.NE.0)) THEN

        DO 174 I=2,NLAY

         TRPY(I)=TRPY(I)*CNSTNT

 174    CONTINUE

       END IF

C

C------ASSIGN OPTIONS FOR UTILITY MODULE U1DREL

C

       LOCAT=7

       CNSTNT=1.0

       FMTIN(1)='(6F1'

       FMTIN(2)='0.3)'

C------FOR IPRN = 0 PARAMETER WILL BE PRINTED AS 10G11.4

       IPRN=0

       WRITE(15,260) LOCAT,CNSTNT,FMTIN,IPRN

       WRITE(15,326)(TRPY(IRD),IRD=1,NLAY)

C

C10b---GRID DIMENSION DATA

C

C------WRITE OUT CELL SPACING ALONG ROWS

C------ABBREVIATED FORM

       IF (IVV2.NE.1) THEN

        LOCXX=0

        CNSTXX=DELR(1)

        WRITE(15,260) LOCXX,CNSTXX

       END IF

C------LINEAR ARRAY FORM

       IF (IVV2.EQ.1) THEN

        WRITE(15,260) LOCAT,CNSTNT,FMTIN,IPRN

        WRITE(15,326)(DELR(IRR),IRR=1,NCOL)

       END IF

C------WRITE OUT CELL SPACING ALONG COLUMNS

C------ABBREVIATED FORM

       IF (IVV1.NE.1) THEN

        LOCXX=0

        CNSTXX=DELC(1)

        WRITE(15,260) LOCXX,CNSTXX

       END IF

C------LINEAR ARRAY FORM

       IF (IVV1.EQ.1) THEN

        WRITE(15,260) LOCAT,CNSTNT,FMTIN,IPRN

        WRITE(15,326)(DELC(ICC),ICC=1,NROW)

       END IF

C

C------ASSIGN OPTIONS FOR UTILITY MODULE U2DREL

C

       LOCAT1=7

       CNST1=1.0

       FMTIN1(1)='(4E1'

       FMTIN1(2)='5.8)'

       FMTIN1(3)='    '

       FMTIN1(4)='    '

       FMTIN1(5)='    '

C------FOR IPRN = 0 PARAMETER WILL BE PRINTED AS 10G11.4

       IPRN1=0

C

C------FLAGS FOR VERTICAL CONDUCTANCE OPTIONS

       IFLAG1=1

       IFLAG2=1

C------SETTING FOR MODEL.DAT FILE

       ZDEPTH=0.0

C

C11b---INPUT 2D ARRAYS FOR PHYSICAL PARAMETERS IN EACH LAYER

C

       DO 175 ICD=1,NLAY

C

C-------TOP LAYER

C

C       NOTES :

C       1. LAYER #1 IS THE ATMOSPHERIC LAYER ADDED TO THE MODEL

C          BY THE PROGRAM

C

C-------TEST TO ENSURE LAYER #1 (ATMOSPHERIC BOUNDARY)

        IF (ICD.EQ.1) THEN

         DO 176 IR=1,NROW

          DO 177 IC=1,NCOL

C----------ASSIGN PNEUMATIC EQUIVALENT OF STORAGE COEFFICIENT

C          TO SUPERIMPOSED ATMOSPHERIC LAYER #1

           SF1(IC,IR)=1.0

C----------ASSIGN PNEUMATIC EQUIVALENT OF TRANSMISSIVITY

C          TO SUPERIMPOSED ATMOSPHERIC LAYER #1

           TRAN(IC,IR)=1.0

C----------ASSIGN VERTICAL CONDUCTANCE AFTER READING VALUES

C          INPUT FOR FIRST GEOLOGIC LAYER

 177      CONTINUE

 176     CONTINUE

C--------TEST TO SEE IF SIMULATION IS STEADY STATE (ISS = 1)

C         OR TRANSIENT (ISS = 0)

         IF (ISS.EQ.0) THEN

          WRITE(15,260) LOCAT1,CNST1,FMTIN1,IPRN1

C---------WRITE OUT 2D ARRAY FOR STORAGE COEFFICIENT FOR 3D SIMS

          DO 178 IR=1,NROW

           WRITE(15,330)(SF1(IC,IR),IC=1,NCOL)

 178      CONTINUE

         END IF

C--------WRITE OUT 2D ARRAY FOR TRANSMISSIVITY FOR 3D SIMULATIONS

         WRITE(15,260) LOCAT1,CNST1,FMTIN1,IPRN1

         DO 179 IR=1,NROW

          WRITE(15,330)(TRAN(IC,IR),IC=1,NCOL)

 179     CONTINUE

        END IF

C

C-------INTERMEDIATE LAYERS

C

C

C-------SAVE PREVIOUS CELL LAYER DEPTHS

C

C       NOTES :

C       1. FOR ICD = 1, PRE-PROCESSOR WRITES OUT INFORMATION

C           ON SUPERIMPOSED ATMOSPHERIC LAYER

C       2. TO CALCULATE VCONT, PROPERTIES OF CONSECUTIVE

C           LAYERS ARE REQUIRED, HENCE PRE-PROCESSOR STORES

C           SELECTED PROPERTIES FROM PREVIOUS LAYER.

C

C

C12b----SAVE CELL DEPTH AND VERTICAL PERMEABILITY FOR LAYER ICD-1

C

C-------ONLY DEALING WITH INTERMEDIATE LAYERS

        IF (ICD.NE.1) THEN

         IF (ICD.GT.2) THEN

          XBB1=XBB2

          DO 182 IR=1,NROW

           DO 183 IC=1,NCOL

            VPERM1(IC,IR)=VPERM2(IC,IR)

 183       CONTINUE

 182      CONTINUE

         END IF

C

C--------READ IN CELL DEPTHS FOR LAYER ICD

C

         READ(12,360) LOCAT,CNSTNT,FMTIN

 360     FORMAT(I10,F20.0,5A4)

C

C--------IF LOCAT=0 THEN SET ALL XBB2 TO CNSTNT

C

         IF (LOCAT.EQ.0) THEN

          XBB2=CNSTNT

         END IF

C--------UNIT CONVERTION

         XBB2=XBB2/XU2(1,IU1(1))

C

C--------IF LOCAT<>0 THEN SET STOP PROGRAM

C

         IF (LOCAT.NE.0) THEN

          WRITE(IOUT,1362)

          WRITE(IOUT,1363)FNAME(2)

          WRITE(IOUT,1364)

          WRITE(IOUT,1365)FNAME(2)

          STOP

         END IF

 1362    FORMAT(//////////,T10,'THICKNESS OF CELLS WITHIN A LAYER',

     1           ' MUST BE UNIFORM')

 1363    FORMAT(/,T10,'TYPICAL ENTRY IN FILE ',A12,' IS AS FOLLOWS',

     1           ' :')

 1364    FORMAT(//,T10,'LOCAT = 0,  CNSTNT = layer depth, FMTIN =',

     1            ' blank')

 1365    FORMAT(//,T10,'MAKE NECESSARY CHANGES TO ',A12,' AND ',

     1            'RE-RUN PREAIR')

C

C13b-----WRITE OUTPUT TO MODEL.DAT FILE

C

C        NOTES :

C        1. ONLY GENERATE VALUE FOR BSURF IF USER DID NOT ENTER

C           VALUE (IE. BSURF = 0)

C        2. IF NO VALUE FOR BSURF WAS SPECIFIED BY USER, THEN

C           SET BSURF = (0.2)(THICKNESS OF SURFACE GEOLOGIC LAYER)

C           PROVIDING BSURF > 5.0 CM ELSE 

C           SET BSURF = (THICKNESS OF SURFACE GEOLOGIC LAYER)

C        3. IF FORMAT STATEMENT 380 IS CHANGED, THEN A SIMILAR

C           CHANGE MUST BE MADE IN THE POST PROCESSOR

C

C--------ONLY GENERATE ON FIRST LOOP 

         IF(ICD.EQ.2) THEN

          IF(BSURF.LT.1.0E-03) THEN

           BSURF = 0.2*XBB2

           IF(BSURF.LT.5.0) THEN

            BSURF = XBB2

           END IF

          END IF

C---------CONVERT BACK TO INPUT UNITS

          GELEVO = GELEV*XU2(1,IU1(1))

          BSURFO = BSURF*XU2(1,IU1(1))

          TAIRO=(TAIR-273.15)*XU2(5,(IU1(5)+5))+XU2(5,IU1(5))

          WRITE(19,349)GELEVO,BSURFO,TAIRO

 349      FORMAT(3F10.2)

         END IF

C

C--------WRITE OUT 1D ARRAYS WITH CELL DEPTHS TO FILE MODEL.DAT

C

         ZDEPTH=ZDEPTH+XBB2

         WRITE(19,380)ZDEPTH*XU2(1,IU1(1))

 380     FORMAT(F10.2)

C

C14b-----DESCRIPTION OF INPUT FOR VERTICAL PERMEABILITY

C

         ANAME(1) = 'VERT'

         ANAME(2) = 'ICAL'

         ANAME(3) = ' PER'

         ANAME(4) = 'MEAB'

         ANAME(5) = 'ILIT'

         ANAME(6) = 'Y'

C

C--------READ IN VERTICAL PERMEABILITIES OF CELLS IN LAYER ICD

C

C        NOTES :

C        1. VARIABLES :

C          FOR  IFLAG2 = 0, MODFLOW EQUATION (49) WILL BE USED

C                           TO CALCULATE VCONT

C          FOR  IFLAG2 = 1, MODFLOW EQUATION (53) WILL BE USED

C                           TO CALCULATE VCONT

C

         IFLAG1 = IFLAG2

C

C--------READ IN VERTICAL PERMEABILITY FOR LAYER ICD

C

         READ(12,390) LOCAT,CNSTNT,FMTIN,IFLAG2

 390     FORMAT(I10,F20.0,5A4,I10)

C

C--------IF LOCAT=0 THEN SET ALL ARRAY VALUES EQUAL TO CNSTNT

C

         IF (LOCAT.EQ.0) THEN

          DO 820 I=1,NROW

           DO 821 J=1,NCOL

            VPERM2(J,I)=CNSTNT

 821       CONTINUE

 820      CONTINUE

         END IF

C

C--------IF LOCAT>0 THEN READ FORMATTED RECORDS USING FORMAT FMTIN

C

         IF ((LOCAT.GT.0).AND.(LOCAT.NE.12)) THEN

          INQUIRE (UNIT=LOCAT,OPENED=OP)

          IF (OP) GO TO 555

C---------SET FLAG TO TEXT INPUT (0) AND SPECIFY FILE NAME &

C         NUMBER IN SUBROUTINE FILEDF

          IFG = 0

          CALL FILEDF(LOCAT,ANAME,IFG)

         END IF

 555     CONTINUE

C--------INPUT VERTICAL PERMEABILITY DATA FROM REDEFINED FILE

         IF (LOCAT.GT.0) THEN

          DO 825 I=1,NROW

           READ(LOCAT,FMTIN) (VPERM2(J,I),J=1,NCOL)

 825      CONTINUE

         END IF

C

C--------LOCAT<0 THEN READ UNFORMATTED RECORD CONTAINING ARRAY VALUES

C

         IF (LOCAT.LT.0) THEN

          LOCAT=-LOCAT

C

C---------TEST TO MAKE SURE UNIT NUMBER CONFORMS TO A BINARY FILE

C

          IF (LOCAT.EQ.12) THEN

 556       CONTINUE

           WRITE(IOUT,370)LOCAT

           WRITE(IOUT,371)

           WRITE(IOUT,372)

           READ(INBAS,373) LOCAT

           IF ((LOCAT.LT.20).OR.(LOCAT.GT.50)) GO TO 556

          END IF

 370      FORMAT(///////,T10,'UNIT ',I2,' IS NOT A BINARY FILE')

 371      FORMAT(//,T10,'ENTER UNIT NUMBER FOR BINARY FILE')

 372      FORMAT(/,T10,'BETWEEN NUMBERS 20 AND 50  : ')

 373      FORMAT(I2)

          IF (LOCAT.NE.12) THEN

           INQUIRE (UNIT=LOCAT,OPENED=OP)

           IF (OP) GO TO 557

C----------SET FLAG TO BINARY INPUT (1) AND SPECIFY FILE NAME &

C           NUMBER IN SUBROUTINE FILEDF

           IFG = 1

           CALL FILEDF(LOCAT,ANAME,IFG)

 557       CONTINUE

C----------READ AN UNFORMATTED DUMMY RECORD FIRST

           READ(LOCAT)

C----------READ AN UNFORMATTED VERTICAL PERMEABILITY ARRAY FOR 3D SIMS

           READ(LOCAT) VPERM2

          END IF

         END IF

C

C--------IF CNSTNT NOT ZERO THEN MULTIPLY ARRAY VALUES BY CNSTNT

C

         IF (((CNSTNT.GT.1.0E-20).OR.(CNSTNT.LT.-1.0E-20)).AND.

     1       (LOCAT.NE.0)) THEN

          DO 830 I=1,NROW

           DO 831 J=1,NCOL

            VPERM2(J,I)=VPERM2(J,I)*CNSTNT

 831       CONTINUE

 830      CONTINUE

         END IF

C--------UNIT CONVERTION

         DO 832 I=1,NROW

          DO 833 J=1,NCOL

           VPERM2(J,I)=VPERM2(J,I)/XU2(7,IU1(7))

 833      CONTINUE

 832     CONTINUE

C

C15b-----CALCULATE VERTICAL CONDUCTANCE FOR UNIT WITH

C        PERMEABILITY SIMILAR TO ADJACENT LAYER

C        NOTES :

C        1. USE EQUATION 51 FROM MODFLOW MANUAL FOR VCONT

C

         IF (ICD.GT.2) THEN

          IF (IFLAG2.EQ.IFLAG1) THEN

           DO 187 IR=1,NROW

            DO 188 IC=1,NCOL

C------------DENOMINATOR IN VERTICAL CONDUCTANCE EQN 51 MANUAL

             VK1=XBB1/VPERM1(IC,IR)

             VK2=XBB2/VPERM2(IC,IR)

C------------VERTICAL CONDUCTANCE (EQN 51 IN MODFLOW MANUAL)

             VCONT(IC,IR)=2.0/(VK1+VK2)

 188        CONTINUE

 187       CONTINUE

          END IF

C

C---------CALCULATE VERTICAL CONDUCTANCE FOR UNIT WITH

C         PERMEABILITY SUBSTANTIALLY LESS THAN ADJACENT LAYER

C         NOTES :

C         1. USE EQUATION 53 FROM MODFLOW MANUAL FOR VCONT

C

          IF (IFLAG2.NE.IFLAG1) THEN

           DO 787 IR=1,NROW

            DO 788 IC=1,NCOL

C------------VERTICAL CONDUCTANCE (EQN 53 IN MODFLOW MANUAL)

             VCONT(IC,IR)=VPERM1(IC,IR)/XBB1

 788        CONTINUE

 787       CONTINUE

          END IF

         END IF

C

C--------CALCULATE VERTICAL CONDUCTANCE FOR SUPERIMPOSED 

C        ATMOSPHERIC UNIT

C

C        NOTES :

C        1. ONLY GENERATE VALUE FOR XVKSRF IF USER DID NOT ENTER

C           VALUE (IE. XVKSRF = 0.0)

C        2. IF NO VALUE FOR XVKSRF WAS SPECIFIED BY USER, THEN

C           SET XVKSRF = (100.0)(MAXIMUM VCONT VALUE CALCULATED

C                                IN SURFACE GEOLOGIC LAYER)

C        3. USE EQUATION 53 FROM MODFLOW MANUAL FOR VCONT IN 

C           ATMOSPHERIC LAYER

C

         IF (ICD.EQ.2) THEN

C---------TEST FOR USER ASSIGNED VALUE FOR VERTICAL PERMEABILITY

          IF (XVKSRF.GT.0.9E-20) THEN

           VSCONT1 = XVKSRF/BSURF

          END IF

          IF (XVKSRF.LT.0.9E-20) THEN

           XVKSRF1 = VPERM2(1,1)

           DO 776 IR=1,NROW

            DO 777 IC=1,NCOL

C------------DETERMINE MAXIMUM VALUE OF VPERM IN TOP GEOLOGIC LAYER

             XVKSRF2 = VPERM2(IC,IR)

             IF(XVKSRF2.GT.XVKSRF1) THEN

              XVKSRF1 = XVKSRF2

             END IF

 777        CONTINUE

 776       CONTINUE

           VSCONT1 = 100.0*XVKSRF1/BSURF

          END IF

C---------SET ALL VCONT VALUES IN ATMOSPHERIC LAYER TO SAME VALUE

          DO 778 IR=1,NROW

           DO 779 IC=1,NCOL

            VCONT(IC,IR)=VSCONT1

 779       CONTINUE

 778      CONTINUE

         END IF

C

C--------WRITE VERTICAL CONDUCTANCE FOR LAYER ICD-1 IN 3D SIMULATIONS

C

         WRITE(15,260) LOCAT1,CNST1,FMTIN1,IPRN1

C--------ASSIGN VERTICAL CONDUCTANCE TO EACH CELL IN LAYER FOR 3D SIMS

         DO 189 IR=1,NROW

          WRITE(15,330)(VCONT(IC,IR),IC=1,NCOL)

 189     CONTINUE

C

C16b-----IF RUN IS TRANSIENT READ IN AIR FILLED POROSITY

C         IN LAYER ICD

C

C        NOTES :

C        1. USE VCONT(NCOL,NROW) TO STORE AIR PHASE POROSITY

C            VALUES IN EACH CELL

C

C--------TEST TO SEE IF SIMULATION IS STEADY STATE (ISS = 1)

C         OR TRANSIENT (ISS = 0)

         IF (ISS.EQ.0) THEN

C

C---------DESCRIPTION OF INPUT FOR AIR PHASE POROSITY

C

          ANAME(1) = 'AIR '

          ANAME(2) = 'PHAS'

          ANAME(3) = 'E PO'

          ANAME(4) = 'ROSI'

          ANAME(5) = 'TY'

          ANAME(6) = ' '

C

C---------READ IN AIR PHASE POROSITY IN EACH CELL FOR LAYER ICD

C         NOTES :

C         1. VCONT(IC,IR) = AIR PHASE POROSITY IN EACH CELL

C

C

C---------READ IN POROSITY FOR LAYER ICD

C

          READ(12,400) LOCAT,CNSTNT,FMTIN

 400      FORMAT(I10,F20.0,5A4)

C

C---------IF LOCAT=0 THEN SET ALL ARRAY VALUES EQUAL TO CNSTNT

C

          IF (LOCAT.EQ.0) THEN

           DO 840 I=1,NROW

            DO 841 J=1,NCOL

             VCONT(J,I)=CNSTNT

 841        CONTINUE

 840       CONTINUE

          END IF

C

C---------IF LOCAT>0 THEN READ FORMATTED RECORDS USING FORMAT FMTIN

C

          IF ((LOCAT.GT.0).AND.(LOCAT.NE.12)) THEN

           INQUIRE (UNIT=LOCAT,OPENED=OP)

           IF (OP) GO TO 560

C----------SET FLAG TO TEXT INPUT (0) AND SPECIFY FILE NAME &

C          NUMBER IN SUBROUTINE FILEDF

           IFG = 0

           CALL FILEDF(LOCAT,ANAME,IFG)

          END IF

 560      CONTINUE

C---------INPUT AIR PHASE POROSITY DATA FROM REDEFINED FILE

          IF (LOCAT.GT.0) THEN

           DO 850 I=1,NROW

            READ(LOCAT,FMTIN) (VCONT(J,I),J=1,NCOL)

 850       CONTINUE

          END IF

C

C---------LOCAT<0 THEN READ UNFORMATTED RECORD CONTAINING ARRAY VALUES

C

          IF (LOCAT.LT.0) THEN

           LOCAT=-LOCAT

C

C----------TEST TO MAKE SURE UNIT NUMBER CONFORMS TO A BINARY FILE

C

           IF (LOCAT.EQ.12) THEN

 561        CONTINUE

            WRITE(IOUT,370)LOCAT

            WRITE(IOUT,371)

            WRITE(IOUT,372)

            READ(INBAS,373) LOCAT

            IF ((LOCAT.LT.20).OR.(LOCAT.GT.50)) GO TO 561

           END IF

           IF (LOCAT.NE.12) THEN

            INQUIRE (UNIT=LOCAT,OPENED=OP)

            IF (OP) GO TO 562

C-----------SET FLAG TO BINARY INPUT (1) AND SPECIFY FILE NAME &

C            NUMBER IN SUBROUTINE FILEDF

            IFG = 1

            CALL FILEDF(LOCAT,ANAME,IFG)

 562        CONTINUE

C-----------READ AN UNFORMATTED DUMMY RECORD FIRST

            READ(LOCAT)

C-----------READ AN UNFORMATTED POROSITY ARRAY FOR 3D SIMULATIONS

            READ(LOCAT) VCONT

           END IF

          END IF

C

C---------IF CNSTNT NOT ZERO THEN MULTIPLY ARRAY VALUES BY CNSTNT

C

          IF (((CNSTNT.GT.1.0E-20).OR.(CNSTNT.LT.-1.0E-20)).AND.

     1        (LOCAT.NE.0)) THEN

           DO 851 I=1,NROW

            DO 852 J=1,NCOL

             VCONT(J,I)=VCONT(J,I)*CNSTNT

 852        CONTINUE

 851       CONTINUE

          END IF

C

C17b------GENERATE PNEUMATIC EQUIVALENT OF STORAGE COEFFICIENT

C

          DO 191 IR=1,NROW

           DO 192 IC=1,NCOL

            SF1(IC,IR)=(VCONT(IC,IR)*XBB2*VA)/STDATM

 192       CONTINUE

 191      CONTINUE

C---------WRITE OUT STORAGE COEFFICIENT FOR LAYER ICD FOR 3D SIMS

          WRITE(15,260) LOCAT1,CNST1,FMTIN1,IPRN1

          DO 193 IR=1,NROW

           WRITE(15,330)(SF1(IC,IR),IC=1,NCOL)

 193      CONTINUE

         END IF

C

C18b------DESCRIPTION OF INPUT FOR HORIZONTAL PERMEABILITY

C

          ANAME(1) = 'HORI'

          ANAME(2) = 'ZONT'

          ANAME(3) = 'AL P'

          ANAME(4) = 'ERME'

          ANAME(5) = 'ABIL'

          ANAME(6) = 'ITY'

C

C--------READ HORIZONTAL PERMEABILITY OF EACH CELL IN LAYER ICD

C

C

C--------READ IN HORIZONTAL PERMEABILITY FOR LAYER ICD

C

         READ(12,410) LOCAT,CNSTNT,FMTIN

 410     FORMAT(I10,F20.0,5A4)

C

C--------IF LOCAT=0 THEN SET ALL ARRAY VALUES EQUAL TO CNSTNT

C

         IF (LOCAT.EQ.0) THEN

          DO 860 I=1,NROW

           DO 861 J=1,NCOL

            XPERM(J,I)=CNSTNT

 861       CONTINUE

 860      CONTINUE

         END IF

C

C--------IF LOCAT>0 THEN READ FORMATTED RECORDS USING FORMAT FMTIN

C

         IF ((LOCAT.GT.0).AND.(LOCAT.NE.12)) THEN

          INQUIRE (UNIT=LOCAT,OPENED=OP)

          IF (OP) GO TO 570

C---------SET FLAG TO TEXT INPUT (0) AND SPECIFY FILE NAME &

C         NUMBER IN SUBROUTINE FILEDF

          IFG = 0

          CALL FILEDF(LOCAT,ANAME,IFG)

         END IF

 570     CONTINUE

C--------INPUT HORIZONTAL PERMEABILITY DATA FROM REDEFINED FILE

         IF (LOCAT.GT.0) THEN

          DO 870 I=1,NROW

           READ(LOCAT,FMTIN) (XPERM(J,I),J=1,NCOL)

 870      CONTINUE

         END IF

C

C--------LOCAT<0 THEN READ UNFORMATTED RECORD CONTAINING ARRAY VALUES

C

         IF (LOCAT.LT.0) THEN

          LOCAT=-LOCAT

C

C---------TEST TO MAKE SURE UNIT NUMBER CONFORMS TO A BINARY FILE

C

          IF (LOCAT.EQ.12) THEN

 571       CONTINUE

           WRITE(IOUT,370)LOCAT

           WRITE(IOUT,371)

           WRITE(IOUT,372)

           READ(INBAS,373) LOCAT

           IF ((LOCAT.LT.20).OR.(LOCAT.GT.50)) GO TO 571

          END IF

          IF (LOCAT.NE.12) THEN

           INQUIRE (UNIT=LOCAT,OPENED=OP)

           IF (OP) GO TO 572

C----------SET FLAG TO BINARY INPUT (1) AND SPECIFY FILE NAME &

C           NUMBER IN SUBROUTINE FILEDF

           IFG = 1

           CALL FILEDF(LOCAT,ANAME,IFG)

 572       CONTINUE

C----------READ AN UNFORMATTED DUMMY RECORD FIRST

           READ(LOCAT)

C----------READ AN UNFORMATTED HORIZ PERMEABILITY ARRAY FOR 3D SIMS

           READ(LOCAT) XPERM

          END IF

         END IF

C

C--------IF CNSTNT NOT ZERO THEN MULTIPLY ARRAY VALUES BY CNSTNT

C

         IF (((CNSTNT.GT.1.0E-20).OR.(CNSTNT.LT.-1.0E-20)).AND.

     1       (LOCAT.NE.0)) THEN

          DO 871 I=1,NROW

           DO 872 J=1,NCOL

            XPERM(J,I)=XPERM(J,I)*CNSTNT

 872       CONTINUE

 871      CONTINUE

         END IF

C--------UNIT CONVERTION

         DO 873 I=1,NROW

          DO 874 J=1,NCOL

           XPERM(J,I)=XPERM(J,I)/XU2(7,IU1(7))

 874      CONTINUE

 873     CONTINUE

C

C19b-----PNEUMATIC EQUIVALENT OF TRANSMISSIVITY

C

C        NOTES :

C        1. SINCE HYDRAULIC CONDUCTIVITY IS REPLACED WITH

C            PERMEABILITY IN PNEUMATIC SIMULATIONS, THE

C            EQUIVALENT TRANSMISSIVITY TERM IN AIR FLOW MODELS

C            IS GIVEN AS THE PRODUCT OF PERMEABILITY AND CELL

C            DEPTH.

C

         DO 196 IR=1,NROW

          DO 197 IC=1,NCOL

           TRAN(IC,IR)=XPERM(IC,IR)*XBB2

 197      CONTINUE

 196     CONTINUE

C--------WRITE OUT TRANSMISSIVITY FOR AIR FLOW FOR LAYER ICD FOR 3D SIMS

         WRITE(15,260) LOCAT1,CNST1,FMTIN1,IPRN1

         DO 198 IR=1,NROW

          WRITE(15,330)(TRAN(IC,IR),IC=1,NCOL)

 198     CONTINUE

        END IF

 175   CONTINUE

      END IF

C

C20b--OUTPUT WELL / TRENCH INFO TO MODEL.DAT FILE

C

      DO 880 IW=1,NWELL

       SHWELL=SQRT(SHW(IW))*XU2(4,IU1(4))/STDATM

       WRITE(19,890)IWELL(IW,1),IWELL(IW,2),IWELL(IW,3),IWELL(IW,4),

     1    IWELL(IW,5),IWELL(IW,6),IWELL(IW,7),SHWELL

 880  CONTINUE

      DO 881 IT=1,NTRCH

       SHTRCH=SQRT(TSHD(IT))*XU2(4,IU1(4))/STDATM

       WRITE(19,890)ITRCH(IT,1),ITRCH(IT,2),ITRCH(IT,3),ITRCH(IT,4),

     1    ITRCH(IT,5),ITRCH(IT,6),ITRCH(IT,7),SHTRCH

 881  CONTINUE

 890  FORMAT(7I5,E20.8)

C

C-----RETURN

C

      RETURN

      END

C

C     *****************

      SUBROUTINE AIREND

C     *****************

C

C1----NOTES :

C

C     1. USE THIS ROUTINE TO WRITE ENDING MESSAGE TO USER

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(20)

      CHARACTER*12 FNAME

C-----INITIALIZE VARIABLES

      IOUT = IV(82)

C

C3----MESSAGE TO USER

C

      WRITE(IOUT,201)

      WRITE(IOUT,202)

      WRITE(IOUT,203)

      IF(IOUT.EQ.6) THEN

       WRITE(IOUT,204)

       WRITE(IOUT,205)

      END IF

      IF(IOUT.EQ.6) THEN

       WRITE(IOUT,206)

      END IF

      WRITE(IOUT,207)

      WRITE(IOUT,208)

      WRITE(IOUT,209)FNAME(11)

      WRITE(IOUT,210)

 201  FORMAT(////////////////////////,T20,'PREAIR - AN AIRFLOW',

     1   ' PREPROCESSOR (Ver 1.1)')

 202  FORMAT(T20,'======   == ======= ============')

 203  FORMAT(//,T10,'PREAIR has successfully set up the MODFLOW',

     1       ' data files.')

 204  FORMAT(//,T10,'Next run MODFLOW, Enter :')

 205  FORMAT(/,T10,'MODFLOW < INFILE.MOD')

 206  FORMAT(//,T10,'Next run MODFLOW')

 207  FORMAT(//,T10,'When complete, run POSTAIR, Enter :')

 208  FORMAT(/,T10,'POSTAIR')

 209  FORMAT(//,T10,'Then use file ',A12,' to input or modify ',

     1       'POSTAIR data.')

 210  FORMAT(//)

C

C4----END

C

      RETURN

      END

C

C     *****************

      SUBROUTINE FILEDF(LOCAT,ANAME,IFLAG)

C     *****************

C

C1----NOTES :

C

C     1. FILEDF IS USED TO DEFINE INPUT FILE UNIT NUMBERS

C         AND NAMES

C     2. VARIABLES :

C         LOCAT   IS THE USER DEFINED UNIT NUMBER FOR THE

C                 INPUT FILE

C         ANAME   IS 24 CHARACTER DESCRIPTION OF THE INPUT

C                 FILE CONTENTS

C         FNAME   IS THE NAME OF INFILEx.PRE

C         INBAS   IS UNIT NUMBER FOR READING INPUT FROM SCREEN

C         IOUT    IS UNIT NUMBER FOR WRITING OUTPUT TO THE SCREEN

C         IFLAG   IS USED TO DISTINGUISH BETWEEN TEXT (0) AND

C                 BINARY (1) INPUT DATA

C

C2----SPECIFICATIONS:

C

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(20)

      DIMENSION ANAME(6)

      CHARACTER*12 FNAME,RELFIL,ANAME*4

C-----INITIALIZE VARIABLES

      INBAS= IV(81)

      IOUT = IV(82)

C

C3----CHECK NEW UNIT NUMBER DOES NOT CONFLICT WITH PROGRAM

C      SETTINGS

C

 500  CONTINUE

      IF ((LOCAT.LT.25).OR.(LOCAT.GT.50)) THEN

       WRITE(IOUT,190)FNAME(2)

       WRITE(IOUT,191)LOCAT

       WRITE(IOUT,192)

       WRITE(IOUT,193)

       WRITE(IOUT,194)FNAME(2)

       WRITE(IOUT,201)

       WRITE(IOUT,202)

       WRITE(IOUT,203)FNAME(2)

       WRITE(IOUT,204)

       READ(INBAS,205)ITM2

       IF (ITM2.NE.1) STOP

 190   FORMAT(////////,T10,'WHILE ENTERING DATA FROM THE FILE ',A12)

 191   FORMAT(/,T10,'AN EXTERNAL INPUT FILE WAS REFERNCED (IE. ',

     1        'UNIT ',I2,')')

 192   FORMAT(/,T10,'UNIT NUMBER FOR EXTERNAL DATA INPUT ',

     1  'MUST LIE BETWEEN 25 & 50')

 193   FORMAT(/,T10,'ALTERNATIVELY SPECIFY A UNIT NO.= 12')

 194   FORMAT(/,T10,'TO ENTER ALL DATA FROM THE FILE ',A12)

 201   FORMAT(/,T10,'SELECT  :')

 202   FORMAT(/,T10,'1   TO REDEFINE UNIT NUMBER')

 203   FORMAT(/,T10,'2   TO END PROGRAM AND EDIT ',A12)

 204   FORMAT(//,T10,'PLEASE ENTER   1  OR  2  : ')

 205   FORMAT(I2)

C

C4-----INPUT NEW UNIT NUMBER

C

       WRITE(IOUT,210)

       READ(INBAS,211)LOCAT

 210   FORMAT(//,T10,'PLEASE ENTER NEW UNIT NUMBER  : ')

 211   FORMAT(I2)

       IF ((LOCAT.LT.25).OR.(LOCAT.GT.50)) GO TO 500

      END IF

C

C5----INPUT NEW UNIT NAME AND OPEN TEXT FILE 

C

      IF (IFLAG.NE.1) THEN

       WRITE(IOUT,220) ANAME,LOCAT

 220   FORMAT(/////////,T10,'ENTER THE FILE NAME FOR THE ',

     1  6A4,'TEXT UNIT ',I2,': ')

       READ(INBAS,221) RELFIL

 221   FORMAT(A12)

       OPEN(UNIT=LOCAT,FILE=RELFIL,ACCESS='SEQUENTIAL',

     1  STATUS='OLD')

      END IF

C

C6----INPUT NEW UNIT NAME AND OPEN BINARY FILE 

C

      IF (IFLAG.EQ.1) THEN

       WRITE(IOUT,230) ANAME,LOCAT

 230   FORMAT(/////////,T10,'ENTER THE FILE NAME FOR THE ',

     1  6A4,'BINARY UNIT ',I2,': ')

       READ(INBAS,231) RELFIL

 231   FORMAT(A12)

       OPEN(UNIT=LOCAT,FILE=RELFIL,ACCESS='SEQUENTIAL',

     1  FORM='UNFORMATTED',STATUS='OLD')

      END IF

C

C7----RETURN

C

      RETURN

      END

C

C     ****************

      SUBROUTINE RCORD(A,XC1,XL1,XR1,NC,NCOL)

C     ****************

C

C1----NOTES :

C     1. ROUTINE TO DETERMINE X- AND Y- COORDINATES 

C         CORRESPONDING TO THE CENTER AND/OR FACE OF A

C         SPECIFIED NODE

C     2. THE SUBROUTINE ASSUMES THE FOLLOWING ORIENTATION :

C         - ORIGIN COINCIDES WITH REAR, LEFT HAND CORNER

C

C                     SPATIAL          NODAL

C                           X

C                  O----------     1,1    1,2   1,3...

C                  |               2,1    2,2   2,3...

C                  |               3,1    3,2   3,3...

C                 Y|               4,1    4,2   4,3...

C

C     3. ARRAYS ARE AS FOLLOWS :

C        A IS ARRAY STORING CELL WIDTH ALONG ROWS (DELR)

C          IE. WIDTH OF CELL IN X-DIRECTION

C     4. VARIABLES :

C        XC1 = X-COORDINATE AT CENTER OF NODE NC

C        XL1 = X-COORDINATE AT LEFT FACE OF NODE NC

C        XR1 = X-COORDINATE AT RIGHT FACE OF NODE NC

C        XW1 = X-COORDINATE AT WELL FACE OF NODE NC

C        NR  = ROW NUMBER (IE. IN Y-DIRECTION)

C        NC  = COLUMN NUMBER (IE. IN X-DIRECTION)

C        IV(2) = NCOL  = NUMBER OF COLUMNS

C

C2----SPECIFICATIONS :

C

      COMMON/IVALUE/IV(100)

      DIMENSION A(NCOL)

C-----ASSIGN VARIABLES

      IOUT =IV(82)

C

C3----CHECK NODE POSITION WITHIN DOMAIN

C

C-----CHECK SPECIFIED NODE DOES NOT EXCEED NCOLS

C

      IF(NC.GT.IV(2))THEN

       WRITE(IOUT,100)NC,IV(2)

       STOP

      END IF

 100  FORMAT(/////,T10,'NODE',I3,'EXCEEDS NCOLS IE.',I3)

C

C4----DETERMINE X-COORDINATE AT CENTER OF CELL (NR,NC)

C

C     NOTES :

C     1. THIS ALGORITHM GENERATES THE DISTANCE FROM THE 

C         LEFT HAND EDGE OF THE MODEL DOMAIN TO THE CENTER

C         OF A NODE LYING WITHIN A SPECIFIED COLUMN.

C         IE DISTANCE ALONG ROW IN X-DIRECTION. THIS IS ALSO THE

C         RADIAL DISTANCE.

C     2. NR DEFAULTS TO 2 FOR ALL 2D RADIAL SIMULATIONS BECAUSE 

C         THERE WILL ALWAYS BE 3 ROWS PRESENT.

C

C-----SUM CELL WIDTHS ALONG ROWS

C

      XC1 = 0.0

      L1M = NC-1

      DO 20 I = 1,L1M

       XC1 = XC1 + A(I)

 20   CONTINUE

      XC1 = XC1 + A(NC)/2.0

C

C5----DETERMINE X-COORDINATE AT LEFT FACE OF CELL (NR,NC)

C

      XL1 = XC1 - A(NC)/2.0

C

C6----DETERMINE X-COORDINATE AT RIGHT FACE OF CELL (NR,NC)

C

      XR1 = XC1 + A(NC)/2.0

C

      RETURN

      END

 