C     ********************************************

C     POST PROCESSOR FOR PROCESSING MODFLOW OUTPUT

C     ==== ========= === ========== ======= ======

C

C     DEVELOPED BY - CRAIG J. JOSS   (1991)

C                    P.O. BOX 943

C                    BALA CYNWYD, PA 19004

C

C                  - ARTHUR L. BAEHR (1991)

C                    USGS, 810 BEAR TAVERN RD.

C                    WEST TRENTON, NJ 08628

C

C     ********************************************

C

C1----VERSION 1.1  06JUL1994

C

C     PROGRAM NAME ON PERSONAL COMPUTER : POSTAIR.FOR

C                  ON MAIN FRAME        : POSTAIR.F77

C

C     DATE OF LAST REVISION             : 07/06/94

C

C2----NOTES  :

C

C     1. THIS PROGRAM HAS A NUMBER OF FEATURES INCLUDING  :

C        A. ACCESSING HEAD AND FLOW DATA FROM HYDRAULIC AND

C            PNEUMATIC SIMULATIONS;

C        B. PROCESSING OUTPUT INFORMATION FROM HYDRAULIC AND

C            PNEUMATIC SIMULATIONS;

C        C. OUTPUTING INFORMATION TO USER SPECIFIED FILES FOR

C            FURTHER ANALYSIS

C

C     2. INPUT DATA FILES NEEDED TO IMPLEMENT POST PROCESSOR

C

C        -  MODFLOW INPUT FILES (BASIC, BCF, AND OC FILES)

C        -  BINARY OUTPUT FILES (HEAD, DRAWDOWN AND/OR FLOW

C            OUTPUT)

C        -  OUTPUT FILES FROM THE PREPROCESSOR RECORDING MODEL

C            INFORMATION

C

C3----SPECIFICATIONS:

C

      PARAMETER(LENX=1000000,LENI=100000)

      COMMON XX(LENX),IX(LENI),AX(50)

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(25)

      COMMON/KVALUE/KN(10)

      CHARACTER FNAME*12,AX*4,KN*1,IU3*6

C-----INITIALIZE VARIABLES

      DO 101 I = 1,100

       IV(I) = 0

 101  CONTINUE

      DO 102 I=1,25

       FNAME(I)  = ' '

 102  CONTINUE

C

C4----ASSIGN INPUT UNIT AND PRINTER UNIT

C

C     SET  :  IV(81) = INBAS = 5 WHEN USING IBM PC OR MAC

C     SET  :  IV(81) = INBAS = 1 WHEN USING MAIN FRAME

C

C     SET  :  IV(82) = IOUT  = 6 WHEN USING IBM PC OR MAC

C     SET  :  IV(82) = IOUT  = 1 WHEN USING MAIN FRAME

C

      INBAS = 5

      IOUT  = 6

C-----SAVE DATA

      IV(81) = INBAS

      IV(82) = IOUT

      IV(83) = LENX

      IV(84) = LENI

C

C5----SETUP PROBLEM

C

      CALL SETUP(AX(1),AX(33),AX(37))

C

C6----TEST FILE SETTINGS AND AVAILABLE MEMORY IN POST ARRAYS

C

      CALL STOR(XX(1),IX(1),AX(41))

C

C7----READ IN BINARY HEAD, TRANSFORM, OUTPUT TO TEXT OR BINARY FILES

C

      CALL PRES(XX(1),XX(IV(25)),XX(IV(26)),XX(IV(27)),XX(IV(28)),

     1 XX(IV(29)),IX(1),IX(IV(54)),AX(33),IV(1),IV(2),IV(3),IV(95),

     2 IV(96),DATUM,TAIR,CLEN)

C

C8----READ IN BINARY FLOW, TRANSFORM, OUTPUT TO TEXT OR BINARY FILES

C

      IF(IV(38).EQ.2) THEN

C      FOR TEXT FLOW OUTPUT FILES

       IQC=1

C      FOR BINARY FLOW OUTPUT FILES

       IF(IV(41).LT.0)IQC=2

       DO 120 IQ1=1,IQC

        CALL AFLOW(XX(1),XX(IV(26)),XX(IV(27)),XX(IV(28)),

     1   XX(IV(29)),XX(IV(50)),XX(IV(51)),IX(IV(54)),AX(33),

     2   AX(37),IV(1),IV(2),IV(3),IV(11),IV(12),IV(13),IV(14),

     3   IV(15),IV(16),IV(95),IV(96),DATUM,TAIR,IQ1,CLEN)

 120   CONTINUE

      END IF

C

C9----READ IN TEXT FLOW, COMBINE, OUTPUT 2D RESULTANT FLOW TEXT FILES

C

      IF((IV(38).EQ.2).AND.(IV(41).EQ.3)) THEN

       CALL R2FLOW(XX(IV(26)),XX(IV(27)),XX(IV(28)),XX(IV(29)),

     1      XX(IV(55)),IX(1),IV(1),IV(2),IV(3),IV(11),IV(12),IV(94))

      END IF

C

C10---READ IN TEXT FLOW, COMBINE, OUTPUT 3D RESULTANT FLOW TEXT FILES

C

      IF((IV(38).EQ.2).AND.(IV(41).EQ.4)) THEN

       DO 130 IQ1=1,2

        CALL R3FLOW(XX(IV(26)),XX(IV(27)),XX(IV(28)),XX(IV(29)),

     1   XX(IV(50)),XX(IV(56)),XX(IV(57)),AX(33),AX(37),IV(1),

     2   IV(2),IV(3),IV(17),IV(18),IV(19),DATUM,TAIR,IQ1,CLEN)

 130   CONTINUE

      END IF

C

C11---CALCULATE AND OUTPUT FLOW DIVERGENCE

C

      IF(IV(41).EQ.-1) THEN

       CALL DFLOW(XX(IV(26)),XX(IV(27)),XX(IV(28)),XX(IV(29)),

     1  XX(IV(50)),AX(37),IV(1),IV(2),IV(3),IV(11),IV(12),IV(13))

      END IF

C

C12---WRITE END MESSAGE TO USER

C

      CALL AIREND

C

C13---END

C

      STOP

      END

C

C     ****************

      SUBROUTINE SETUP(HEADING,TEXTH,TEXTF)

C     ****************

C

C1----NOTES :

C

C     1. USE THIS ROUTINE TO SETUP MODEL AND ENTER FILE NAMES

C

C2----SPECIFICATIONS :

C

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(25)

      COMMON/KVALUE/KN(10)

      DIMENSION HEADING(32),TEXTH(4),TEXTF(4)

      CHARACTER FNAME*12,IU3*6,HEADING*4,TEXTH*4,TEXTF*4,KN*1

C-----ASSIGN VARIABLES

      INBAS=IV(81)

      IOUT =IV(82)

      KN(1) ='1'

      KN(2) ='2'

      KN(3) ='3'

      KN(4) ='4'

      KN(5) ='5'

      KN(6) ='6'

      KN(7) ='7'

      KN(8) ='8'

      KN(9) ='9'

      KN(10)='0'

C

C3----SET UP UNIT ARRAYS

C

C     NOTES :

C     1. IU1() STORES UNIT SYSTEM SELECTED BY USER

C        IU1(1)  -  FOR LENGTH UNIT SYSTEM

C        IU1(2)  -  FOR VOLUME UNIT SYSTEM

C        IU1(3)  -  FOR TIME UNIT SYSTEM

C        IU1(4)  -  FOR PRESSURE UNIT SYSTEM

C        IU1(5)  -  FOR TEMPERATURE UNIT SYSTEM

C        IU1(6)  -  FOR MASS UNIT SYSTEM

C        IU1(7)  -  FOR PERMEABILITY UNIT SYSTEM

C

C     2. XU2() STORES UNIT CONVERTIONS

C        XU2(1,1) - XU2(1,10) :  FOR LENGTH UNITS

C        XU2(2,1) - XU2(2,10) :  FOR VOLUME UNITS

C        XU2(3,1) - XU2(3,10) :  FOR TIME UNITS 

C        XU2(4,1) - XU2(4,10) :  FOR PRESSURE UNITS

C        XU2(5,1) - XU2(5,10) :  FOR TEMPERATURE UNITS

C        XU2(6,1) - XU2(6,10) :  FOR MASS UNITS

C        XU2(7,1) - XU2(7,10) :  FOR PERMEABILITY UNITS

C

C     3. IU3() STORES UNIT DESCRIPTIONS

C        IU3(1,1) - IU3(1,10) :  FOR LENGTH UNITS

C        IU3(2,1) - IU3(2,10) :  FOR VOLUME UNITS

C        IU3(3,1) - IU3(3,10) :  FOR TIME UNITS 

C        IU3(4,1) - IU3(4,10) :  FOR PRESSURE UNITS

C        IU3(5,1) - IU3(5,10) :  FOR TEMPERATURE UNITS

C        IU3(6,1) - IU3(6,10) :  FOR MASS UNITS

C        IU3(7,1) - IU3(7,10) :  FOR PERMEABILITY UNITS

C

C3a---DEFAULT ARRAYS TO BLANK FIELDS

C

      DO 105 I=1,7

       IU1(I)=0

 105  CONTINUE

      DO 106 I=1,7

       DO 107 J =1,10

        XU2(I,J)=0.0

        IU3(I,J)='    '

 107   CONTINUE

 106  CONTINUE

C

C-----SPECIFY CONVERTION FACTORS IN ARRAY XU2(I,J)

C

C-----SPECIFY LENGTH CONVERTION FACTORS IN ARRAY XU2(1,x)

C

C-----CM TO CM, DIVIDE INPUT BY XU2(1,1)

      XU2(1,1) = 1.0

C-----DM TO CM, DIVIDE INPUT BY XU2(1,2)

      XU2(1,2) = 1.0E-01

C-----M TO CM, DIVIDE INPUT BY XU2(1,3)

      XU2(1,3) = 1.0E-02

C-----IN TO CM, DIVIDE INPUT BY XU2(1,4)

      XU2(1,4) = 3.937E-01

C-----FT TO CM, DIVIDE INPUT BY XU2(1,5)

      XU2(1,5) = 3.281E-02

C-----YD TO CM, DIVIDE INPUT BY XU2(1,5)

      XU2(1,6) = 1.0936E-02

C

C-----SPECIFY VOLUME CONVERTION FACTORS IN ARRAY XU2(2,x)

C

C-----CM^3 TO CM^3, DIVIDE INPUT BY XU2(2,1)

      XU2(2,1) = 1.0

C-----LITERS TO CM^3, DIVIDE INPUT BY XU2(2,2)

      XU2(2,2) = 1.0E-03

C-----M^3 TO CM^3, DIVIDE INPUT BY XU2(2,3)

      XU2(2,3) = 1.0E-06

C-----IN^3 TO CM^3, DIVIDE INPUT BY XU2(2,4)

      XU2(2,4) = 6.1024E-02

C-----FT^3 TO CM^3, DIVIDE INPUT BY XU2(2,5)

      XU2(2,5) = 3.5315E-05

C-----YD^3 TO CM^3, DIVIDE INPUT BY XU2(2,6)

      XU2(2,6) = 1.3080E-06

C-----GAL TO CM^3, DIVIDE INPUT BY XU2(2,7)

      XU2(2,7) = 2.6417E-04

C

C-----SPECIFY TIME CONVERTION FACTORS IN ARRAY XU2(3,x)

C

C-----SECONDS TO SECONDS, DIVIDE INPUT BY XU2(3,1)

      XU2(3,1) = 1.0

C-----MINUTES TO SECONDS, DIVIDE INPUT BY XU2(3,2)

      XU2(3,2) = 1.6667E-02

C-----HOURS TO SECONDS, DIVIDE INPUT BY XU2(3,3)

      XU2(3,3) = 2.7778E-04

C-----DAYS TO SECONDS, DIVIDE INPUT BY XU2(3,4)

      XU2(3,4) = 1.1574E-05

C-----YEARS TO SECONDS, DIVIDE INPUT BY XU2(3,5)

      XU2(3,5) = 3.1688E-08

C

C-----SPECIFY PRESSURE CONVERTION FACTORS IN ARRAY XU2(4,x)

C

C-----ATMOSPHERES TO ATMOSPHERES, DIVIDE INPUT BY XU2(4,1)

      XU2(4,1) = 1.0

C-----MM MERCURY TO ATMOSPHERES, DIVIDE INPUT BY XU2(4,2)

      XU2(4,2) = 760.0

C-----INCHES OF WATER TO ATMOSPHERES, DIVIDE INPUT BY XU2(4,3)

      XU2(4,3) = 406.38

C-----KILOPASCALS TO ATMOSPHERES, DIVIDE INPUT BY XU2(4,4)

      XU2(4,4) = 101.325

C-----POUNDS PER SQ INCH TO ATMOSPHERES, DIVIDE INPUT BY XU2(4,5)

      XU2(4,5) = 14.70

C

C-----SPECIFY TEMPERTURE CONVERTION FACTORS IN ARRAY XU2(5,x)

C

C-----DEGREES CELSIUS TO DEGREES CELSIUS, SUBRACT XU2(5,1) FROM INPUT

      XU2(5,1) = 0.0

C       AND DIVIDE BY XU2(5,6)

      XU2(5,6) = 1.0

C-----KELVIN TO DEGREES CELSIUS, SUBTRACT XU2(5,2) FROM INPUT

      XU2(5,2) = 273.15

C       AND DIVIDE BY XU2(5,7)

      XU2(5,7) = 1.0

C-----DEGREES FAHRENHEIT TO DEGREES CELSIUS, SUBTRACT XU2(5,3)

      XU2(5,3) = 32.0

C       AND DIVIDE BY XU2(5,8)

      XU2(5,8) = 1.8

C

C-----SPECIFY MASS CONVERTION FACTORS IN ARRAY XU2(6,x)

C

C-----GRAMS TO GRAMS, DIVIDE INPUT BY XU2(6,1)

      XU2(6,1) = 1.0

C-----KILOGRAMS TO GRAMS, DIVIDE INPUT BY XU2(6,2)

      XU2(6,2) = 1.0E-03

C-----POUNDS TO GRAMS, DIVIDE INPUT BY XU2(6,3)

      XU2(6,3) = 2.2046E-03

C

C-----SPECIFY PERMEABILITY CONVERTION FACTORS IN ARRAY XU2(7,x)

C

C-----CM^2 TO CM^2, DIVIDE INPUT BY XU2(7,1)

      XU2(7,1) = 1.0

C-----DM^2 TO CM^3, DIVIDE INPUT BY XU2(7,2)

      XU2(7,2) = 1.0E-02

C-----M^2 TO CM^2, DIVIDE INPUT BY XU2(7,3)

      XU2(7,3) = 1.0E-04

C-----IN^2 TO CM^2, DIVIDE INPUT BY XU2(7,4)

      XU2(7,4) = 1.5500E-01

C-----FT^2 TO CM^2, DIVIDE INPUT BY XU2(7,5)

      XU2(7,5) = 1.0764E-03

C-----YD^2 TO CM^2, DIVIDE INPUT BY XU2(7,6)

      XU2(7,6) = 1.1960E-04

C-----DARCY TO CM^2, DIVIDE INPUT BY XU2(7,7)

      XU2(7,7) = 1.0E+08

C

C-----SPECIFY UNIT DESCRIPTIONS IN ARRAY IU3(I,J)

C

C-----SPECIFY LENGTH DESCRIPTIONS IN ARRAY IU3(1,x)

C

      IU3(1,1) = 'cm'

      IU3(1,2) = 'dm'

      IU3(1,3) = 'm'

      IU3(1,4) = 'in'

      IU3(1,5) = 'ft'

      IU3(1,6) = 'yd'

C

C-----SPECIFY VOLUME DESCRIPTIONS IN ARRAY IU3(2,x)

C

      IU3(2,1) = 'cm^3'

      IU3(2,2) = 'lit'

      IU3(2,3) = 'm^3'

      IU3(2,4) = 'in^3'

      IU3(2,5) = 'ft^3'

      IU3(2,6) = 'yd^3'

      IU3(2,7) = 'gal'

C

C-----SPECIFY TIME DESCRIPTIONS IN ARRAY IU3(3,x)

C

      IU3(3,1) = 'sec'

      IU3(3,2) = 'min'

      IU3(3,3) = 'hr'

      IU3(3,4) = 'day'

      IU3(3,5) = 'yr'

C

C-----SPECIFY PRESSURE DESCRIPTIONS IN ARRAY IU3(4,x)

C

      IU3(4,1) = 'atm'

      IU3(4,2) = 'mmHg'

      IU3(4,3) = '"H2O'

      IU3(4,4) = 'kPa'

      IU3(4,5) = 'psi'

C

C-----SPECIFY TEMPERTURE DESCRIPTIONS IN ARRAY IU3(5,x)

C

      IU3(5,1) = 'degC'

      IU3(5,2) = 'K'

      IU3(5,3) = 'degF'

C

C-----SPECIFY MASS DESCRIPTIONS IN ARRAY IU3(6,x)

C

      IU3(6,1) = ' g'

      IU3(6,2) = 'kg'

      IU3(6,3) = 'lb'

C

C-----SPECIFY PERMEABILITY DESCRIPTIONS IN ARRAY IU3(7,x)

C

      IU3(7,1) = 'cm^2'

      IU3(7,2) = 'dm^2'

      IU3(7,3) = 'm^2'

      IU3(7,4) = 'in^2'

      IU3(7,5) = 'ft^2'

      IU3(7,6) = 'yd^2'

      IU3(7,7) = 'drcy'

C

C4----DISPLAY HEADING

C

 600  CONTINUE

      WRITE(IOUT,201)

      WRITE(IOUT,202)

      WRITE(IOUT,203)

      WRITE(IOUT,204)

      WRITE(IOUT,205)

      WRITE(IOUT,206)

      WRITE(IOUT,207)

      WRITE(IOUT,208)

      WRITE(IOUT,209)

      WRITE(IOUT,210)

      READ(INBAS,211,IOSTAT=K1,ERR=600)IV(86)

C-----END PROGRAM

      IF(IV(86).EQ.4) THEN

       STOP

      END IF

C-----TEST USER INPUT

 601  CONTINUE

      IF((IV(86).NE.1).AND.(IV(86).NE.2).AND.(IV(86).NE.3)) THEN

       IV(86) = 0

       GO TO 600

      END IF

 201  FORMAT(////////////////////////,T20,'POSTAIR - AN AIRFLOW',

     1   ' POSTPROCESSOR (Ver 1.1)')

 202  FORMAT(T20,'=======   == ======= =============')

 203  FORMAT(//,T10,'DEVELOPED BY :  CRAIG J. JOSS')

 204  FORMAT(/,T26,'ARTHUR L. BAEHR')

 205  FORMAT(//,T10,'SELECT  :')

 206  FORMAT(/,T10,'1.  TO RUN POSTAIR USING AN EXISTING INPUT FILE')

 207  FORMAT(/,T10,'2.  TO MODIFY AN EXISTING INPUT FILE')

 208  FORMAT(/,T10,'3.  TO CREATE A NEW DATA INPUT FILE')

 209  FORMAT(//,T10,'4.  TO EXIT POSTAIR')

 210  FORMAT(//,T10,'PLEASE SELECT NUMBER  1, 2, 3  OR  4  :  ')

 211  FORMAT(I3)

C

C5----ENTER NAME OF INPUT FILE (EG INFILEx.POS)

C

C-----DIRECT ENTRY

      IF (IV(86).EQ.1) THEN

       IF(FNAME(11).EQ.' ') FNAME(18)='INFILE.POS'

       IF(FNAME(11).NE.' ') FNAME(18)=FNAME(11)

       WRITE(IOUT,201)

       WRITE(IOUT,202)

       WRITE(IOUT,221)FNAME(18)

       READ(INBAS,225)FNAME(18)

       IF(FNAME(18).NE.' ') FNAME(11)=FNAME(18)

       OPEN(UNIT=21,FILE=FNAME(11),STATUS='OLD')

       REWIND 21

      END IF

C-----MODIFY FILE

      IF (IV(86).EQ.2) THEN

       IF(FNAME(11).EQ.' ') FNAME(18)='INFILE.POS'

       IF(FNAME(11).NE.' ') FNAME(18)=FNAME(11)

       WRITE(IOUT,201)

       WRITE(IOUT,202)

       WRITE(IOUT,222)FNAME(18)

       READ(INBAS,225)FNAME(18)

       IF(FNAME(18).NE.' ') FNAME(11)=FNAME(18)

       OPEN(UNIT=21,FILE=FNAME(11),STATUS='UNKNOWN')

       REWIND 21

      END IF

C-----SET UP FILE

      IF (IV(86).EQ.3) THEN

       WRITE(IOUT,201)

       WRITE(IOUT,202)

       WRITE(IOUT,223)

       READ(INBAS,225)FNAME(11)

       OPEN(UNIT=21,FILE=FNAME(11),STATUS='UNKNOWN')

       REWIND 21

      END IF

 221  FORMAT(//////,T10,'PLEASE ENTER NAME OF INPUT FILE',

     1      '  EG ',A12,' :  ')

 222  FORMAT(//////,T10,'PLEASE ENTER NAME OF FILE TO MODIFY',

     1      '  EG ',A12,' :  ')

 223  FORMAT(//////,T10,'PLEASE ENTER NAME OF FILE TO SET UP',

     1      '  EG INFILE.POS   :  ')

 225  FORMAT(A12)

C

C6----ENTER INFILE.POS DATA DIRECTLY

C

C     VARIABLES :

C     IV(35) = FLAG FOR HYDRAULIC (1) OR PNEUMATIC (2) RUNS

C     IV(36) = FLAG RECORDING COORDINATE SYSTEM SELECTED (1,2,3)

C     IV(37) = FLAG TO INCLUDE (1) OR NEGLECT (2) COORD OFFSET

C     IV(38) = FLAG FOR PRESSURE (1) OR PRESSURE AND FLOW (2) ANAL

C     IV(39) = OUTPUT RESULTS BY LAYER (1), ROW (2) OR COLUMN (3)

C     IV(40) = IDENTIFICATION NUMBER CORRESPONDING TO SIMULATION

C     IV(41) = FLAG TO WRITE PRESSURE, VOLUMETRIC FLOW AND MASS

C               FLOW TO SINGLE TEXT FILES (1) (OR -1 FOR BINARY

C               FILES), OR, MULTIPLE TEXT FILES (2), OR, MULTIPLE

C               AND 2D RESULTANT TEXT FILES (3), OR, MULTIPLE AND

C               3D RESULTANT TEXT FILES (4)

C     IV(42) = FLAG TO GENERATE (1) OR SKIP (2) MASS BALANCE OUTPUT

C     IV(43) = FLAG FOR LAYER, ROW OR COLUMN OUTPUT TO BE GENERATED

C     IV(45) = FLAG PRES (1), HEAD (2), VOL FLOW (3), MASS FLOW (4)

C

 610  CONTINUE

      IF((IV(86).EQ.1).OR.(IV(86).EQ.2)) THEN

       READ(21,230,IOSTAT=K1,ERR=620,END=621)IV(35),IV(36),IV(37),

     1       IV(38),IV(39),IV(40),IV(41),IV(42),IV(43)

 230   FORMAT(8I2,I4)

C

C------CHECK AND CORRECT USER INPUT

C

C------DEFAULT ANALYSIS TO PNEUMATIC IF UNSPECIFIED

       IF (IV(35).NE.1) IV(35)=2

C------DEFAULT COORDINATE SYSTEM TO MODFLOW SETTINGS IF UNSPECIFIED

       IF ((IV(36).NE.2).AND.(IV(36).NE.3)) IV(36)=1

C------DEFAULT COORDINATE OFFSET TO BE INCLUDED IF UNSPECIFIED

       IF (IV(37).NE.2) IV(37)=1

C------DEFAULT ANALYSIS TO HEAD AND FLOW ANALYSIS IF UNSPECIFIED

       IF (IV(38).NE.1) IV(38)=2

C------DEFAULT OUTPUT TO STORING BY LAYERS IF UNSPECIFIED

       IF ((IV(39).NE.2).AND.(IV(39).NE.3)) IV(39)=1

C------DEFAULT SIMULATION NUMBER TO 1 IF UNSPECIFIED

       IF ((IV(40).LT.0).OR.(IV(40).GT.99)) IV(40)=1

C------DEFAULT TO NO RESULTANT VECTORS & SINGLE TEXT FILE OUTPUT

       IF ((IV(41).NE.-1).AND.(IV(41).NE.2).AND.(IV(41).NE.3)

     1   .AND.(IV(41).NE.4)) IV(41)=1

C------DEFAULT MASS BALANCE TO BE PERFORMED IF UNSPECIFIED

       IF (IV(42).NE.2) IV(42)=1

C------CORRECT LAYER NUMBER SELECTION FOR ATMOSPHERIC LAYER

       IF((IV(39).EQ.1).AND.(IV(35).EQ.2).AND.(IV(43).NE.0)) THEN

        IV(43) = IV(43)+1

       END IF

C

C------INPUT FILE NAMES SPECIFIED IN INFILEx.POS

C

C------SPECIFY NAME OF BASIC FILE USED IN MODFLOW SIMULATION

       READ(21,231,IOSTAT=K1,ERR=620,END=621)FNAME(3)

C------SPECIFY NAME OF OC FILE USED IN MODFLOW SIMULATION

       READ(21,231,IOSTAT=K1,ERR=620,END=621)FNAME(4)

C------SPECIFY NAME OF BCF FILE USED IN MODFLOW SIMULATION

       READ(21,231,IOSTAT=K1,ERR=620,END=621)FNAME(5)

C------SPECIFY NAME OF BINARY HEAD FILE OUTPUT FROM MODFLOW

       READ(21,231,IOSTAT=K1,ERR=620,END=621)FNAME(7)

C------SPECIFY NAME OF BINARY FLOW FILE OUTPUT FROM MODFLOW

       READ(21,231,IOSTAT=K1,ERR=620,END=621)FNAME(8)

C------SPECIFY NAME OF MODEL DATA FILE USED TO TRANSFER INFO

       READ(21,231,IOSTAT=K1,ERR=620,END=621)FNAME(9)

 231   FORMAT(A12)

C

C------SUBROUTINES CONTROLING ERRORS IN DATA INPUT

C

       IF(K1.EQ.0) GO TO 615

 620   CALL ERRMES(FNAME(11),IER1)

C------REINPUT DATA DIRECTLY USING DIFFERENT FILE NAME

       IF(IER1.EQ.1) GO TO 610

C------INPUT DATA INTERACTIVELY

       IF(IER1.EQ.2) IV(86)=2

       IF(IER1.EQ.2) GO TO 615

 621   CALL ENDMES(FNAME(11),IER1)

       IF(IER1.EQ.1) GO TO 610

       IF(IER1.EQ.2) IV(86)=2

       IF(IER1.EQ.2) GO TO 615

      END IF

C

C7----ENTER INFILE.POS DATA INTERACTIVEY

C

 615  CONTINUE

      IF((IV(86).EQ.2).OR.(IV(86).EQ.3)) THEN

C------SELECT HYDRAULIC (1) OR PNEUMATIC (2) SIMULATIONS

 630   CONTINUE

       IVAR = 2

       IF(IV(86).EQ.2) IVAR = IV(35)

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,253)

       WRITE(IOUT,243)

       WRITE(IOUT,244)

       WRITE(IOUT,245)

       WRITE(IOUT,246)

       IF(IV(86).EQ.2) WRITE(IOUT,247) IVAR

       IF(IV(86).EQ.3) WRITE(IOUT,248)

       READ(INBAS,250,IOSTAT=K1,ERR=630)IVAR

       IF(IVAR.EQ.3) THEN

        STOP

       END IF

       IF(((IV(86).EQ.2).AND.(IVAR.NE.0)).OR.(IV(86).EQ.3)) THEN

        IV(35)=IVAR

       END IF

C------TEST USER INPUT

       IF((IV(35).NE.1).AND.(IV(35).NE.2)) THEN

        IV(35) = 0

        GO TO 630

       END IF

 241   FORMAT(////////////////////////,T25,'POST PROCESSOR ',

     1  'APPLICATION MENU')

 242   FORMAT(T25,'==== ========= =========== ====')

 253   FORMAT(///,T10,'ENTER AIR FLOW OUTPUT OPTIONS')

 254   FORMAT(///,T10,'AIR FLOW OUTPUT OPTIONS ENTERED SUCCESSFULLY')

 255   FORMAT(/,T10,'NOW ENTER POST PROCESSOR INPUT / OUTPUT FILE ',

     1        'NAMES')

 243   FORMAT(//,T10,'SELECT  :')

 244   FORMAT(/,T10,'1.  FOR GROUND WATER SIMULATIONS')

 245   FORMAT(/,T10,'2.  FOR AIR FLOW SIMULATIONS')

 246   FORMAT(/,T10,'3.  TO END PROGRAM')

 247   FORMAT(//,T10,'PLEASE SELECT NUMBER 1, 2  OR  3 ',

     1       ' (EG',I2,')  :  ')

 248   FORMAT(//,T10,'PLEASE SELECT NUMBER 1, 2  OR  3  :  ')

 250   FORMAT(I2)

 251   FORMAT(I4)

C

C------SELECT COORDINATE SYSTEM (1,2,3) FOR USE

C

 640   CONTINUE

       IVAR = 1

       IF(IV(86).EQ.2) IVAR = IV(36)

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,260)

       WRITE(IOUT,261)

       WRITE(IOUT,262)

       WRITE(IOUT,263)

       IF(IV(86).EQ.2) WRITE(IOUT,264) IVAR

       IF(IV(86).EQ.3) WRITE(IOUT,265)

       READ(INBAS,250,IOSTAT=K1,ERR=640)IVAR

       IF(((IV(86).EQ.2).AND.(IVAR.NE.0)).OR.(IV(86).EQ.3)) THEN

        IV(36)=IVAR

       END IF

C------TEST USER INPUT

       IF((IV(36).NE.1).AND.(IV(36).NE.2).AND.(IV(36).NE.3)) THEN

        IV(36) = 0

        GO TO 640

       END IF

 260   FORMAT(////,T10,'SELECT  :')

 261   FORMAT(/,T10,'1.  FOR MODFLOW COORDINATES SYSTEM')

 262   FORMAT(/,T10,'2.  TO SHIFT SPATIAL ORIGIN')

 263   FORMAT(/,T10,'3.  TO SHIFT SPATIAL AND NODAL ORIGINS')

 264   FORMAT(//,T10,'PLEASE SELECT NUMBER 1, 2  OR  3 ',

     1       ' (EG',I2,')  :  ')

 265   FORMAT(//,T10,'PLEASE SELECT NUMBER  1,  2  OR  3  :  ')

C

C------SPECIFY WHETHER TO APPLY FLOW AT ACTIVE CELLS AT

C       CELL FACES (1) OR CELL CENTERS (2)

C

 650   CONTINUE

       IVAR = 1

       IF(IV(86).EQ.2) IVAR = IV(37)

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,270)

       WRITE(IOUT,271)

       WRITE(IOUT,272)

       IF(IV(86).EQ.2) WRITE(IOUT,273) IVAR

       IF(IV(86).EQ.3) WRITE(IOUT,274)

       READ(INBAS,250,IOSTAT=K1,ERR=650)IVAR

       IF(((IV(86).EQ.2).AND.(IVAR.NE.0)).OR.(IV(86).EQ.3)) THEN

        IV(37)=IVAR

       END IF

C------TEST USER INPUT

       IF((IV(37).NE.1).AND.(IV(37).NE.2)) THEN

        IV(37) = 0

        GO TO 650

       END IF

 270   FORMAT(////,T10,'SELECT  :')

 271   FORMAT(/,T10,'1.  FOR FLOW COORDINATES AT CELL FACES')

 272   FORMAT(/,T10,'2.  FOR FLOW COORDINATES AT CELL CENTERS')

 273   FORMAT(//,T10,'PLEASE SELECT NUMBER 1  OR  2 ',

     1       ' (EG',I2,')  :  ')

 274   FORMAT(//,T10,'PLEASE SELECT NUMBER  1  OR  2  :  ')

C

C------SELECT HEAD ONLY (1) OR HEAD AND FLOW (2) ANALYSIS

C

 660   CONTINUE

       IVAR = 2

       IF(IV(86).EQ.2) IVAR = IV(38)

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,280)

       IF(IV(35).EQ.1) THEN

        WRITE(IOUT,281)

        WRITE(IOUT,282)

       END IF 

       IF(IV(35).EQ.2) THEN

        WRITE(IOUT,283)

        WRITE(IOUT,284)

       END IF 

       IF(IV(86).EQ.2) WRITE(IOUT,285) IVAR

       IF(IV(86).EQ.3) WRITE(IOUT,286)

       READ(INBAS,250,IOSTAT=K1,ERR=660)IVAR

       IF(((IV(86).EQ.2).AND.(IVAR.NE.0)).OR.(IV(86).EQ.3)) THEN

        IV(38)=IVAR

       END IF

C------TEST USER INPUT

       IF((IV(38).NE.1).AND.(IV(38).NE.2)) THEN

        IV(38) = 0

        GO TO 660

       END IF

 280   FORMAT(////,T10,'SELECT  :')

 281   FORMAT(/,T10,'1.  TO PERFORM HEAD ANALYSIS ONLY')

 282   FORMAT(/,T10,'2.  TO PERFORM HEAD AND FLOW ANALYSIS')

 283   FORMAT(/,T10,'1.  TO PERFORM PRESSURE ANALYSIS ONLY')

 284   FORMAT(/,T10,'2.  TO PERFORM PRESSURE AND FLOW ANALYSIS')

 285   FORMAT(///,T10,'PLEASE SELECT NUMBER 1  OR  2 ',

     1       ' (EG',I2,')  :  ')

 286   FORMAT(///,T10,'PLEASE SELECT NUMBER  1  OR  2  :  ')

C

C------SPECIFY OUTPUT BY LAYER (1), ROW (2) OR COLUMN (3)

C

 670   CONTINUE

       IVAR = 1

       IF(IV(86).EQ.2) IVAR = IV(39)

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,290)

       WRITE(IOUT,291)

       WRITE(IOUT,292)

       WRITE(IOUT,293)

       IF(IV(86).EQ.2) WRITE(IOUT,294) IVAR

       IF(IV(86).EQ.3) WRITE(IOUT,295)

       READ(INBAS,250,IOSTAT=K1,ERR=670)IVAR

       IF(((IV(86).EQ.2).AND.(IVAR.NE.0)).OR.(IV(86).EQ.3)) THEN

        IV(39)=IVAR

       END IF

C------TEST USER INPUT

       IF((IV(39).NE.1).AND.(IV(39).NE.2).AND.(IV(39).NE.3)) THEN

        IV(39) = 0

        GO TO 670

       END IF

 290   FORMAT(////,T10,'SELECT  :')

 291   FORMAT(/,T10,'1.  TO OUTPUT DATA BY LAYER')

 292   FORMAT(/,T10,'2.  TO OUTPUT DATA BY ROW')

 293   FORMAT(/,T10,'3.  TO OUTPUT DATA BY COLUMN')

 294   FORMAT(//,T10,'PLEASE SELECT NUMBER 1, 2  OR  3 ',

     1       ' (EG',I2,')  :  ')

 295   FORMAT(//,T10,'PLEASE SELECT NUMBER  1, 2  OR  3  :  ')

C

C------SPECIFY SIMULATION ID NUMBER

C

 680   CONTINUE

       IVAR = 1

       IF(IV(86).EQ.2) IVAR = IV(40)

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,296)

       WRITE(IOUT,297)IABS(IVAR)

       READ(INBAS,250,IOSTAT=K1,ERR=680)IVAR

       IF(((IV(86).EQ.2).AND.(IVAR.NE.0)).OR.(IV(86).EQ.3)) THEN

        IV(40)=IVAR

       END IF

C------TEST USER INPUT

       IF(IV(40).LE.0) THEN

        IV(40) = 0

        GO TO 680

       END IF

 296   FORMAT(///////,T10,'PLEASE SPECIFY  :')

 297   FORMAT(//,T10,'SIMULATION ID NUMBER  (EG ',I2,')  :  ')

C

C------SPECIFY WHETHER TO WRITE OUTPUT TO SINGLE FILES OR

C      TO MULTIPLE FILES OR TO MULTIPLE AND RESULTANT FILES

C

C      NOTES :

C      1.  STORE SELECTION IN VARIABLE IV(41)

C      2a. FOR IV(41)=1, THREE TEXT FILES ARE GENERATED, AS FOLLOWS :

C           - ONE HEAD/PRESSURE FILE

C           - ONE VOLUMETRIC FLOW FILE (FOR IV(38)=2)

C           - ONE MASS FLOW FILE       (FOR IV(38)=2 AND IV(35)=2)

C      2b. FOR IV(41)=-1, THE OUTPUT IN 2a ABOVE IS GENERATED IN

C           A BINARY FORMAT

C           ALSO, A FILE IS GENERATED WITH DIV(Q) OUTPUT

C      3a. FOR IV(41)=2, OUTPUT CONTAINED IN THE ABOVE THREE FILES

C           IS ORGANIZED INTO 2-D SECTIONS BY LAYER, ROW OR COLUMN

C           DEPENDING ON THE SPECIFICATION OF IV(39), WITH DATA FOR 

C           EACH SECTION WRITTEN TO A SEPARATE FILE (MULTIPLE FILES)

C      3b. BINARY OPTION IV(41)=-2 IS NOT AVAILABLE AT CURRENT TIME

C      4a. FOR IV(41)=3, THE OUTPUT IN 2 ABOVE IS GENERATED AND IS

C           THEN COMBINED TO GIVE RESULTANT 2-D FLOW VECTORS

C      4b. BINARY OPTION IV(41)=-3, IS NOT AVAILABLE AT CURRENT TIME

C      5a. FOR IV(41)=4, THE OUTPUT IN 2 ABOVE IS GENERATED AND IS

C           THEN COMBINED TO GIVE RESULTANT 3-D FLOW VECTORS

C           NOTE, CONSIDERABLE VIRTUAL MEMORY IS REQUIRED FOR THIS OPTION

C      5b. BINARY OPTION IV(41)=-4, IS NOT AVAILABLE AT CURRENT TIME

C

 690   CONTINUE

       IVAR = 1

       IF(IV(86).EQ.2) IVAR = IV(41)

C------TEST FOR HEAD AND FLOW ANALYSES

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,300)

       IF((IV(35).EQ.1).AND.(IV(38).EQ.1)) THEN

        WRITE(IOUT,301)

        WRITE(IOUT,315)

        WRITE(IOUT,302)

       END IF 

       IF((IV(35).EQ.2).AND.(IV(38).EQ.1)) THEN

        WRITE(IOUT,303)

        WRITE(IOUT,315)

        WRITE(IOUT,304)

       END IF 

       IF((IV(35).EQ.1).AND.(IV(38).EQ.2)) THEN

        WRITE(IOUT,305)

        WRITE(IOUT,315)

        WRITE(IOUT,306)

        WRITE(IOUT,307)

        WRITE(IOUT,308)

        WRITE(IOUT,3081)

        WRITE(IOUT,3082)

       END IF 

       IF((IV(35).EQ.2).AND.(IV(38).EQ.2)) THEN

        WRITE(IOUT,309)

        WRITE(IOUT,315)

        WRITE(IOUT,310)

        WRITE(IOUT,311)

        WRITE(IOUT,312)

        WRITE(IOUT,313)

        WRITE(IOUT,314)

       END IF 

       IF(IV(38).EQ.1) THEN

        IF(IV(86).EQ.2) WRITE(IOUT,316) IVAR

        IF(IV(86).EQ.3) WRITE(IOUT,317)

       END IF 

       IF(IV(38).EQ.2) THEN

        IF(IV(86).EQ.2) WRITE(IOUT,318) IVAR

        IF(IV(86).EQ.3) WRITE(IOUT,319)

       END IF 

       READ(INBAS,250,IOSTAT=K1,ERR=690)IVAR

       IF(((IV(86).EQ.2).AND.(IVAR.NE.0)).OR.(IV(86).EQ.3)) THEN

        IV(41)=IVAR

       END IF

       IF((IABS(IV(41)).NE.1).AND.(IV(41).NE.2).AND.

     1    (IV(41).NE.3)) THEN

        IV(41) = 0

        GO TO 690

       END IF

 300   FORMAT(////,T10,'SELECT  :')

 301   FORMAT(/,T10,'1.  TO OUTPUT HEAD TO A SINGLE FILE')

 302   FORMAT(/,T10,'2.  TO OUTPUT HEAD BY SECTIONS')

 303   FORMAT(/,T10,'1.  TO OUTPUT PRESSURE TO A SINGLE FILE')

 304   FORMAT(/,T10,'2.  TO OUTPUT PRESSURE BY SECTIONS')

 305   FORMAT(/,T10,'1.  TO OUTPUT HEAD AND FLOW TO SINGLE FILES')

 306   FORMAT(/,T10,'2.  TO OUTPUT HEAD AND FLOW BY SECTIONS')

 307   FORMAT(/,T10,'3.  TO OUTPUT HEAD AND FLOW BY SECTIONS')

 308   FORMAT(T10,  '    AND OUTPUT 2-D FLOW RESULTANTS')

 3081  FORMAT(/,T10,'4.  TO OUTPUT HEAD AND FLOW BY SECTIONS')

 3082  FORMAT(T10,  '    AND OUTPUT 3-D FLOW RESULTANTS')

 309   FORMAT(/,T10,'1.  TO OUTPUT PRESSURE AND FLOW TO SINGLE FILES')

 310   FORMAT(/,T10,'2.  TO OUTPUT PRESSURE AND FLOW BY SECTIONS')

 311   FORMAT(/,T10,'3.  TO OUTPUT PRESSURE AND FLOW BY SECTIONS')

 312   FORMAT(T10, '     AND OUTPUT 2-D FLOW RESULTANTS')

 313   FORMAT(/,T10,'4.  TO OUTPUT PRESSURE AND FLOW BY SECTIONS')

 314   FORMAT(T10, '     AND OUTPUT 3-D FLOW RESULTANTS')

 315   FORMAT(T10, '     1 FOR TEXT FILE, OR, -1 FOR BINARY FILE')

 316   FORMAT(//,T10,'PLEASE SELECT NUMBER  1, -1  OR  2 ',

     1       ' (EG',I2,')  :  ')

 317   FORMAT(//,T10,'PLEASE SELECT NUMBER  1, -1  OR  2  :  ')

 318   FORMAT(//,T10,'PLEASE SELECT NUMBER  1, -1, 2  OR  3 ',

     1       ' (EG',I2,')  :  ')

 319   FORMAT(//,T10,'PLEASE SELECT NUMBER  1, -1, 2  OR  3  :  ')

C

C------SPECIFY WHETHER TO GENERATE (1) OR SKIP (2) MASS BALANCE

C

 695   CONTINUE

C------TEST FOR HEAD AND FLOW ANALYSES

       IF(IV(38).EQ.1) THEN

        IV(42)=2

       END IF

       IF(IV(38).EQ.2) THEN

        IVAR = 1

        IF(IV(86).EQ.2) IVAR = IV(42)

        WRITE(IOUT,241)

        WRITE(IOUT,242)

        WRITE(IOUT,340)

        WRITE(IOUT,341)

        WRITE(IOUT,342)

        IF(IV(86).EQ.2) WRITE(IOUT,343) IVAR

        IF(IV(86).EQ.3) WRITE(IOUT,344)

        READ(INBAS,250,IOSTAT=K1,ERR=695)IVAR

        IF(((IV(86).EQ.2).AND.(IVAR.NE.0)).OR.(IV(86).EQ.3)) THEN

         IV(42)=IVAR

        END IF

C-------TEST USER INPUT

        IF((IV(42).NE.1).AND.(IV(42).NE.2)) THEN

         IV(42) = 0

         GO TO 695

        END IF

       END IF 

 340   FORMAT(////,T10,'SELECT  :')

 341   FORMAT(/,T10,'1.  TO GENERATE MASS BALANCE OUTPUT')

 342   FORMAT(/,T10,'2.  TO SKIP MASS BALANCE OUTPUT')

 343   FORMAT(///,T10,'PLEASE SELECT NUMBER 1  OR  2 ',

     1       ' (EG',I2,')  :  ')

 344   FORMAT(//,T10,'PLEASE SELECT NUMBER  1  OR  2  :  ')

C

C------SPECIFY PARTICULAR LAYER, ROW, OR COLUMN OR ALL (0) FOR OUTPUT

C

 696   CONTINUE

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,320)

       IF(IV(39).EQ.1) WRITE(IOUT,321)

       IF(IV(39).EQ.1) WRITE(IOUT,322)

       IF(IV(39).EQ.2) WRITE(IOUT,323)

       IF(IV(39).EQ.2) WRITE(IOUT,324)

       IF(IV(39).EQ.3) WRITE(IOUT,325)

       IF(IV(39).EQ.3) WRITE(IOUT,326)

       WRITE(IOUT,327)

       READ(INBAS,251,IOSTAT=K1,ERR=696)IV(43)

C------CANNOT TEST USER INPUT SINCE NLAY, NROW, NCOL NOT KNOWN

C      AT THIS POINT - INPUT MUST BE POSITIVE HOWEVER

       IF(IV(43).LT.0) GO TO 696

C------CORRECT OUTPUT BY LAYER FOR ATMOSPHERIC LAYER

C      IF((IV(39).EQ.1).AND.(IV(35).EQ.2).AND.(IV(43).NE.0)) THEN

C       IV(43) = IV(43)+1

C      END IF

 320   FORMAT(////,T10,'PLEASE SPECIFY  :')

 321   FORMAT(//,T10,'LAYER NUMBER FOR WHICH TO GENERATE OUTPUT, OR,')

 322   FORMAT(/,T10,'0  TO GENERATE OUTPUT FOR ALL LAYERS')

 323   FORMAT(//,T10,'ROW NUMBER FOR WHICH TO GENERATE OUTPUT, OR,')

 324   FORMAT(/,T10,'0  TO GENERATE OUTPUT FOR ALL ROWS')

 325   FORMAT(//,T10,'COLUMN NUMBER FOR WHICH TO GENERATE OUTPUT, OR,')

 326   FORMAT(/,T10,'0  TO GENERATE OUTPUT FOR ALL COLUMNS')

 327   FORMAT(//,T10,'PLEASE SELECT NUMBER  :  ')

C

C-----OUTPUT HEADING FOR INPUT FILE NAMES

C

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,254)

       WRITE(IOUT,255)

C

C------INPUT NAME FOR MODFLOW BASIC FILE

C

 700   CONTINUE

       FNAME(18) = 'BASAIR.PRN'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(3)

       WRITE(IOUT,420)

       WRITE(IOUT,421)FNAME(18)

 420   FORMAT(//////,T10,'PLEASE SPECIFY  :')

 421   FORMAT(//,T10,'NAME OF MODFLOW BASIC FILE ',

     1       '  EG ',A12,'  :  ')

 422   FORMAT(A12)

       READ(INBAS,422,ERR=700)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(3) = FNAME(18)

       END IF

C

C------INPUT NAME FOR MODFLOW OUTPUT CONTROL FILE

C

 710   CONTINUE

       FNAME(18) = 'OCAIR.PRN'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(4)

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,420)

       WRITE(IOUT,431)FNAME(18)

 431   FORMAT(//,T10,'NAME OF MODFLOW OUTPUT CONTROL FILE ',

     1       '  EG ',A12,'  :  ')

       READ(INBAS,422,ERR=710)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(4) = FNAME(18)

       END IF

C

C------INPUT NAME FOR MODFLOW BLOCK CENTERED FLOW FILE

C

 720   CONTINUE

       FNAME(18) = 'BCFAIR.PRN'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(5)

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,420)

       WRITE(IOUT,441)FNAME(18)

 441   FORMAT(//,T10,'NAME OF MODFLOW BLOCK CENTERED FLOW FILE ',

     1       '  EG ',A12,'  :  ')

       READ(INBAS,422,ERR=720)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(5) = FNAME(18)

       END IF

C

C------INPUT NAME FOR MODFLOW BINARY HEAD OUTPUT FILE

C

 730   CONTINUE

       FNAME(18) = 'HEAD.BIN'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(7)

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,420)

       WRITE(IOUT,451)FNAME(18)

 451   FORMAT(//,T10,'NAME OF MODFLOW BINARY HEAD OUTPUT FILE ',

     1       '  EG ',A12,'  :  ')

       READ(INBAS,422,ERR=730)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(7) = FNAME(18)

       END IF

C

C------INPUT NAME FOR MODFLOW BINARY FLOW OUTPUT FILE

C

 740   CONTINUE

C------ONLY PROMPT FOR BINARY FLOW FILE IF FLOW ANALYSIS SELECTED

       IF(IV(38).NE.1) THEN

        FNAME(18) = 'FLOW.BIN'

        IF(IV(86).EQ.2) FNAME(18) = FNAME(8)

        WRITE(IOUT,241)

        WRITE(IOUT,242)

        WRITE(IOUT,420)

        WRITE(IOUT,461)FNAME(18)

 461    FORMAT(//,T10,'NAME OF MODFLOW BINARY FLOW OUTPUT FILE ',

     1        '  EG ',A12,'  :  ')

        READ(INBAS,422,ERR=740)FNAME(18)

        IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1     THEN

         FNAME(8) = FNAME(18)

        END IF

       END IF

C

C------INPUT NAME FOR PREPROCESSOR MODEL DATA FILE

C

 750   CONTINUE

       FNAME(18) = 'MODEL.DAT'

       IF(IV(86).EQ.2) FNAME(18) = FNAME(9)

       WRITE(IOUT,241)

       WRITE(IOUT,242)

       WRITE(IOUT,420)

       WRITE(IOUT,471)FNAME(18)

 471   FORMAT(//,T10,'NAME OF MODEL DATA TRANSFER FILE ',

     1       '  EG ',A12,'  :  ')

       READ(INBAS,422,ERR=750)FNAME(18)

       IF(((IV(86).EQ.2).AND.(FNAME(18).NE.' ')).OR.(IV(86).EQ.3))

     1    THEN

        FNAME(9) = FNAME(18)

       END IF

C------SET UP INFILE.POS FILE

       REWIND 21

       WRITE(21,230)IV(35),IV(36),IV(37),IV(38),IV(39),IV(40),

     1   IV(41),IV(42),IV(43)

       WRITE(21,225) FNAME(3)

       WRITE(21,225) FNAME(4)

       WRITE(21,225) FNAME(5)

       WRITE(21,225) FNAME(7)

       WRITE(21,225) FNAME(8)

       WRITE(21,225) FNAME(9)

C------MESSAGE TO USER

       WRITE(IOUT,201)

       WRITE(IOUT,202)

       IF(IV(86).EQ.2) WRITE(IOUT,480)FNAME(11)

       IF(IV(86).EQ.3) WRITE(IOUT,481)FNAME(11)

       WRITE(IOUT,205)

       WRITE(IOUT,206)

       WRITE(IOUT,207)

       WRITE(IOUT,208)

       WRITE(IOUT,209)

       WRITE(IOUT,210)

       READ(INBAS,250,ERR=600)IV(86)

       IF (IV(86).EQ.4) THEN

        STOP

       END IF

C------RETURN TO MENU

       GO TO 601

 480   FORMAT(///,T10,A12,' HAS BEEN MODIFIED')

 481   FORMAT(///,T10,A12,' HAS BEEN CREATED')

      END IF

C

C8----OPEN DATA FILES USED IN POSTMOD

C

C-----OPEN AND TEST BASIC FILE SPECIFIED BY USER

 705  CONTINUE

      OPEN(UNIT=13,FILE=FNAME(3),STATUS='OLD')

      REWIND 13

      READ(13,423,IOSTAT=K1,ERR=701,END=702)HEADING

 423  FORMAT(20A4)

      IF (K1.EQ.0) GO TO 715

 701  CALL ERRMES(FNAME(3),IER1)

      IF(IER1.EQ.1) GO TO 705

C-----INPUT DATA INTERACTIVELY

      IF(IER1.EQ.2) IV(86)=2

      IF(IER1.EQ.2) GO TO 615

 702  CALL ENDMES(FNAME(3),IER1)

      IF(IER1.EQ.1) GO TO 705

C-----INPUT DATA INTERACTIVELY

      IF(IER1.EQ.2) IV(86)=2

      IF(IER1.EQ.2) GO TO 615

C-----OPEN AND TEST OUTPUT CONTROL FILE SPECIFIED BY USER

 715  CONTINUE

      OPEN(UNIT=14,FILE=FNAME(4),STATUS='OLD')

      REWIND 14

      READ(14,432,IOSTAT=K1,ERR=711,END=712)IHEDFM,IDDNFM,

     1  IHEDUN,IDDNUN

 432  FORMAT(4I10)

      IV(88)=IHEDUN

      IV(98)=IHEDFM

      IV(98)=IDDNFM

      IV(98)=IDDNUN

      IF (K1.EQ.0) GO TO 725

 711  CALL ERRMES(FNAME(4),IER1)

      IF(IER1.EQ.1) GO TO 715

C-----INPUT DATA INTERACTIVELY

      IF(IER1.EQ.2) IV(86)=2

      IF(IER1.EQ.2) GO TO 615

 712  CALL ENDMES(FNAME(4),IER1)

      IF(IER1.EQ.1) GO TO 715

C-----INPUT DATA INTERACTIVELY

      IF(IER1.EQ.2) IV(86)=2

      IF(IER1.EQ.2) GO TO 615

C-----OPEN AND TEST BLOCK CENTERED FLOW FILE SPECIFIED BY USER

 725  CONTINUE

      OPEN(UNIT=15,FILE=FNAME(5),STATUS='OLD')

      REWIND 15

      READ(15,442,IOSTAT=K1,ERR=721,END=722)ISS,IBCFCB

 442  FORMAT(2I10)

      IV(89)=IBCFCB

      IV(90)=ISS

      IF (K1.EQ.0) GO TO 735

 721  CALL ERRMES(FNAME(5),IER1)

      IF(IER1.EQ.1) GO TO 725

C-----INPUT DATA INTERACTIVELY

      IF(IER1.EQ.2) IV(86)=2

      IF(IER1.EQ.2) GO TO 615

 722  CALL ENDMES(FNAME(5),IER1)

      IF(IER1.EQ.1) GO TO 725

C-----INPUT DATA INTERACTIVELY

      IF(IER1.EQ.2) IV(86)=2

      IF(IER1.EQ.2) GO TO 615

C-----OPEN AND TEST BINARY HEAD FILE SPECIFIED BY USER

 735  CONTINUE

      OPEN(UNIT=17,FILE=FNAME(7),FORM='UNFORMATTED',

     1 ACCESS='SEQUENTIAL',STATUS='OLD')

      REWIND 17

      READ(17) KSTPH,KPERH,PERTIMH,TOTIMH,TEXTH

      IV(98)=KSTPH

      IV(98)=KPERH

      IV(98)=INT(PERTIMH)

      IV(98)=INT(TOTIMH)

      IF (TEXTH(1).EQ.'    ') GO TO 745

      CALL ERRMES(FNAME(7),IER1)

      IF(IER1.EQ.1) GO TO 735

C-----INPUT DATA INTERACTIVELY

      IF(IER1.EQ.2) IV(86)=2

      IF(IER1.EQ.2) GO TO 615

C-----OPEN AND TEST BINARY FLOW FILE SPECIFIED BY USER

C-----ONLY OPEN BINARY FLOW FILE IF FLOW ANALYSIS SELECTED

 745  CONTINUE

      IF(IV(38).NE.1) THEN

       OPEN(UNIT=18,FILE=FNAME(8),FORM='UNFORMATTED',

     1  ACCESS='SEQUENTIAL',STATUS='OLD')

       REWIND 18

       READ(18) KSTPF,KPERF,TEXTF

       IV(98)=KSTPF

       IV(98)=KPERF

       IF ((ISS.EQ.0).AND.(TEXTF(1).EQ.'    ')) GO TO 755

       IF ((ISS.NE.0).AND.(TEXTF(1).EQ.'   C')) GO TO 755

       CALL ERRMES(FNAME(8),IER1)

       IF(IER1.EQ.1) GO TO 745

C------INPUT DATA INTERACTIVELY

       IF(IER1.EQ.2) IV(86)=2

       IF(IER1.EQ.2) GO TO 615

      END IF

C-----OPEN AND TEST MODEL DATA FILE SPECIFIED BY USER

 755  CONTINUE

      OPEN(UNIT=19,FILE=FNAME(9),STATUS='OLD')

      REWIND 19

      READ(19,472,IOSTAT=K1,ERR=751,END=752)IU1(1),IU1(2),IU1(3),

     1       IU1(4),IU1(5),IU1(6),IU1(7),IV(4),IV(5),IV(9)

 472  FORMAT(10I5)

C-----CORRECT ROW SETTINGS IN INFILE.POS FOR 2D RADIAL SIMULATIONS

      IF ((IV(9).EQ.2).AND.(IV(39).EQ.2)) THEN

       IV(43) = 2

      END IF

      IF (K1.EQ.0) GO TO 753

 751  CALL ERRMES(FNAME(4),IER1)

      IF(IER1.EQ.1) GO TO 755

C-----INPUT DATA INTERACTIVELY

      IF(IER1.EQ.2) IV(86)=2

      IF(IER1.EQ.2) GO TO 615

 752  CALL ENDMES(FNAME(4),IER1)

      IF(IER1.EQ.1) GO TO 755

C-----INPUT DATA INTERACTIVELY

      IF(IER1.EQ.2) IV(86)=2

      IF(IER1.EQ.2) GO TO 615

 753  CONTINUE

C-----SET UNITS TO DEFAULT SYSTEM IF NO ENTRY MADE

      IF((IU1(1).LT.2).OR.(IU1(1).GT.6)) IU1(1)=1

      IF((IU1(2).LT.2).OR.(IU1(2).GT.7)) IU1(2)=1

      IF((IU1(3).LT.2).OR.(IU1(3).GT.5)) IU1(3)=1

      IF((IU1(4).LT.2).OR.(IU1(4).GT.5)) IU1(4)=1

      IF((IU1(5).LT.2).OR.(IU1(5).GT.3)) IU1(5)=1

      IF((IU1(6).LT.2).OR.(IU1(6).GT.3)) IU1(6)=1

      IF((IU1(7).LT.2).OR.(IU1(7).GT.7)) IU1(7)=1

C

C9----RETURN

C

      RETURN

      END

C

C     ***************

      SUBROUTINE STOR(XTMP,ITMP,FMT1)

C     ***************

C

C1----NOTES :

C

C     1. USE THIS ROUTINE TO TEST FILE SETTINGS AND POST PROCESSOR

C         MEMORY ALLOCATIONS

C

C2----SPECIFICATIONS :

C

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(25)

      DIMENSION XTMP(500),ITMP(500),FMT1(5)

      CHARACTER FNAME*12,FMT1*4

C-----ASSIGN VARIABLES

      NWELL = IV(4)

      NTRCH = IV(5)

C     INBAS = IV(81)

      IOUT  = IV(82)

      IHEDUN= IV(88)

      IBCFCB= IV(89)

      ISS   = IV(90)

C

C3----PARTIAL INPUT OF INFORMATION FROM BASIC FILE

C

C     NOTES :

C

C     1. VARIABLE ASSIGNMENTS :

C

C        IV(1) = NROW  = NUMBER OF ROWS

C        IV(2) = NCOL  = NUMBER OF COLUMNS

C        IV(3) = NLAY  = NUMBER OF LAYERS

C        IV(4) = NWELL = NUMBER OF WELLS

C        IV(5) = NTRCH = NUMBER OF TRENCHES

C        IV(6) = NPER  = NUMBER OF STRESS PERIODS

C        IV(7) = ITMUNI= TIME UNITS OF MODEL DATA

C        IV(8) = NROW*NCOL = PRODUCT OF ROWS * COLUMNS

C

C        IV(11)= NRC = ARRAY DIMENSION = NROW > 0

C        IV(12)= NCC = ARRAY DIMENSION = NCOL > 0

C        IV(13)= NLC = ARRAY DIMENSION = NLAY > 0

C        IV(14)= MRC = BUFF DIM FOR STEADY (1) OR TRANSIENT (NROW)

C        IV(15)= MCC = BUFF DIM FOR STEADY (1) OR TRANSIENT (NCOL)

C        IV(16)= MLC = BUFF DIM FOR STEADY (1) OR TRANSIENT (NLAY)

C        IV(17)= LRC = BUFx DIM FOR 2D RESULT (1) OR 3D RESULT (NROW)

C        IV(18)= LCC = BUFx DIM FOR 2D RESULT (1) OR 3D RESULT (NCOL)

C        IV(19)= LLC = BUFx DIM FOR 2D RESULT (1) OR 3D RESULT (NLAY)

C

C        IV(20)= IUNIT(15)= UNIT NUMBER OF BCF PACKAGE

C        IV(21)= IUNIT(14)= UNIT NUMBER OF OC PACKAGE

C        IV(22)= IAPART   = FLAG FOR BUFF & RHS ARRAYS

C        IV(23)= ISTRT    = FLAG FOR SAVING HEADS

C

C        IV(25)= START NUMBER FOR ANISOTROPY ARRAY (TRPY)

C        IV(26)= START NUMBER FOR CELL WIDTH ALONG ROW (DELR)

C        IV(27)= START NUMBER FOR CELL WIDTH ALONG COL (DELC)

C        IV(28)= START NUMBER FOR CELL WIDTH ALONG LAY (DELL)

C        IV(29)= START NUMBER FOR HEAD BINARY ARRAY (BUFH)

C

C        IV(35)....IV(43) - OUTPUT CONTROL FLAGS

C        IV(45)= FLAG FOR PRES(1), HEAD(2), VOL FLOW (3), MASS FLOW(4)

C        IV(50)= START NUMBER FOR FLOW BINARY ARRAY (BUFF)

C        IV(51)= START NUMBER FOR FLOW BINARY ARRAY (BUFP)

C        IV(54)= START NUMBER FOR WELL/TRENCH ARRAY (SCRD)

C        IV(55)= START NUMBER FOR SPATIAL COORD (SCRD)

C        IV(56)= START NUMBER FOR FLOW BINARY ARRAY (BUFR)

C        IV(57)= START NUMBER FOR FLOW BINARY ARRAY (BUFF)

C        IV(58)= START NUMBER FOR FLOW BINARY ARRAY (BUFL)

C

C        IV(60)= TOTAL NUMBER OF TIME STEPS IN SIMULATION

C                (IE. IN ALL STRESS PERIODS)

C        IV(61)= NUMBER OF TIME STEPS IN STRESS PERIOD 1

C        IV(62)= NUMBER OF TIME STEPS IN STRESS PERIOD 2 ETC...

C

C        IV(81)= INBAS    = INPUT UNIT NUMBER

C        IV(82)= OUTBAS   = OUTPUT UNIT NUMBER

C        IV(83)= LENX     = DIMENSION OF XX-ARRAY

C        IV(84)= LENI     = DIMENSION OF IX-ARRAY

C        IV(86)= FLAG FOR RUN (1), MODIFY (2), CREATE (3) OR END (4)

C        IV(88)= IHEDUN   = UNIT NUMBER TO WHICH HEADS ARE WRITTEN

C        IV(89)= IBCFCB   = UNIT NUMBER TO WHICH FLOWS ARE WRITTEN

C        IV(90)= ISS      = FLAG FOR TRANSIENT (0) OR STEADY STATE (1)

C

C        IV(94)= NROW/NCOL= STORAGE FOR 2D RADIAL RESULTS

C        IV(95)= NWC      = ARRAY DIMENSION = NWELL > 0

C        IV(96)= NTC      = ARRAY DIMENSION = NTRCH > 0

C        IV(96)= DUMMY STORAGE SPACE (VARIABLE)

C

C-----INPUT FROM BASIC FILE

C

C-----READ NUMBER OF LAYERS,ROWS,COLUMNS,STRESS PERIODS AND

C-----UNITS OF TIME CODE

      READ(13,200)NLAY,NROW,NCOL,NPER,ITMUNI

 200  FORMAT(5I10)

C-----STORE VARIABLES

      IV(1)=NROW

      IV(2)=NCOL

      IV(3)=NLAY

      IV(6)=NPER

      IV(7)=ITMUNI

C-----PRODUCT OF ROWS AND COLUMNS

      IV(8)=NROW*NCOL

C-----CHECK INPUT FOR TIME UNITS

      IF((ITMUNI.LT.0).OR.(ITMUNI.GT.5)) ITMUNI=0

C-----READ INPUT UNIT NUMBERS (IUNIT) FOR MAJOR OPTIONS

      READ(13,201)IN01,IN02,IN03,IN04,IN05,IN06,IN07,IN08,IN09,

     1 IN10,IN11,IN12

      IV(98)=IN02

      IV(98)=IN03

      IV(98)=IN04

      IV(98)=IN05

      IV(98)=IN06

      IV(98)=IN07

      IV(98)=IN08

      IV(98)=IN09

      IV(98)=IN10

      IV(98)=IN11

  201 FORMAT(12I3)

C-----STORE VARIABLES

      IV(20)=IN01

      IV(21)=IN12

C-----READ FLAG IAPART AND ISTRT

      READ(13,210) IAPART,ISTRT

 210  FORMAT(2I10)

C-----STORE VARIABLES

      IV(22)=IAPART

      IV(23)=ISTRT

C-----READ IBOUND (BUT DO NOT SAVE)

      DO 110 K=1,NLAY

       READ(13,220) LOC1,ICON1,FMT1,IPR1

 220   FORMAT(I10,I10,5A4,I10)

       IV(98)=ICON1

       IV(98)=IPR1

       IF(LOC1.GT.0) THEN

        DO 111 I=1,NROW

         READ(13,FMT1) (ITMP(J),J=1,NCOL)

 111    CONTINUE

       END IF

       IF(LOC1.LT.0) THEN

        WRITE(IOUT,221)

 221    FORMAT(///////////////,T10,'PROGRAM CANNOT READ IN BINARY',

     1  ' DATA FOR IBOUND ARRAY')

        STOP

       END IF

 110  CONTINUE

C-----READ HNOFLO

      READ(13,230) HNOFLO

      HNOFLO=HNOFLO/1.0

 230  FORMAT(F10.0)

C-----READ SHEAD (BUT DO NOT SAVE)

      DO 115 K=1,NLAY

       READ(13,240) LOC1,CON1,FMT1,IPR1

       IV(98)=INT(CON1)

 240   FORMAT(I10,F10.0,5A4,I10)

       IF(LOC1.GT.0) THEN

        DO 116 I=1,NROW

         READ(13,FMT1) (XTMP(J),J=1,NCOL)

 116    CONTINUE

       END IF

       IF(LOC1.LT.0) THEN

        WRITE(IOUT,241)

 241    FORMAT(///////////,T10,'PROGRAM CANNOT READ IN BINARY',

     1  ' DATA FOR SHEAD ARRAY')

        STOP

       END IF

 115  CONTINUE

C-----READ PERLEN, NSTP, TSMULT FOR EACH STRESS PERIOD

      IF(NPER.GT.20) THEN

       WRITE(IOUT,260)

       WRITE(IOUT,261)

 260   FORMAT(////////,T10,'NUMBER OF STRESS PERIODS EXCEEDS',

     1  ' ALLOCATED MEMORY')

 261   FORMAT(//,T10,'MAXIMUM ALLOWABLE NUMBER OF TIME STEPS :',

     1  ' NPER = 20')

       STOP

      END IF 

      IV(60)=0

      DO 120 I=1,NPER

       ICST2 = 60 + I

       READ(13,262)PERLEN,IV(ICST2),TSMULT

       IV(98)=INT(PERLEN)

       IV(98)=INT(TSMULT)

       IV(60)=IV(60)+IV(ICST2)

 120  CONTINUE

 262  FORMAT(F10.0,I10,F10.0)

C-----TEST UNIT NUMBER TO SEE IF OUTPUT CONTROL IS ACTIVE

      IF(IN12.EQ.0) THEN

       WRITE(IOUT,280)

       WRITE(IOUT,281)

       WRITE(IOUT,282)

       WRITE(IOUT,283)

       WRITE(IOUT,284)

       STOP

      END IF

 280  FORMAT(///////////////,T10,'OUTPUT CONTROL FILE NOT ACTIVE')

 281  FORMAT(/,T10,'NO OC UNIT NUMBER SPECIFIED IN BASIC FILE')

 282  FORMAT(/,T10,'THEREFORE, NO BINARY OUTPUT FILES GENERATED')

 283  FORMAT(/,T10,'POST PROCESSOR CANNOT PROCEED')

 284  FORMAT(//,T10,'RE-RUN MODFLOW WITH OC UNIT NUMBER > 0')

C

C4----TEST BINARY OUTPUT SETTINGS IN OC AND BCF FILE

C

C-----TEST TO SEE IF UNIT NUMBER FOR BINARY HEAD STORAGE WAS

C      ASSIGNED IN OUTPUT CONTROL FILE

C

      IF(IHEDUN.EQ.0) THEN

       WRITE(IOUT,300)

       WRITE(IOUT,301)

       WRITE(IOUT,302)

       WRITE(IOUT,303)

       STOP

      END IF

 300  FORMAT(///////////////,T10,'IHEDUN IN OUTPUT CONTROL FILE',

     1 ' NOT SPECIFIED')

 301  FORMAT(/,T10,'NO BINARY HEAD OUTPUT FILES GENERATED')

 302  FORMAT(/,T10,'POST PROCESSOR CANNOT PROCEED')

 303  FORMAT(//,T10,'RE-RUN MODFLOW WITH IHEDUN > 0')

C

C-----TEST TO SEE IF UNIT NUMBER FOR BINARY FLOW STORAGE WAS

C      ASSIGNED IN BLOCK CENTERED FLOW FILE

C

C-----ONLY TEST IF HEAD AND FLOW ANALYSIS WAS SPECIFIED

      IF(IV(38).NE.1) THEN

       IF(IBCFCB.EQ.0) THEN

        WRITE(IOUT,320)

        WRITE(IOUT,321)

        WRITE(IOUT,322)

        WRITE(IOUT,323)

        STOP

       END IF

      END IF

 320  FORMAT(///////////////,T10,'IBCFCB IN BLOCK CENTERED FLOW',

     1 ' FILE NOT SPECIFIED')

 321  FORMAT(/,T10,'NO BINARY FLOW OUTPUT FILES GENERATED')

 322  FORMAT(/,T10,'POST PROCESSOR CANNOT PROCEED')

 323  FORMAT(//,T10,'RE-RUN MODFLOW WITH IBCFCB > 0')

C

C5----INPUT AND TESTING OF INFORMATION FROM OUTPUT CONTROL FILE

C

C-----TEST TO SEE IF FLAGS FOR SAVING HEAD (AND FLOW) OUTPUT WERE

C      SPECIFIED IN OUTPUT CONTROL FILE

C-----TEST ONCE FOR EACH TIME STEP

      ITT=0

      DO 130 I = 1,IV(60)

       READ(14,340)INCODE,IHDDFL,IBUDFL,ICBCFL

 340   FORMAT(4I10)

       IV(98)=INT(IBUDFL)

C------TEST TO SEE IF INCODE > 0

       IF(INCODE.GT.0) THEN

        WRITE(IOUT,341)

        WRITE(IOUT,342)I,IV(60)

        WRITE(IOUT,343)

        WRITE(IOUT,344)

        WRITE(IOUT,345)

        WRITE(IOUT,346)

        WRITE(IOUT,347)

        WRITE(IOUT,348)

        STOP

       END IF

 341   FORMAT(///////////////,T10,'INCODE IN OUTPUT CONTROL FILE',

     1  ' IS NOT EQUAL TO ZERO')

 342   FORMAT(/,T10,'FOR TIME STEP  : ',I10,'OF TOTAL : ',I10)

 343   FORMAT(//,T10,'INCODE MUST EQUAL ZERO FOR ALL TIME STEPS')

 344   FORMAT(/,T10,'SO THAT BINARY OUTPUT FILES CONTAIN')

 345   FORMAT(/,T10,'IDENTICAL HEAD/FLOW INFORMATION IN EACH')

 346   FORMAT(/,T10,'LAYER')

 347   FORMAT(/,T10,'POST PROCESSOR OPERATION TERMINATED')

 348   FORMAT(//,T10,'RE-RUN MODFLOW WITH ALL INCODE = 0')

C------TEST TO SEE IF IHDDFL <> 0

       IF(IHDDFL.EQ.0) THEN

        WRITE(IOUT,360)

        WRITE(IOUT,361)I,IV(60)

        WRITE(IOUT,362)

        WRITE(IOUT,363)

        WRITE(IOUT,364)

        ITT=ITT+1

       END IF

 360   FORMAT(///////////////,T10,'IHDDFL IN OUTPUT CONTROL FILE',

     1  ' =  0')

 361   FORMAT(/,T10,'FOR TIME STEP  : ',I10,'OF TOTAL : ',I10)

 362   FORMAT(/,T10,'NO BINARY HEAD OUTPUT FILES GENERATED')

 363   FORMAT(/,T10,'POST PROCESSOR OPERATION INTERRUPTED')

 364   FORMAT(//,T10,'RE-RUN MODFLOW WITH ALL IHDDFL = 1')

C------TEST TO SEE IF ICBCFL <> 0

C------ONLY TEST IF HEAD AND FLOW ANALYSIS WAS SPECIFIED

       IF(IV(38).NE.1) THEN

        IF(ICBCFL.EQ.0) THEN

         WRITE(IOUT,380)

         WRITE(IOUT,381)I,IV(60)

         WRITE(IOUT,382)

         WRITE(IOUT,383)

         WRITE(IOUT,384)

         ITT=ITT+1

        END IF

       END IF

 380   FORMAT(///////////////,T10,'ICBCFL IN OUTPUT CONTROL FILE',

     1  ' =  0')

 381   FORMAT(/,T10,'FOR TIME STEP  : ',I10,'OF TOTAL : ',I10)

 382   FORMAT(/,T10,'NO BINARY FLOW OUTPUT FILES GENERATED')

 383   FORMAT(/,T10,'POST PROCESSOR OPERATION INTERRUPTED')

 384   FORMAT(//,T10,'RE-RUN MODFLOW WITH ALL ICBCFL = 1')

C------ONLY TEST IF INCODE = 0

       IF(INCODE.EQ.0) THEN

        READ(14,385)IHDPR,IDDPR,IHDSV,IDDSV

 385    FORMAT(4I10)

        IV(98)=IHDPR

        IV(98)=IDDPR

        IV(98)=IDDSV

C-------TEST TO SEE IF IHDSV <> 0

        IF(IHDSV.EQ.0) THEN

         WRITE(IOUT,400)

         WRITE(IOUT,401)I,IV(60)

         WRITE(IOUT,402)

         WRITE(IOUT,403)

         WRITE(IOUT,404)

         ITT=ITT+1

        END IF

 400    FORMAT(///////////////,T10,'Hdsv IN OUTPUT CONTROL FILE',

     1   ' =  0')

 401    FORMAT(/,T10,'FOR TIME STEP  : ',I10,'OF TOTAL : ',I10)

 402    FORMAT(/,T10,'NO BINARY HEAD OUTPUT FILES GENERATED')

 403    FORMAT(/,T10,'POST PROCESSOR OPERATION INTERRUPTED')

 404    FORMAT(//,T10,'RE-RUN MODFLOW WITH ALL Hdsv = 1')

       END IF

 130  CONTINUE

C-----SPECIFY NUMBER OF INTERRUPTIONS AND TERMINATE PROGRAM

      IF(ITT.NE.0) THEN

       WRITE(IOUT,420)

       WRITE(IOUT,421)ITT

       WRITE(IOUT,422)

       WRITE(IOUT,423)

       WRITE(IOUT,424)

       WRITE(IOUT,425)

       STOP

      END IF

 420  FORMAT(///////////////,T10,'THE TOTAL NUMBER OF',

     1 ' INTERRUPTIONS')

 421  FORMAT(/,T10,'ENCOUNTERED IN OUTPUT CONTROL FILE',

     1 ' WAS  : ',I10)

 422  FORMAT(/,T10,'ERROR IN BINARY OUTPUT IS LIKELY BASED')

 423  FORMAT(/,T10,'ON RESULTS OF OC TESTING')

 424  FORMAT(/,T10,'POST PROCESSOR OPERATION TERMINATED')

 425  FORMAT(//,T10,'RE-RUN MODFLOW WITH OC CORRECTIONS')

C

C6----SET UP ARRAY STORAGE AREAS FOR IX ARRAY

C

C-----START OF LAYER TYPE CODES ARRAY (LAYCON)

C     1

C-----START OF WELL / TRENCH ARRAY (IWELL)

      IV(54)=1+NLAY

C     WELL MEMORY REQUIREMENTS

      NWC=NWELL

      IF(NWELL.LT.1) NWC = 1

      IV(95)=NWC

C     TRENCH MEMORY REQUIREMENTS

      NTC=NTRCH

      IF(NTRCH.LT.1) NTC = 1

      IV(96)=NTC

C-----END OF WELL / TRENCH ARRAY (IWELL)

      IEND1=IV(54)+(7*(NWC+NTC))

C-----START OF NODAL COORDINATE ARRAY (NCRD)

C     1

C-----MEMORY REQUIREMENTS FOR NCRD

C     LARGER OF ROW / COLUMN

      IRCM = NROW

      IF(NROW.LT.NCOL) IRCM = NCOL

C     ROW OR COL DIRECTION (ONLY NEEDED IF FLOW RESULTANTS ARE

C     BEING CALCULATED)(CD11,CD21,CD12,CD22)

      IF((IV(38).EQ.1).OR.(IV(41).LT.3)) IRCM = 1

      IV(94)=IRCM

C-----END OF NODAL COORDINATE ARRAY (NCRD)

      IEND2=1+(IRCM*4)

C

C-----TEST MEMORY ALLOCATION AREA FOR IX ARRAY

C

      IIEND=IEND1

      IF(IIEND.LT.IEND2) IIEND=IEND2

      IF(IIEND.GT.IV(84)) THEN

       WRITE(IOUT,441)IIEND+100

       WRITE(IOUT,442)

       STOP

      END IF

 441  FORMAT(///////,T10,'REDIMENSION IX ARRAY TO LENI = ',I10)

 442  FORMAT(//,T10,'OR REDUCE NCOL, NROW, NLAY IN INPUT DATA')

C

C7----SET UP ARRAY STORAGE AREAS FOR XX ARRAY

C

C-----START OF WELL / TRENCH MASS FLOW (QM) ARRAY (WELLQM)

C     1

C-----START OF ANISOTROPY ARRAY (TRPY)

      IV(25)=1+4*(NWC+NTC)

C-----START OF CELL WIDTHS ALONG ROW ARRAY (DELR)

      IV(26)=IV(25)+NLAY

C-----START OF CELL WIDTHS ALONG COLUMNS ARRAY (DELC)

      IV(27)=IV(26)+NCOL

C-----START OF CELL WIDTHS ALONG LAYERS ARRAY (DELL)

      IV(28)=IV(27)+NROW

C-----START OF HEAD BINARY ARRAY (BUFH)

      IV(29)=IV(28)+NLAY+2

C-----START OF FLOW BINARY ARRAY (BUFF)

      IV(50)=IV(29)+IV(8)

C-----MEMORY REQUIREMENTS FOR BUFF

      IF(IV(38).EQ.1) THEN

       NRC=1

       NCC=1

       NLC=1

      END IF

      IF(IV(38).NE.1) THEN

       NRC=NROW

       NCC=NCOL

       NLC=NLAY

      END IF

C-----STORE VARIABLE

      IV(11)=NRC

      IV(12)=NCC

      IV(13)=NLC

C-----START OF FLOW BINARY ARRAY (BUFP)

      IV(51)=IV(50)+(NRC*NCC*NLC)

C-----TEST FOR TRANSIENT OR STEADY STATE SIMULATION

C-----ARRAY SIZE FOR STEADY STATE SIMULATION

      MRC=1

      MCC=1

      MLC=1

C-----ARRAY SIZE FOR TRANSIENT SIMULATION

      IF(ISS.EQ.0) THEN

       MRC=NRC

       MCC=NCC

       MLC=NLC

      END IF

C-----STORE VARIABLE

      IV(14)=MRC

      IV(15)=MCC

      IV(16)=MLC

C-----END OF FLOW ARRAY (BUFP)

      IXEND1=IV(51)+(MRC*MCC*MLC)

C

C-----START OF 2D RESULTANT FLOW ARRAY (BUFF)

C     1

C-----START OF SPATIAL COORDS IN LONGER ROW/COL DIRN (SCRD)

      IV(55)=IV(29)+(NRC*NCC*2)

C-----END OF SPATIAL COORDS IN LONGER ROW/COL DIRN (SCRD)

      IXEND2=IV(55)+IRCM*4

C

C-----START OF 3D RESULTANT FLOW ARRAY (BUFF)

C     IV(50)

C-----ARRAY SIZE FOR NO 3D RESULTANT CALCULATIONS

      LRC=1

      LCC=1

      LLC=1

C-----ARRAY SIZE FOR 3D RESULTANT CALCULATIONS

      IF(IV(41).EQ.4) THEN

       LRC=NRC

       LCC=NCC

       LLC=NLC

      END IF

C-----STORE VARIABLE

      IV(17)=LRC

      IV(18)=LCC

      IV(19)=LLC

C-----START OF FLOW BINARY ARRAY (BUFP)

      IV(56)=IV(50)+(LRC*LCC*LLC)

C-----START OF FLOW BINARY ARRAY (BUFR)

      IV(57)=IV(56)+(LRC*LCC*LLC)

C-----END OF FLOW ARRAY (BUFR)

      IXEND3=IV(57)+(LRC*LCC*LLC)

C

C-----TEST MEMORY ALLOCATION AREA FOR XX ARRAY

C

      IXEND=IXEND1

      IF(IXEND.LT.IXEND2) IXEND=IXEND2

      IF(IXEND.LT.IXEND3) IXEND=IXEND3

      IF(IXEND.GT.IV(83)) THEN

       WRITE(IOUT,445)IXEND+100

       WRITE(IOUT,446)

       STOP

      END IF

 445  FORMAT(///////,T10,'REDIMENSION XX ARRAY TO LENX = ',I10)

 446  FORMAT(//,T10,'OR REDUCE NCOL, NROW, NLAY IN INPUT DATA')

C

C8----CLOSE INFILE (21), BASIC (13), AND OC (14) FILES

C

      CLOSE(21)

      CLOSE(13)

      CLOSE(14)

C

C9----RETURN

C

      RETURN

      END

C

C     ***************

      SUBROUTINE PRES(WELLQM,TRPY,DELR,DELC,DELL,BUFH,LAYCON,IWELL,

C     ***************

     1 TEXTH,NROW,NCOL,NLAY,NWC,NTC,DATUM,TAIR,CLEN)

C

C1----NOTES :

C

C     1. USE THIS ROUTINE TO GENERATE PRESSURE OUTPUT FROM

C        MODFLOW BINARY HEAD FILE

C

C     2. VARIABLES :

C

C        I      = LAYER NUMBER AND IV(3)  = NLAY

C        J      = ROW NUMBER AND IV(1)    = NROW

C        K      = COLUMN NUMBER AND IV(2) = NCOL

C

C        ICI1   = COUNTER TRACKING LAYER NUMBER

C        ICJ1   = COUNTER TRACKING ROW NUMBER

C        ICK1   = COUNTER TRACKING COLUMN NUMBER

C        IC1    = MARKER DESIGNATING CENTER (1), RIGHT (2),

C                 FRONT (3), OR, BOTTOM (4) FACE

C        J3     = MODIFIED ROW COORDINATE FOR OPTION 3

C        IUN    = UNIT NUMBER FOR OUTPUT FILE

C

C        CD1    = FIRST SPATIAL OUTPUT COORDINATE 

C        CD1    = SECOND SPATIAL OUTPUT COORDINATE 

C        ND1    = FIRST NODAL OUTPUT COORDINATE 

C        ND1    = SECOND NODAL OUTPUT COORDINATE 

C        HCOR   = CORRECTED HEAD OUTPUT

C

C2----SPECIFICATIONS:

C

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(25)

      COMMON/KVALUE/KN(10)

      DIMENSION WELLQM((NWC+NTC),4),TRPY(NLAY),DELR(NCOL),

     1 DELC(NROW),DELL(-1:NLAY),BUFH(NCOL,NROW),LAYCON(NLAY),

     2 IWELL((NWC+NTC),7),TEXTH(4)

      CHARACTER FNAME*12,IU3*6,TEXTH*4,KN*1

      CHARACTER*1 KN1,KN2,KN3,KN4,KN5,KN6,KN9,KN10,KN11,KN12

C-----ASSIGN VARIABLES

      NWELL = IV(4)

      NTRCH = IV(5)

C     INBAS = IV(81)

C     IOUT  = IV(82)

      XW1   = XU2(1,IU1(1))

C     XW2   = XU2(2,IU1(2))

C     XW3   = XU2(3,IU1(3))

      XW4   = XU2(4,IU1(4))

C     XW6   = XU2(6,IU1(6))

C

C3----DEFINE PHYSICAL CONSTANTS REQUIRED IN PNEUMATIC ANALYSES

C

      IF(IV(35).EQ.2) THEN

       STDATM = 1013250.0

      END IF

C

C4----INPUT MODEL DIMENSIONS FROM BCF FILE

C

C-----READ LAYER TYPE CODES

      READ(15,200) (LAYCON(I),I=1,NLAY)

 200  FORMAT(40I2)

      CALL U1DREL(TRPY,NLAY)

      CALL U1DREL(DELR,NCOL)

      CALL U1DREL(DELC,NROW)

C-----SUM CELL WIDTHS ALONG COLS (Y-DIRN)

      CLEN=0.0

      DO 95 I = 1,NROW

       CLEN=CLEN+DELC(I)

 95   CONTINUE

C

C5----INPUT MODEL INFORMATION FROM MODEL.DAT

C

C-----INPUT DEPTHS TO BOTTOM OF CELL LAYERS

 600  CONTINUE

      REWIND 19

      READ(19,210,IOSTAT=K1,ERR=602,END=603)IE1,IE2,IE3,IE4,IE5,

     1     IE6,IE7,IE8,IE9,IE10

      IV(98)=IE1

      IV(98)=IE2

      IV(98)=IE3

      IV(98)=IE4

      IV(98)=IE5

      IV(98)=IE6

      IV(98)=IE7

      IV(98)=IE8

      IV(98)=IE9

      IV(98)=IE10

 210  FORMAT(10I5)

      DELL(0)=0.0

      DELL(1)=0.0

C-----IF HYDRAULIC - READ IN DATUM (IE. 1ST ENTRY)

      IF(IV(35).EQ.1) THEN

       READ(19,211,IOSTAT=K1,ERR=602,END=603)DATUM

       READ(19,211,IOSTAT=K1,ERR=602,END=603)DELL(1)

      END IF

C-----IF PNEUMATIC - READ IN DATUM, AIR LAYER DEPTH, AIR TEMP

      IF(IV(35).EQ.2) THEN

       READ(19,212,IOSTAT=K1,ERR=602,END=603)DATUM,DELL(-1),TAIR

      END IF

C-----UNIT CORRECTION

      DATUM=DATUM/XW1

      DELL(-1)=DELL(-1)/XW1

      DELL(1)=DELL(1)/XW1

      TAIR  = (TAIR-XU2(5,IU1(5)))/XU2(5,(IU1(5)+5)) + 273.15

      DO 100 I = 2,NLAY

       READ(19,211,IOSTAT=K1,ERR=602,END=603)DELL(I)

       DELL(I)=DELL(I)/XW1

 100  CONTINUE

 211  FORMAT(F10.0)

 212  FORMAT(3F10.0)

 213  FORMAT(7I5,E20.8)

C-----INPUT WELL / TRENCH CONFIGURATIONS FROM MODEL.DAT

      IF((IV(35).EQ.2).AND.(IV(42).EQ.1)) THEN

       DO 101 IW = 1,(NWELL+NTRCH)

        READ(19,213)IWELL(IW,1),IWELL(IW,2),IWELL(IW,3),IWELL(IW,4),

     1    IWELL(IW,5),IWELL(IW,6),IWELL(IW,7),WELLQM(IW,2)

        WELLQM(IW,2)=WELLQM(IW,2)/XU2(4,IU1(4))*STDATM

 101   CONTINUE

      END IF

      IF (K1.EQ.0) GO TO 604

 602  CALL ERRMES(FNAME(9),IER1)

      IF(IER1.EQ.1) GO TO 600

      IF(IER1.EQ.2) STOP

 603  CALL ENDMES(FNAME(9),IER1)

      IF(IER1.EQ.1) GO TO 600

      IF(IER1.EQ.2) STOP

 604  CONTINUE

C

C6----INPUT HEAD INFORMATION FROM BINARY FILE (UNIT 17)

C     AND WRITE TO HEAD OUTPUT FILE (UNIT 25)

C

C     NOTES :

C

C-----SPECIFY OUTPUT VARIABLES

      ICI1 = 0

      ICJ1 = 0

      ICK1 = 0

      IC1  = 1

      J3   = 0

      IUN  = 28

C-----SET FLAG FOR PRESSURE (1) OR HEAD (2) OUTPUT

      IF(IV(35).EQ.1) IV(45) = 2

      IF(IV(35).EQ.2) IV(45) = 1

C-----REWIND BINARY HEAD FILE

      REWIND 17

C-----ONCE FOR EACH TIME STEP

      DO 49 IS=1,IV(60)

C------TEST FOR OUTPUT TO SINGLE FILES (IABS(IV(41)=1)) SELECTION

       IF(IABS(IV(41)).EQ.1) THEN

C-------OPEN FILE FOR CONTINUOUS OUTPUT OF HEAD

        CALL FILCNT(IV(40),KN5,KN6)

        CALL FILCNT(IS,KN11,KN12)

        KN9='.'

        IF(IV(41).EQ.1) THEN

         KN10='T'

        END IF

        IF(IV(41).EQ.-1) THEN

         KN10='B'

        END IF

        IF(IV(35).EQ.1) THEN

         KN1='H'

         KN2='E'

         KN3='A'

         KN4='D'

        END IF

        IF(IV(35).EQ.2) THEN

         KN1='P'

         KN2='R'

         KN3='E'

         KN4='S'

        END IF

        FNAME(15)=KN1//KN2//KN3//KN4//KN5//KN6//KN9//KN10//KN11//KN12

        IF(IV(41).EQ.1) THEN

         OPEN(UNIT=25,FILE=FNAME(15),STATUS='UNKNOWN')

        END IF

        IF(IV(41).EQ.-1) THEN

         OPEN(UNIT=25,FILE=FNAME(15),FORM='UNFORMATTED',

     1   ACCESS='SEQUENTIAL',STATUS='UNKNOWN')

        END IF

       END IF

C------ONCE FOR EACH LAYER

       DO 50 I=1,NLAY

C-------READ IN IDENTIFYING INFORMATION

        READ(17) KSTPH,KPERH,PERTIMH,TOTIMH,TEXTH,NHCOL,NHROW,NHLAY

C-------READ IN HEAD/PRESSURE VALUES

        READ(17) ((BUFH(IC,IR),IC=1,NCOL),IR=1,NROW)

C

C-------OUTPUT FOR TEXT OPTION

C

        IF(IV(41).GT.0) THEN

         DO 51 J = 1,NROW

          DO 52 K = 1,NCOL

C----------SET UP FLAGS NEEDED TO TEST FOR OUTPUT

           IF(IV(39).EQ.1) ITO1 = I

           IF(IV(39).EQ.2) ITO1 = J

           IF(IV(39).EQ.3) ITO1 = K

C----------SKIP OUTPUT OF HEAD IN SUPERIMPOSED ATMSOPHERIC LAYER

C          (I=1), IN AIR FLOW SIMULATIONS (IV(35)=2) FOR SORTING

C          BY LAYER (IV(39).EQ.1)

           IF((IV(35).EQ.2).AND.(I.EQ.1).AND.(IV(39).EQ.1)) GO TO 53

C----------SKIP OUTPUT OF HEAD IF LAYERS, ROWS OR COLUMNS NOT DIRECTLY

C          SPECIFIED BY USER (NOTE IV(43) = 0 IS USED TO PRINT ALL)

           IF((IV(43).EQ.0).OR.(IV(43).EQ.ITO1)) THEN

C-----------DETERMINE SPATIAL COORDINATES

            CALL XYCORD(DELR,DELC,XC1,YC1,XR1,YR1,XF1,YF1,

     1       XL1,YL1,J,J3,K,NROW,NCOL,CLEN)

            CALL ZCORD(DELL,ZC1,ZR1,ZF1,ZL1,I,NLAY,DATUM)

C-----------HYDRAULIC OUTPUT

            IF(IV(35).EQ.1) THEN 

             NVLAY = I

             HCOR = BUFH(K,J)

            END IF

C-----------PNEUMATIC OUTPUT

            IF(IV(35).EQ.2) THEN 

             NVLAY = I-1

             HCOR = SQRT(BUFH(K,J))/STDATM

            END IF

C-----------SETUP OUTPUT FOR 'HEAD.Txx' FILE (BY LAYERS)

            CC1=XC1

            CC2=YC1

            CC3=ZC1

            NC1=K

            NC2=J

            IF(IV(36).EQ.3) NC2=J3

            NC3=NVLAY

C-----------SETUP FILNAM FOR OUTPUT BY LAYERS

            IF((IV(39).EQ.1).AND.(ICI1.NE.I).AND.(IV(41).NE.1)) THEN

             ICI1  = I

             ISKP  = 0

             CALL FILNAM(IUN,NVLAY,IC1,IS,ISKP)

            END IF

C-----------SETUP COORDINATES FOR OUTPUT BY LAYERS

            IF(IV(39).EQ.1) THEN

             CD1=XC1

             CD2=YC1

             ND1=K

             ND2=J

             IF(IV(36).EQ.3) ND2=J3

            END IF

C-----------SETUP FILNAM FOR OUTPUT BY ROWS

            IF((IV(39).EQ.2).AND.((ICI1.NE.I).OR.(ICJ1.NE.J)).AND.

     1         (IV(41).NE.1)) THEN

             ICI1 = I

             ICJ1 = J

             ISKP = (I-1)*NCOL

C------------FILE DOES NOT REWIND IF NO OTHER FILES ARE BEING OPENED

C            WITH THE SAME UNIT NUMBER

             IF(IV(43).NE.0) ISKP = 0

             CALL FILNAM(IUN,J,IC1,IS,ISKP)

            END IF

C-----------SETUP COORDINATES FOR OUTPUT BY ROWS

            IF(IV(39).EQ.2) THEN

             CD1=XC1

             CD2=ZC1

             ND1=K

             ND2=NVLAY

            END IF

C-----------SETUP FILNAM FOR OUTPUT BY COLUMNS

            IF((IV(39).EQ.3).AND.((ICJ1.NE.J).OR.(ICK1.NE.K)).AND.

     1         (IV(41).NE.1)) THEN

             ICJ1 = J

             ICK1 = K

             ISKP = (I-1)*NROW+(J-1)

C------------FILE DOES NOT REWIND IF NO OTHER FILES ARE BEING OPENED

C            WITH THE SAME UNIT NUMBER

             IF(IV(43).NE.0) ISKP = 0

             CALL FILNAM(IUN,K,IC1,IS,ISKP)

            END IF

C-----------SETUP COORDINATES FOR OUTPUT BY COLUMNS

            IF(IV(39).EQ.3) THEN

             CD1=YC1

             CD2=ZC1

             ND1=J

             ND2=NVLAY

            END IF

C-----------WRITE OUTPUT TO FILE OPENED IN SUBROUTINE FILNAM

            IF(IV(41).NE.1) THEN

             WRITE(28,120) CD1*XW1,CD2*XW1,HCOR*XW4,ND1,ND2

 120         FORMAT(2F15.5,E20.8,2I5)

            END IF

C-----------WRITE OUTPUT TO HEADxx.Txx OR PRESxx.Txx TEXT FILE

            IF(IV(41).EQ.1) THEN

             WRITE(25,121) CC1*XW1,CC2*XW1,CC3*XW1,HCOR*XW4,NC1,

     1                     NC2,NC3

 121         FORMAT(3F15.5,E20.8,3I5)

            END IF

           END IF

 53        CONTINUE

 52       CONTINUE

 51      CONTINUE

        END IF

C

C-------PNEUMATIC OUTPUT FOR BINARY OPTION

C

        IF((IV(35).EQ.2).AND.(IV(41).LT.0)) THEN

         DO 61 J = 1,NROW

          DO 62 K = 1,NCOL

C----------PRESSURE OUTPUT

           BUFH(K,J) = (SQRT(BUFH(K,J))/STDATM)*XW4

 62       CONTINUE

 61      CONTINUE

C--------WRITE OUTPUT TO HEADxx.Txx OR PRESxx.Txx BINARY FILE

C--------WRITE OUT IDENTIFYING INFORMATION

         WRITE(25) KSTPH,KPERH,PERTIMH,TOTIMH,TEXTH,NHCOL,NHROW,NHLAY

C--------WRITE OUT HEAD/PRESSURE VALUES

         WRITE(25) ((BUFH(IC,IR),IC=1,NCOL),IR=1,NROW)

        END IF

 50    CONTINUE

 49   CONTINUE

C

C7----RETURN

C

      RETURN

      END

C

C     ****************

      SUBROUTINE AFLOW(WELLQM,DELR,DELC,DELL,BUFH,BUFF,BUFP,IWELL,

C     ****************

     1 TEXTH,TEXTF,NROW,NCOL,NLAY,NRC,NCC,NLC,MRC,MCC,MLC,NWC,NTC,

     2 DATUM,TAIR,IQ1,CLEN)

C

C1----NOTES :

C

C     1. USE THIS ROUTINE TO GENERATE VOLUMETRIC AND MASS

C        OUTPUT FROM MODFLOW BINARY FLOW FILE

C

C2----SPECIFICATIONS:

C

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(25)

      DIMENSION WELLQM((NWC+NTC),4),DELR(NCOL),DELC(NROW),

     1 DELL(-1:NLAY),BUFH(NCOL,NROW),BUFF(NCC,NRC,NLC),

     2 BUFP(MCC,MRC,MLC),IWELL((NWC+NTC),7),TEXTH(4),TEXTF(4)

      CHARACTER FNAME*12,IU3*6,TEXTH*4,TEXTF*4

      CHARACTER*1 KN1,KN2,KN3,KN4,KN5,KN6,KN7,KN9,KN10,KN11,KN12

C-----ASSIGN VARIABLES

      NWELL = IV(4)

      NTRCH = IV(5)

      ISS   = IV(90)

      XW1   = XU2(1,IU1(1))

      XW2   = XU2(2,IU1(2))

      XW3   = XU2(3,IU1(3))

      XW4   = XU2(4,IU1(4))

      XW6   = XU2(6,IU1(6))

C

C3----DEFINE PHYSICAL CONSTANTS REQUIRED IN PNEUMATIC ANALYSES

C

      IF(IV(35).EQ.2) THEN

       VAS    = 1.76E-4

       TVAS   = 283.15

       VA     = VAS*(TAIR/TVAS)**0.5

       RG     = 8.314E7

       WAIR   = 28.8

       STDATM = 1013250.0

      END IF

C

C4----INPUT FLOW INFORMATION FROM BINARY FILE (IF SPECIFIED)

C

C     NOTES :

C     1. COUNTERS REPRESENT :

C        IC = COUNTER FOR CENTER (0 OR 1), RIGHT (2), FRONT (3)

C             (4) LOWER FACE

C        I  = LAYER NUMBER

C        J  = ROW NUMBER

C        K  = COLUMN NUMBER

C     2. THERE ARE FIVE MAJOR ARRAYS IN THE BINARY FLOW FILE

C         0. FLOW IN / OUT OF STORAGE (TRANSIENT SIMULATIONS ONLY)

C         1. FLOW IN CONSTANT HEAD NODES

C         2. FLOW THROUGH RIGHT FACE OF ACTIVE NODES

C         3. FLOW THROUGH FRONT FACE OF ACTIVE NODES

C         4. FLOW THROUGH LOWER FACE OF ACTIVE NODES

C     3. INPUT EACH SET AND PRINT OUT

C

C-----SPECIFY OUTPUT VARIABLES

      ICC1 = 0

      IF(ISS.EQ.0) ICC1 =-1

      ICI1 = 0

      ICJ1 = -1

      ICK1 = -1

      ICC2 = 0

      IF(ISS.EQ.0) ICC2 =-1

      ICI2 = 0

      ICJ2 = -1

      ICK2 = -1

      REWIND 17

      REWIND 18

C-----ONCE FOR EACH TIME STEP

      DO 50 IS = 1,IV(60)

C------MASS BALANCE OPTION (AVAILABLE IN AIR FLOW ONLY)

       IF((IV(35).EQ.2).AND.((IV(41).GT.0).OR.(IQ1.EQ.2)).AND.

     1    (IV(42).EQ.1)) THEN

C-------OPEN FILE FOR MASS BAL OUTPUT

        CALL FILCNT(IS,KN11,KN12)

        CALL FILCNT(IV(40),KN5,KN6)

        KN1='M'

        KN2='A'

        KN3='S'

        KN4='S'

        KN9='.'

        KN10='T'

        FNAME(14)=KN1//KN2//KN3//KN4//KN5//KN6//KN9//KN10//KN11//KN12

        OPEN(UNIT=24,FILE=FNAME(14),STATUS='UNKNOWN')

        WRITE(24,125)KN5,KN6

        WRITE(24,126)

        WRITE(24,127)

        WRITE(24,128)

 125    FORMAT(T15,'MASS BALANCE / WELL / UNIT OUTPUT FOR',

     1             ' SIMULATION # ',2A1)

 126    FORMAT(T15,'==== =======   ====   ==== ====== ===',

     1             ' ========== =  ==')

 127    FORMAT(//,T10,'MASS FLOW INTO DOMAIN IS POSITIVE')

 128    FORMAT(/,T10,'MASS FLOW OUT OF DOMAIN IS NEGATIVE',//)

C-------MASS BALANCE SET UP

C-------INITIALIZE MASS BALANCE TERMS FOR EACH TIME STEP

C       VARIABLES :

C       AMASSA = MASS THROUGH ATMOSPHERIC LAYER

C       AMASSL = MASS THROUGH LEFT SIDE OF MODEL DOMAIN

C       AMASSB = MASS THROUGH BACK SIDE OF MODEL DOMAIN

C       AMASSR = MASS THROUGH RIGHT SIDE OF MODEL DOMAIN

C       AMASSF = MASS THROUGH FRONT SIDE OF MODEL DOMAIN

C       AMASSW = TOTAL MASS THROUGH WELL/TRENCH IN MODEL DOMAIN

C       WELLQM = INDIVIDUAL MASS THROUGH WELL/TRENCH IN MODEL DOMAIN

C

        AMASSA=0.0

        AMASSL=0.0

        AMASSB=0.0

        AMASSR=0.0

        AMASSF=0.0

        AMASSW=0.0

C-------INITIALIZE WELL / TRENCH FLOWS

        DO 51 IW=1,(NWELL+NTRCH)

         WELLQM(IW,1)=0.0

C        WELLQM(IW,3)=0.0

 51     CONTINUE

       END IF

C------SETUP SINGLE FILES FOR COMBINED FLOW OUTPUT

       IF(IABS(IV(41)).EQ.1) THEN

C

C-------GENERATE OUTPUT FILE EXTENSION USING TIME STEP

        CALL FILCNT(IV(40),KN6,KN7)

        CALL FILCNT(IS,KN11,KN12)

        KN1='F'

        KN2='L'

        KN3='O'

        KN4='W'

        KN5='V'

        KN9='.'

        IF(IV(41).EQ.1) KN10='T'

        IF(IV(41).EQ.-1) KN10='B'

C-------OPEN TEXT FILE FOR CONTINUOUS OUTPUT OF VOLUMETRIC FLOW

        FNAME(16)=KN1//KN2//KN3//KN4//KN5//KN6//KN7//KN9//KN10//

     1           KN11//KN12

        IF(IV(41).EQ.1) THEN

         OPEN(UNIT=26,FILE=FNAME(16),STATUS='UNKNOWN')

        END IF

C-------OPEN BINARY FILE FOR CONTINUOUS OUTPUT OF VOLUMETRIC FLOW

        IF(IV(41).EQ.-1) THEN

         OPEN(UNIT=26,FILE=FNAME(16),FORM='UNFORMATTED',

     1   ACCESS='SEQUENTIAL',STATUS='UNKNOWN')

        END IF

C-------OPEN TEXT FILE FOR CONTINUOUS OUTPUT OF MASS FLOW

        KN5='M'

        FNAME(17)=KN1//KN2//KN3//KN4//KN5//KN6//KN7//KN9//KN10//

     1           KN11//KN12

        IF(IV(41).EQ.1) THEN

         OPEN(UNIT=27,FILE=FNAME(17),STATUS='UNKNOWN')

        END IF

C-------OPEN BINARY FILE FOR CONTINUOUS OUTPUT OF MASS FLOW

        IF(IV(41).EQ.-1) THEN

         OPEN(UNIT=27,FILE=FNAME(17),FORM='UNFORMATTED',

     1   ACCESS='SEQUENTIAL',STATUS='UNKNOWN')

        END IF

       END IF

C------STORE HEAD VALUES TO BUFP FOR TRANSIENT SIMULATIONS

       IF (ISS.EQ.0) THEN 

        DO 57 II = 1,NLAY

         READ(17) KSTPH,KPERH,PERTIMH,TOTIMH,TEXTH,NHCOL,NHROW,NHLAY

         READ(17) ((BUFH(ICL,IRL),ICL=1,NCOL),IRL=1,NROW)

         DO 58 JJ = 1,NROW

          DO 59 KK = 1,NCOL

           BUFP(KK,JJ,II)=BUFH(KK,JJ)

 59       CONTINUE

 58      CONTINUE

 57     CONTINUE

       END IF

C------ONCE FOR EACH FLOW SET (STORAGE (TRANSIENT ONLY), CONSTANT

C      HEAD, RIGHT, FRONT, LOWER)

       ICSS = 1

       IF(ISS.EQ.0) ICSS = 0

       DO 60 IC = ICSS,4

C-------REWIND HEAD/PRESSURE FILE (17) WITH EACH LOOP

        IF (ISS.NE.0) REWIND 17

C-------READ IN IDENTIFYING INFORMATION FOR FLOW FILE (18)

        READ(18) KSTPF,KPERF,TEXTF,NFCOL,NFROW,NFLAY

C-------READ IN FLOW VALUES

        READ(18) BUFF

C

C5------OUTPUT FLOW RATE TO TEXT FILE

C

        IF(IV(41).GT.0) THEN

         DO 61 I=1,NLAY

C---------INPUT PRESSURE DATA FOR PNEUMATIC, STEADY STATE ANALYSES ONLY

C---------(NEEDED FOR CORRECTION TO VOLUMETRIC FLOW)

          IF((IV(35).EQ.2).AND.(ISS.NE.0)) THEN

           READ(17) KSTPH,KPERH,PERTIMH,TOTIMH,TEXTH,NHCOL,NHROW,NHLAY

           READ(17) ((BUFH(ICL,IRL),ICL=1,NCOL),IRL=1,NROW)

           IV(98)=KSTPH

           IV(98)=KPERH

           IV(98)=PERTIMH

           IV(98)=INT(TOTIMH)

           IV(98)=NHCOL

           IV(98)=NHROW

           IV(98)=NHLAY

          END IF

          DO 62 J = 1,NROW

           DO 63 K = 1,NCOL

C

C-----------PERFORM MASS BALANCE CALCULATIONS FOR AIR FLOW

C

C            NOTES :

C            1. MASS INTO DOMAIN +VE

C               MASS OUT OF DOMAIN -VE

C

C-----------TEST FOR MASS BALANCE SELECTION (IV(42)=1), AIR FLOW

C           ANALYSIS (IV(35)=2), AND CONSTANT HEAD (IC=1) OUTPUT

            IF((IV(42).EQ.1).AND.(IV(35).EQ.2).AND.(IC.EQ.1)) THEN 

             VR2   = WAIR/(2.0*VA*RG*TAIR)

             FMASS = BUFF(K,J,I)*VR2

C------------SUM MASS THROUGH ATMOSPHERIC LAYER

             IF(I.EQ.1) THEN

              AMASSA=AMASSA+FMASS

             END IF

C------------SUM MASS THROUGH LEFT SIDE OF MODEL DOMAIN

             IF((I.GT.1).AND.(K.EQ.1)) THEN

              AMASSL=AMASSL+FMASS

             END IF

C------------SUM MASS THROUGH BACK SIDE OF MODEL DOMAIN

             IF((I.GT.1).AND.(J.EQ.1)) THEN

              AMASSB=AMASSB+FMASS

             END IF

C------------SUM MASS THROUGH RIGHT SIDE OF MODEL DOMAIN

             IF((I.GT.1).AND.(K.EQ.NCOL)) THEN

              AMASSR=AMASSR+FMASS

             END IF

C------------SUM MASS THROUGH FRONT SIDE OF MODEL DOMAIN

             IF((I.GT.1).AND.(J.EQ.NROW)) THEN

              AMASSF=AMASSF+FMASS

             END IF

C------------SUM MASS THROUGH ALL WELLS/TRENCHES OF MODEL DOMAIN

             IF((I.GT.1).AND.(J.GT.1).AND.(J.LT.NROW).AND.

     1          (K.GT.1).AND.(K.LT.NCOL)) THEN

              AMASSW=AMASSW+FMASS

             END IF

C------------SUM MASS THROUGH INDIVIDUAL WELLS/TRENCHES OF DOMAIN

             DO 65 IW = 1,NWELL+NTRCH

              IF ((J.GE.IWELL(IW,2)).AND.(J.LE.IWELL(IW,3)).AND.

     1            (K.GE.IWELL(IW,4)).AND.(K.LE.IWELL(IW,5)).AND.

     1            (I.GE.IWELL(IW,6)).AND.(I.LE.IWELL(IW,7))) THEN

C--------------MASS FLOW THRO WELL

               WELLQM(IW,1)=WELLQM(IW,1)+FMASS

C--------------VOLUMETRIC FLOW THRO WELL

C              VV1   = 2.0*VA*SQRT(BUFH(K,J))

C              FVOLM = BUFF(K,J,I)/VV1

C              WELLQM(IW,3)=WELLQM(IW,3)+FVOLM

C--------------PRESSURE IN WELL

C              WELLQM(IW,4)=(SQRT(BUFH(K,J))/STDATM)*XW4

              END IF

 65          CONTINUE

            END IF

C-----------SET UP FLAGS NEEDED TO TEST FOR OUTPUT

            IF(IV(39).EQ.1) ITO1 = I

            IF(IV(39).EQ.2) ITO1 = J

            IF(IV(39).EQ.3) ITO1 = K

C-----------SKIP OUTPUT OF FLOW IN SUPERIMPOSED ATMSOPHERIC LAYER

C           (I=1), IN AIR FLOW SIMULATIONS (IV(35)=2), FOR OUTPUT

C           BY LAYERS (IV(39)=1)

C           RETAIN FOR SECTIONAL OUTPUT

            IF((IV(35).EQ.2).AND.(I.EQ.1).AND.(IV(39).EQ.1)) GO TO 64

C-----------SKIP OUTPUT OF FLOW IF LAYERS, ROWS OR COLUMNS NOT DIRECTLY

C           SPECIFIED BY USER (NOTE IV(43) = 0 IS USED TO PRINT ALL)

            IF((IV(43).EQ.0).OR.(IV(43).EQ.ITO1)) THEN

C------------DETERMINE SPATIAL COORDINATES

             CALL XYCORD(DELR,DELC,XC1,YC1,XR1,YR1,XF1,YF1,

     1        XL1,YL1,J,J3,K,NROW,NCOL,CLEN)

             CALL ZCORD(DELL,ZC1,ZR1,ZF1,ZL1,I,NLAY,DATUM)

             IVR1 = 0

             IVR2 = 0

C------------HYDRAULIC OUTPUT

             IF(IV(35).EQ.1) THEN 

              NVLAY = I

C-------------VOLUMETRIC FLOW ONLY FOR HYDRAULIC SIMULATIONS

              FCOR1 = BUFF(K,J,I)

              IVR1 = 1

             END IF

C------------PNEUMATIC OUTPUT

             IF(IV(35).EQ.2) THEN 

              NVLAY = I-1

C-------------VOLUMETRIC FLOW DETERMINATION

              IF(ISS.EQ.0) VR1 = 2.0*VA*SQRT(BUFP(K,J,I))

              IF(ISS.NE.0) VR1 = 2.0*VA*SQRT(BUFH(K,J))

              FCOR1 = BUFF(K,J,I)/VR1

              IVR1  = 1

C-------------MASS FLOW DETERMINATION

              VR2   = WAIR/(2.0*VA*RG*TAIR)

              FCOR2 = BUFF(K,J,I)*VR2

              IVR2  = 1

             END IF

C

C------------SETUP COORDINATES FOR OUTPUT TO FLOWx.Txx (CONTINUOUS)

C

C------------NEGLECT OFFSETS (IV(37)=2)

             IF(IV(37).EQ.2) THEN

              CC1=XC1

              CC2=YC1

              CC3=ZC1

              NC1=K

              NC2=J3

              NC3=NVLAY

             END IF

C------------NEGLECT OFFSETS FOR FLOW AT CELL CENTERS (IC=1)

             IF(IC.LE.1) THEN

              CC1=XC1

              CC2=YC1

              CC3=ZC1

              NC1=K

              NC2=J3

              NC3=NVLAY

             END IF

C------------INCLUDE OFFSETS (IV(37)=1)

             IF(IV(37).EQ.1) THEN

C-------------FOR FLOW THROUGH RIGHT HAND FACES (IC=2)

              IF(IC.EQ.2) THEN

               CC1=XR1

               CC2=YR1

               CC3=ZR1

               NC1=K

               NC2=J3

               NC3=NVLAY

              END IF

C-------------FOR FLOW THROUGH FRONT FACES (IC=3)

              IF(IC.EQ.3) THEN

               CC1=XF1

               CC2=YF1

               CC3=ZF1

               NC1=K

               NC2=J3

               NC3=NVLAY

              END IF

C-------------FOR FLOW THROUGH LOWER FACES (IC=4)

              IF(IC.EQ.4) THEN

               CC1=XL1

               CC2=YL1

               CC3=ZL1

               NC1=K

               NC2=J3

               NC3=NVLAY

              END IF

             END IF

C

C------------SETUP COORDINATES FOR OUTPUT BY LAYERS

C

C------------NEGLECT OFFSETS (IV(37)=2) FOR ALL FLOW CASES

C            OUTPUT BY LAYER (IV(39)=1)

             IF((IV(39).EQ.1).AND.(IV(37).EQ.2)) THEN

              CD1=XC1

              CD2=YC1

              ND1=K

              ND2=J3

             END IF

C------------NEGLECT OFFSETS FOR FLOW AT CELL CENTERS (IC=1)

C            REGARDLESS OF OFFSET SETTINGS (IV(37)) FOR FLOW

C            OUTPUT BY LAYER (IV(39)=1)

             IF((IV(39).EQ.1).AND.(IC.LE.1)) THEN

              CD1=XC1

              CD2=YC1

              ND1=K

              ND2=J3

             END IF

C------------INCLUDE OFFSETS (IV(37)=1) FOR FLOW THROUGH

C            RIGHT HAND FACES (IC=2) OUTPUT BY LAYER (IV(39)=1)

             IF((IV(39).EQ.1).AND.(IC.EQ.2).AND.(IV(37).EQ.1)) THEN

              CD1=XR1

              CD2=YR1

              ND1=K

              ND2=J3

             END IF

C------------INCLUDE OFFSETS (IV(37)=1) FOR FLOW THROUGH

C            FRONT FACES (IC=3) OUTPUT BY LAYER (IV(39)=1)

             IF((IV(39).EQ.1).AND.(IC.EQ.3).AND.(IV(37).EQ.1)) THEN

              CD1=XF1

              CD2=YF1

              ND1=K

              ND2=J3

             END IF

C------------INCLUDE OFFSETS (IV(37)=1) FOR FLOW THROUGH

C            LOWER FACES (IC=4) OUTPUT BY LAYER (IV(39)=1)

             IF((IV(39).EQ.1).AND.(IC.EQ.4).AND.(IV(37).EQ.1)) THEN

              CD1=XL1

              CD2=YL1

              ND1=K

              ND2=J3

             END IF

C

C------------SETUP COORDINATES FOR OUTPUT BY ROWS

C

C------------NEGLECT OFFSETS (IV(37)=2) FOR ALL FLOW CASES

C            OUTPUT BY ROWS (IV(39)=2)

             IF((IV(39).EQ.2).AND.(IV(37).EQ.2)) THEN

              CD1=XC1

              CD2=ZC1

              ND1=K

              ND2=NVLAY

             END IF

C------------NEGLECT OFFSETS FOR FLOW AT CELL CENTERS (IC=1)

C            REGARDLESS OF OFFSET SETTINGS (IV(37)) FOR FLOW

C            OUTPUT BY ROW (IV(39)=2)

             IF((IV(39).EQ.2).AND.(IC.LE.1)) THEN

              CD1=XC1

              CD2=ZC1

              ND1=K

              ND2=NVLAY

             END IF

C------------INCLUDE OFFSETS (IV(37)=1) FOR FLOW THROUGH

C            RIGHT HAND FACES (IC=2) OUTPUT BY ROW (IV(39)=2)

             IF((IV(39).EQ.2).AND.(IC.EQ.2).AND.(IV(37).EQ.1)) THEN

              CD1=XR1

              CD2=ZR1

              ND1=K

              ND2=NVLAY

             END IF

C------------INCLUDE OFFSETS (IV(37)=1) FOR FLOW THROUGH

C            FRONT FACES (IC=3) OUTPUT BY ROW (IV(39)=2)

             IF((IV(39).EQ.2).AND.(IC.EQ.3).AND.(IV(37).EQ.1)) THEN

              CD1=XF1

              CD2=ZF1

              ND1=K

              ND2=NVLAY

             END IF

C------------INCLUDE OFFSETS (IV(37)=1) FOR FLOW THROUGH

C            LOWER FACES (IC=4) OUTPUT BY ROW (IV(39)=2)

             IF((IV(39).EQ.2).AND.(IC.EQ.4).AND.(IV(37).EQ.1)) THEN

              CD1=XL1

              CD2=ZL1

              ND1=K

              ND2=NVLAY

             END IF

C

C------------SETUP COORDINATES FOR OUTPUT BY COLUMNS

C

C------------NEGLECT OFFSETS (IV(37)=2) FOR ALL FLOW CASES

C            OUTPUT BY COLUMNS (IV(39)=2)

             IF((IV(39).EQ.3).AND.(IV(37).EQ.2)) THEN

              CD1=YC1

              CD2=ZC1

              ND1=J

              ND2=NVLAY

             END IF

C------------NEGLECT OFFSETS FOR FLOW AT CELL CENTERS (IC=1)

C            REGARDLESS OF OFFSET SETTINGS (IV(37)) FOR FLOW

C            OUTPUT BY COLUMN (IV(39)=3)

             IF((IV(39).EQ.3).AND.(IC.LE.1)) THEN

              CD1=YC1

              CD2=ZC1

              ND1=J

              ND2=NVLAY

             END IF

C------------INCLUDE OFFSETS (IV(37)=1) FOR FLOW THROUGH

C            RIGHT HAND FACES (IC=2) OUTPUT BY COLUMN (IV(39)=3)

             IF((IV(39).EQ.3).AND.(IC.EQ.2).AND.(IV(37).EQ.1)) THEN

              CD1=YR1

              CD2=ZR1

              ND1=J

              ND2=NVLAY

             END IF

C------------INCLUDE OFFSETS (IV(37)=1) FOR FLOW THROUGH

C            FRONT FACES (IC=3) OUTPUT BY COLUMN (IV(39)=3)

             IF((IV(39).EQ.3).AND.(IC.EQ.3).AND.(IV(37).EQ.1)) THEN

              CD1=YF1

              CD2=ZF1

              ND1=J

              ND2=NVLAY

             END IF

C------------INCLUDE OFFSETS (IV(37)=1) FOR FLOW THROUGH

C            LOWER FACES (IC=4) OUTPUT BY COLUMN (IV(39)=3)

             IF((IV(39).EQ.3).AND.(IC.EQ.4).AND.(IV(37).EQ.1)) THEN

              CD1=YL1

              CD2=ZL1

              ND1=J

              ND2=NVLAY

             END IF

C

C------------WRITE OUT VOLUMETRIC FLOW RATES (HYDRAULIC AND PNEUMATIC)

C

             IF(IVR1.EQ.1) THEN

C-------------FLAG FOR VOLUMETRIC FLOW RATE OUTPUT

              IV(45)=3

C-------------SPECIFY UNIT NUMBER FOR VOLUMETRIC OUTPUT

              IUN=29

C-------------SETUP FILNAM FOR OUTPUT BY LAYERS

              IF((IV(39).EQ.1).AND.((ICI1.NE.I).OR.(ICC1.NE.IC)).AND.

     1           (IV(41).NE.1)) THEN

               ICI1 = I

               ICC1 = IC

               ISKP = 0

               CALL FILNAM(IUN,NVLAY,IC,IS,ISKP)

              END IF

C-------------SETUP FILNAM FOR OUTPUT BY ROWS

              IF((IV(39).EQ.2).AND.((ICI1.NE.I).OR.(ICJ1.NE.J)).AND.

     1           (IV(41).NE.1)) THEN

               ICI1 = I

               ICJ1 = J

               ISKP = (I-1)*NCOL

C--------------FILE DOES NOT REWIND IF NO OTHER FILES ARE BEING

C              OPENED WITH THE SAME UNIT NUMBER

               IF(IV(43).NE.0) ISKP = 0

               CALL FILNAM(IUN,J,IC,IS,ISKP)

              END IF

C-------------SETUP FILNAM FOR OUTPUT BY COLUMNS

              IF((IV(39).EQ.3).AND.((ICJ1.NE.J).OR.(ICK1.NE.K)).AND.

     1           (IV(41).NE.1))THEN

               ICJ1 = J

               ICK1 = K

               ISKP = (I-1)*NROW+(J-1)

C--------------FILE DOES NOT REWIND IF NO OTHER FILES ARE BEING

C              OPENED WITH THE SAME UNIT NUMBER

               IF(IV(43).NE.0) ISKP = 0

               CALL FILNAM(IUN,K,IC,IS,ISKP)

              END IF

C-------------WRITE VOLUMETRIC FLOW OUTPUT TO FILE OPENED IN

C             SUBROUTINE FILENAM

              IF(IV(41).NE.1) THEN

               WRITE(29,130) CD1*XW1,CD2*XW1,FCOR1*XW2/XW3,ND1,ND2

              END IF

C-------------WRITE OUTPUT TO FLOWVxx.Txx TEXT FILE

              IF(IV(41).EQ.1) THEN

               WRITE(26,131) CC1*XW1,CC2*XW1,CC3*XW1,FCOR1*XW2/XW3,

     1                       NC1,NC2,NC3

              END IF

             END IF

 130         FORMAT(2F15.5,E20.8,2I5)

 131         FORMAT(3F15.5,E20.8,3I5)

C

C------------WRITE OUT MASS FLOW RATES (PNEUMATIC ONLY)

C

             IF(IVR2.EQ.1) THEN

C-------------FLAG FOR MASS FLOW RATE OUTPUT

              IV(45)=4

C-------------SPECIFY UNIT NUMBER FOR MASS OUTPUT

              IUN=30

C-------------SETUP FILNAM FOR OUTPUT BY LAYERS

              IF((IV(39).EQ.1).AND.((ICI2.NE.I).OR.(ICC2.NE.IC)).AND.

     1           (IV(41).NE.1)) THEN

               ICI2 = I

               ICC2 = IC

               ISKP = 0

               CALL FILNAM(IUN,NVLAY,IC,IS,ISKP)

              END IF

C-------------SETUP FILNAM FOR OUTPUT BY ROWS

              IF((IV(39).EQ.2).AND.((ICI2.NE.I).OR.(ICJ2.NE.J)).AND.

     1           (IV(41).NE.1)) THEN

               ICI2 = I

               ICJ2 = J

               ISKP = (I-1)*NCOL

C--------------FILE DOES NOT REWIND IF NO OTHER FILES ARE BEING

C              OPENED WITH THE SAME UNIT NUMBER

               IF(IV(43).NE.0) ISKP = 0

               CALL FILNAM(IUN,J,IC,IS,ISKP)

              END IF

C-------------SETUP FILNAM FOR OUTPUT BY COLUMNS

              IF((IV(39).EQ.3).AND.((ICJ2.NE.J).OR.(ICK2.NE.K)).AND.

     1           (IV(41).NE.1)) THEN

               ICJ2 = J

               ICK2 = K

               ISKP = (I-1)*NROW+(J-1)

C--------------FILE DOES NOT REWIND IF NO OTHER FILES ARE BEING

C              OPENED WITH THE SAME UNIT NUMBER

               IF(IV(43).NE.0) ISKP = 0

               CALL FILNAM(IUN,K,IC,IS,ISKP)

              END IF

C-------------WRITE MASS FLOW OUTPUT TO FILE OPENED IN

C             SUBROUTINE FILENA

              IF(IV(41).NE.1) THEN

               WRITE(30,130) CD1*XW1,CD2*XW1,FCOR2*XW6/XW3,ND1,ND2

              END IF

C-------------WRITE OUTPUT TO FLOWMxx.Txx TEXT FILE

              IF(IV(41).EQ.1) THEN

               WRITE(27,131) CC1*XW1,CC2*XW1,CC3*XW1,FCOR2*XW6/XW3,

     1                       NC1,NC2,NC3

              END IF

             END IF

            END IF

 64         CONTINUE

 63        CONTINUE

 62       CONTINUE

 61      CONTINUE

        END IF

C

C6------PNEUMATIC OUTPUT FOR BINARY OPTION

C

        IF((IV(35).EQ.2).AND.(IV(41).LT.0)) THEN

         DO 71 I=1,NLAY

C---------VOLUMETRIC FLOW DETERMINATION

          IF(IQ1.EQ.1) THEN

C----------NEED PRESSURE FOR CORRECTION TO VOLUMETRIC FLOW ONLY

           IF(ISS.NE.0) THEN

            READ(17) KSTPH,KPERH,PERTIMH,TOTIMH,TEXTH,NHCOL,NHROW,

     1              NHLAY

            READ(17) ((BUFH(ICL,IRL),ICL=1,NCOL),IRL=1,NROW)

           END IF

           DO 72 J = 1,NROW

            DO 73 K = 1,NCOL

             IF (ISS.NE.0) VR1 = 2.0*VA*SQRT(BUFH(K,J))*(XW3/XW2)

             IF (ISS.EQ.0) VR1 = 2.0*VA*SQRT(BUFP(K,J,I))*(XW3/XW2)

             BUFF(K,J,I) = BUFF(K,J,I)/VR1

 73         CONTINUE

 72        CONTINUE

          END IF

C---------MASS FLOW DETERMINATION

          IF(IQ1.EQ.2) THEN

           DO 74 J = 1,NROW

            DO 75 K = 1,NCOL

             VR2 = (XW6/XW3)*WAIR/(2.0*VA*RG*TAIR)

             BUFF(K,J,I) = BUFF(K,J,I)*VR2

C------------MASS BALANCE DETERMINATION (USE CONST HEAD NODES (IC=1))

             IF((IV(42).EQ.1).AND.(IC.EQ.1)) THEN 

              FMASS = BUFF(K,J,I)/(XW6/XW3)

C-------------SUM MASS THROUGH ATMOSPHERIC LAYER

              IF(I.EQ.1) THEN

               AMASSA=AMASSA+FMASS

              END IF

C-------------SUM MASS THROUGH LEFT SIDE OF MODEL DOMAIN

              IF((I.GT.1).AND.(K.EQ.1)) THEN

               AMASSL=AMASSL+FMASS

              END IF

C-------------SUM MASS THROUGH BACK SIDE OF MODEL DOMAIN

              IF((I.GT.1).AND.(J.EQ.1)) THEN

               AMASSB=AMASSB+FMASS

              END IF

C-------------SUM MASS THROUGH RIGHT SIDE OF MODEL DOMAIN

              IF((I.GT.1).AND.(K.EQ.NCOL)) THEN

               AMASSR=AMASSR+FMASS

              END IF

C-------------SUM MASS THROUGH FRONT SIDE OF MODEL DOMAIN

              IF((I.GT.1).AND.(J.EQ.NROW)) THEN

               AMASSF=AMASSF+FMASS

              END IF

C-------------SUM MASS THROUGH ALL WELLS/TRENCHES OF MODEL DOMAIN

              IF((I.GT.1).AND.(J.GT.1).AND.(J.LT.NROW).AND.

     1           (K.GT.1).AND.(K.LT.NCOL)) THEN

               AMASSW=AMASSW+FMASS

              END IF

C-------------SUM MASS THROUGH INDIVIDUAL WELLS/TRENCHES OF DOMAIN

              DO 76 IW = 1,NWELL+NTRCH

               IF ((J.GE.IWELL(IW,2)).AND.(J.LE.IWELL(IW,3)).AND.

     1             (K.GE.IWELL(IW,4)).AND.(K.LE.IWELL(IW,5)).AND.

     1             (I.GE.IWELL(IW,6)).AND.(I.LE.IWELL(IW,7))) THEN

C---------------MASS FLOW THRO WELL

                WELLQM(IW,1)=WELLQM(IW,1)+FMASS

               END IF

 76           CONTINUE

             END IF

 75         CONTINUE

 74        CONTINUE

          END IF

 71      CONTINUE

C--------VOLUMETRIC FLOW OUTPUT TO BINARY FILE

         IF(IQ1.EQ.1) THEN

C---------WRITE OUT IDENTIFYING INFORMATION FOR FLOW FILE (16)

          WRITE(26) KSTPF,KPERF,TEXTF,NFCOL,NFROW,NFLAY

C---------WRITE OUT VOLUMETRIC FLOW VALUES

          WRITE(26) BUFF

         END IF

C--------MASS FLOW OUTPUT TO BINARY FILE

         IF(IQ1.EQ.2) THEN

C---------WRITE OUT IDENTIFYING INFORMATION FOR FLOW FILE (16)

          WRITE(27) KSTPF,KPERF,TEXTF,NFCOL,NFROW,NFLAY

C---------WRITE OUT FLOW VALUES

          WRITE(27) BUFF

         END IF

        END IF

 60    CONTINUE

C

C7-----OUTPUT MASS BALANCE RESULTS AT END OF EACH TIME STEP

C

       IF((IV(35).EQ.2).AND.((IV(41).GT.0).OR.(IQ1.EQ.2)).AND.

     1    (IV(42).EQ.1)) THEN

C-------TOTAL MASS IN/OUT FOR LATERAL RECHARGE

        AMLR=AMASSL+AMASSB+AMASSR+AMASSF

C-------TOTAL MASS IN/OUT FOR ATMOSPHERIC RECHARGE

        AMAR=AMASSA

C-------TOTAL MASS ENTERING / LEAVING DOMAIN

        AMTR=AMLR+AMAR

C-------TOTAL MASS THROUGH BOUNDARIES - TOTAL MASS THROUGH WELLS

        AMMB=AMTR+AMASSW

C-------AVERAGE TOTAL MASS ENTERING / LEAVING DOMAIN

        AMXX=0.5*(ABS(AMTR)+ABS(AMASSW))

C-------NORMALIZED MASS BALANCE

        AMYY=AMMB/AMXX*100.0

C-------PERCENT RECHARGE FROM ATMOSPHERE

        AMPAR=ABS(AMAR/AMXX*100.0)

C-------PERCENT RECHARGE FROM LATERAL DOMAIN

        AMPRL=100.0-AMPAR

C-------UNIT CORRECTION

        AMOA=AMASSA*XW6/XW3

        AMOL=AMASSL*XW6/XW3

        AMOB=AMASSB*XW6/XW3

        AMOR=AMASSR*XW6/XW3

        AMOF=AMASSF*XW6/XW3

        AMOT=AMTR*XW6/XW3

        AMOW=AMASSW*XW6/XW3

        AMOM=AMMB*XW6/XW3

C-------OUTPUT MASS BALANCE RESULTS

        WRITE(24,132)IS

        WRITE(24,133)AMOA,IU3(6,IU1(6)),IU3(3,IU1(3))

        WRITE(24,134)AMOL,IU3(6,IU1(6)),IU3(3,IU1(3))

        WRITE(24,135)AMOB,IU3(6,IU1(6)),IU3(3,IU1(3))

        WRITE(24,136)AMOR,IU3(6,IU1(6)),IU3(3,IU1(3))

        WRITE(24,137)AMOF,IU3(6,IU1(6)),IU3(3,IU1(3))

        WRITE(24,138)AMOT,IU3(6,IU1(6)),IU3(3,IU1(3))

        WRITE(24,139)AMOW,IU3(6,IU1(6)),IU3(3,IU1(3))

        WRITE(24,140)AMOM,IU3(6,IU1(6)),IU3(3,IU1(3))

        WRITE(24,141)AMPAR

        WRITE(24,142)AMPRL

        WRITE(24,143)AMYY

 132    FORMAT(/,T5,'MASS BALANCE OUTPUT FOR TIME STEP : ',I2)

 133    FORMAT(/,T5,'MASS FLOW RATE THROUGH MODEL ATMOSPHERIC ',

     1              'LAYER        : ',E12.4,' ',A2,'/',A3)

 134    FORMAT(T5,'MASS FLOW RATE THROUGH LEFT SIDE OF ',

     1            'MODEL DOMAIN      : ',E12.4,' ',A2,'/',A3)

 135    FORMAT(T5,'MASS FLOW RATE THROUGH BACK SIDE OF ',

     1            'MODEL DOMAIN      : ',E12.4,' ',A2,'/',A3)

 136    FORMAT(T5,'MASS FLOW RATE THROUGH RIGHT SIDE OF ',

     1              'MODEL DOMAIN     : ',E12.4,' ',A2,'/',A3)

 137    FORMAT(T5,'MASS FLOW RATE THROUGH FRONT SIDE OF ',

     1            'MODEL DOMAIN     : ',E12.4,' ',A2,'/',A3)

 138    FORMAT(/,T5,'TOTAL MASS FLOW RATE ACROSS MODEL ',

     1            'BOUNDARIES          : ',E12.4,' ',A2,'/',A3)

 139    FORMAT(T5,'TOTAL MASS FLOW RATE THROUGH WELLS / ',

     1            'TRENCHES         : ',E12.4,' ',A2,'/',A3)

 140    FORMAT(T5,'FLOW ACROSS BOUNDARIES - FLOW THROUGH ',

     1            'WELLS/TRENCHES  : ',E12.4,' ',A2,'/',A3)

 141    FORMAT(/,T5,'PERCENT AIR RECHARGE FROM ATMOSPHERE ',

     1            '                 : ', F10.2,' %')

 142    FORMAT(T5,'PERCENT AIR RECHARGE FROM LATERAL ',

     1            'BOUNDARIES          : ', F10.2,' %')

 143    FORMAT(T5,'NORMALIZED MASS BALANCE (FLOW IN-FLOW ',

     1            'OUT)/TOTAL FLOW : ',F10.2,' %')

C

C8------OUTPUT WELL / TRENCH FLOWS

C

C-------MASS FLOW IN WELL / TRENCH

C

        WRITE(24,161)IS

C-------MASS FLOW THORUGH WELLS

        DO 80 IW = 1,NWELL

         WRITE(24,162)IWELL(IW,1),WELLQM(IW,1)*XW6/XW3,

     1     IU3(6,IU1(6)),IU3(3,IU1(3))

 80     CONTINUE

C-------MASS FLOW THORUGH TRENCHES

        WRITE(24,175)

        DO 81 IT = 1+NWELL,NTRCH+NWELL

         WRITE(24,163)IWELL(IT,1),WELLQM(IT,1)*XW6/XW3,

     1        IU3(6,IU1(6)),IU3(3,IU1(3))

 81     CONTINUE

 161    FORMAT(//,T5,'MASS FLOW RATES THROUGH WELLS/TRENCHES FOR',

     1              ' TIME STEP  : ',I2,/)

 162    FORMAT(T5,'MASS FLOW RATE THROUGH WELL NUMBER',I5,

     1              '               : ',E12.4,' ',A2,'/',A3)

 163    FORMAT(T5,'MASS FLOW RATE THROUGH TRENCH NUMBER',I5,

     1              '             : ',E12.4,' ',A2,'/',A3)

C

C-------VOLUMETRIC FLOW IN WELL / TRENCH

C

        WRITE(24,165)IS

C-------VOLUMETRIC FLOW THORUGH WELLS

        DO 90 IW = 1,NWELL

         FVOLM = (WELLQM(IW,1)*RG*TAIR*XW2)/(WAIR*WELLQM(IW,2)*XW3)

         WRITE(24,166)IWELL(IW,1),FVOLM,IU3(2,IU1(2)),IU3(3,IU1(3))

C        WRITE(24,166)IWELL(IW,1),WELLQM(IW,3)*XW2/XW3,

C    1      IU3(2,IU1(2)),IU3(3,IU1(3))

 90     CONTINUE

C-------VOLUMETRIC FLOW THORUGH TRENCHES

        WRITE(24,175)

        DO 91 IT = 1+NWELL,NTRCH+NWELL

         FVOLM = (WELLQM(IT,1)*RG*TAIR*XW2)/(WAIR*WELLQM(IT,2)*XW3)

         WRITE(24,167)IWELL(IT,1),FVOLM,IU3(2,IU1(2)),IU3(3,IU1(3))

C        WRITE(24,167)IWELL(IT,1),WELLQM(IT,3)*XW2/XW3,

C    1      IU3(6,IU1(6)),IU3(3,IU1(3))

 91     CONTINUE

 165    FORMAT(//,T5,'VOLUMETRIC FLOW RATES THROUGH WELLS/TRENCHES',

     1              ' FOR TIME STEP : ',I2,/)

 166    FORMAT(T5,'VOLUMETRIC FLOW RATE THROUGH WELL NUMBER',I5,

     1              '         : ',E12.4,' ',A4,'/',A3)

 167    FORMAT(T5,'VOLUMETRIC FLOW RATE THROUGH TRENCH NUMBER',I5,

     1              '       : ',E12.4,' ',A4,'/',A3)

C

C-------PRESSURE IN WELL / TRENCH

C

        WRITE(24,171)IS

C-------PRESSURE IN WELLS

        DO 95 IW = 1,NWELL

         WRITE(24,172)IWELL(IW,1),WELLQM(IW,2)/STDATM*XW4,

     1     IU3(4,IU1(4))

C        WRITE(24,172)IWELL(IW,1),WELLQM(IW,4),IU3(4,IU1(4))

 95     CONTINUE

C-------PRESSURE IN TRENCHES

        WRITE(24,175)

        DO 96 IT = 1+NWELL,NTRCH+NWELL

         WRITE(24,173)IWELL(IT,1),WELLQM(IT,2)/STDATM*XW4,

     1     IU3(4,IU1(4))

C        WRITE(24,173)IWELL(IT,1),WELLQM(IT,4),IU3(4,IU1(4))

 96     CONTINUE

 171    FORMAT(//,T5,'PRESSURE IN WELLS / TRENCHES FOR',

     1              ' TIME STEP : ',I2,/)

 172    FORMAT(T5,'PRESSURE IN WELL NUMBER',I5,'           ',

     1              '               : ',E12.4,' ',A4)

 173    FORMAT(T5,'PRESSURE IN TRENCH NUMBER',I5,'           ',

     1              '             : ',E12.4,' ',A4)

 175    FORMAT(/)

C------END OF MASS BAL OUTPUT

       END IF

C-----TIME STEP LOOP

 50   CONTINUE

C

C9----OUTPUT UNITS TO MASS BALANCE FILE

C

      IF((IV(35).EQ.2).AND.((IV(41).GT.0).OR.(IQ1.EQ.2)).AND.

     1   (IV(42).EQ.1)) THEN

C------OUTPUT DESCRIPTON OF UNIT SYSTEM

       WRITE(24,180)

       WRITE(24,181)IU3(1,IU1(1))

       WRITE(24,182)IU3(2,IU1(2))

       WRITE(24,183)IU3(3,IU1(3))

       WRITE(24,184)IU3(4,IU1(4))

       WRITE(24,185)IU3(5,IU1(5))

       WRITE(24,186)IU3(6,IU1(6))

       WRITE(24,187)IU3(7,IU1(7))

      END IF

 180  FORMAT(///,T10,'SUMMARY OF UNITS USED IN SIMULATION')

 181  FORMAT(/,T10,'LENGTH UNIT SYSTEM       :  ',A4)

 182  FORMAT(/,T10,'VOLUME UNIT SYSTEM       :  ',A4)

 183  FORMAT(/,T10,'TIME UNIT SYSTEM         :  ',A4)

 184  FORMAT(/,T10,'PRESSURE UNIT SYSTEM     :  ',A4)

 185  FORMAT(/,T10,'TEMPERATURE UNIT SYSTEM  :  ',A4)

 186  FORMAT(/,T10,'MASS UNIT SYSTEM         :  ',A4)

 187  FORMAT(/,T10,'PERMEABILITY UNIT SYSTEM :  ',A4)

C

C10---CLOSE FILES

C

      CLOSE(26)

      CLOSE(27)

C

C11---RETURN

C

      RETURN

      END

C

C

C     *****************

      SUBROUTINE R2FLOW(DELR,DELC,DELL,BUFF,SCRD,NCRD,NROW,NCOL,

C     *****************

     1      NLAY,NRC,NCC,IRCM)

C

C1----NOTES :

C

C     1. USE THIS ROUTINE TO COMBINE 1D FLOWS TO GENERATE

C        2D RESULTANT FLOWS

C

C2----SPECIFICATIONS:

C

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(25)

      DIMENSION DELR(NCOL),DELC(NROW),DELL(-1:NLAY),BUFF(NCC,NRC,2),

     1          SCRD(4,IRCM),NCRD(4,IRCM)

      CHARACTER FNAME*12,IU3*6

C-----ASSIGN VARIABLES

      NROW =IV(1)

      NCOL =IV(2)

      NLAY =IV(3)

      IOUT =IV(82)

C

C3----DEFINE PHYSICAL CONSTANTS REQUIRED IN PNEUMATIC ANALYSES

C

C-----CONVERSION FOR RADIANS TO DEGREES

      PIRD   = 57.29578

C

C4----COMBINE 1-D FLOW VECTORS TO GET 2-D RESULTANTS

C

C     VARIABLES :

C     

C        ICI1   = COUNTER TRACKING LAYER NUMBER

C        ICJ1   = COUNTER TRACKING ROW NUMBER

C        ICK1   = COUNTER TRACKING COLUMN NUMBER

C        IC1    = MARKER DESIGNATING CENTER (0 OR 1), RIGHT (2),

C                 FRONT (3), BOTTOM (4), X-Y PLANE (5),

C                 Z-X PLANE (6), OR, Z-Y PLANE (7)

C        ICN    = MARKER DESIGNATING ONE LOOP FOR HYDRAULIC RUNS

C                 OR TWO LOOPS FOR PNEUMATIC RUNS

C        IFGI   = MARKER USED TO SKIP CERTAIN LAYER OUTPUT IN

C                 ATMOSPHERIC LAYER IN PNEUMATIC SIMULATIONS

C        IFGJ   = MARKER USED TO SKIP CERTAIN ROW OUTPUT IN

C                 ATMOSPHERIC LAYER IN PNEUMATIC SIMULATIONS

C        IFGK   = MARKER USED TO SKIP CERTAIN COLUMN OUTPUT IN

C                 ATMOSPHERIC LAYER IN PNEUMATIC SIMULATIONS

C        NVLAY  = MARKER RECORDING CORRECTED LAYER NUMBER

C        IUNUM  = UNIT NUMBER FOR OUTPUT FILE

C        KN()   = ARRAY STORING CHARACTERS FOR FILE NAMES

C        CD11   = SPATIAL OUTPUT (COORD 1, DIRN 1)

C        CD21   = SPATIAL OUTPUT (COORD 2, DIRN 1)

C        CD12   = SPATIAL OUTPUT (COORD 1, DIRN 2)

C        CD22   = SPATIAL OUTPUT (COORD 2, DIRN 2)

C        ND11   = NODAL OUTPUT (COORD 1, DIRN 1)

C        ND21   = NODAL OUTPUT (COORD 2, DIRN 1)

C        ND12   = NODAL OUTPUT (COORD 1, DIRN 2)

C        ND22   = NODAL OUTPUT (COORD 2, DIRN 2)

C        FC11   = FLOW OUTPUT (STEP 1, DIRN 1)

C        FC21   = FLOW OUTPUT (STEP 2, DIRN 1)

C        FC12   = FLOW OUTPUT (STEP 1, DIRN 2)

C        FC22   = FLOW OUTPUT (STEP 2, DIRN 2)

C        FA1    = AVERAGE FLOW OUTPUT (DIRN 1)

C        FA2    = AVERAGE FLOW OUTPUT (DIRN 2)

C        FR1    = MAGNITUDE OF RESULTANT FLOW OUTPUT (STEP 1)

C        FD1    = ANGLE OF RESULTANT FLOW OUTPUT IN DEGREES (STEP 1)

C        AV1    = CORRECTION FACTOR TO AVERAGE FLOW (DIRN 1)

C        AV2    = CORRECTION FACTOR TO AVERAGE FLOW (DIRN 2)

C        ASHIFT = CORRECTION FACTOR TO ROTATE ANGLE OF RESULTANT

C        PIRD   = CONVERSION FACTOR FROM RADIANS TO DEGREES

C        ISYMBL = SYMBOL DESIGNATING ARROW IN GRAPHICS PACKAGE 

C

C-----INITIALIZE ARRAY BUFF(K,J,I)

      DO 68 I=1,2

       DO 68 J=1,NRC

        DO 68 K=1,NCC

         BUFF(K,J,I)=0.0

 68   CONTINUE

      ISKP = 0

C

C------ONCE FOR EACH TIME STEP

C

       DO 69 IS = 1,IV(60)

C

C-------ONCE PER FLOW RATE

C

C-------ONLY GENERATE VOLUMETRIC FLOW (ICN=1) FOR HYDRAULIC RUNS

        IF(IV(35).EQ.1) ICN=1

C-------GENERATE VOLUMETRIC AND MASS FLOW (ICN=2) FOR PNEUMATIC RUNS

        IF(IV(35).EQ.2) ICN=2

        DO 70 IC = 1,ICN

C--------SET FLAG TO VOLUMETRIC FLOW (IV(45)=3) FOR IC=1

         IF (IC.EQ.1) IV(45)=3

C--------SET FLAG TO MASS FLOW (IV(45)=4) FOR IC=2

         IF (IC.EQ.2) IV(45)=4

C

C--------SPECIFY OUTPUT VARIABLES

C

         ICI1 = -1

         IC1  = 1

C

C--------OUTER LOOP I

C

C        NOTES :

C        1. IF OUTPUT IS BEING SORTED BY LAYER (IV(39)=1), THEN

C            I = LAYER #

C        2. IF OUTPUT IS BEING SORTED BY ROW (IV(39)=2), THEN

C            I = ROW #

C        3. IF OUTPUT IS BEING SORTED BY COLUMN (IV(39)=3), THEN

C            I = COLUMN #

C        4. II1= STARTING VALUE FOR LOOP I

C           II2= ENDING VALUE FOR LOOP I

C

C

C--------VALUE OF I AT START FOR HYDRAULIC SIMULATIONS

C

         IF(IV(35).EQ.1) II1=1

C

C--------VALUE OF I AT START FOR PNEUMATIC SIMULATIONS

C

         IF(IV(35).EQ.2) THEN

C---------WHEN SORTING BY LAYER

          IF(IV(39).EQ.1) II1=1

C---------WHEN SORTING BY ROW

          IF(IV(39).EQ.2) II1=1

C---------WHEN SORTING BY COLUMN

          IF(IV(39).EQ.3) II1=1

         END IF

C

C--------VALUE OF I AT END FOR HYDRAULIC SIMULATIONS

C

         IF(IV(35).EQ.1) THEN

C---------WHEN SORTING BY LAYER

          IF(IV(39).EQ.1) II2=NLAY

C---------WHEN SORTING BY ROW

          IF(IV(39).EQ.2) II2=NROW

C---------WHEN SORTING BY COLUMN

          IF(IV(39).EQ.3) II2=NCOL

         END IF

C

C--------VALUE OF I AT END FOR PNEUMATIC SIMULATIONS

C

         IF(IV(35).EQ.2) THEN

C---------WHEN SORTING BY LAYER (SKIP ATMOSPHERIC LAYER)

          IF(IV(39).EQ.1) II2=NLAY-1

C---------WHEN SORTING BY ROW

          IF(IV(39).EQ.2) II2=NROW

C---------WHEN SORTING BY COLUMN

          IF(IV(39).EQ.3) II2=NCOL

         END IF

C

C--------LOOP FOR I VALUES

C

         DO 71 I=II1,II2

C

C---------INNER LOOP FOR J VALUES

C

C         NOTES :

C         1. IF OUTPUT IS BEING SORTED BY LAYER (IV(39)=1), THEN

C             J = ROW #

C         2. IF OUTPUT IS BEING SORTED BY ROW (IV(39)=2), THEN

C             J = LAYER #

C         3. IF OUTPUT IS BEING SORTED BY COLUMN (IV(39)=3), THEN

C             J = LAYER #

C         4. JJ1= STARTING VALUE FOR LOOP J

C            JJ2= ENDING VALUE FOR LOOP J

C         5. EXTRA J LOOP NEEDED TO AVERAGE VECTORS IN DIRN 2

C             HENCE INCREASE LOOP VALUES BY 1

C

C

C---------VALUE OF J AT START FOR HYDRAULIC SIMULATIONS

C

          IF(IV(35).EQ.1) JJ1=1

C

C---------VALUE OF J AT START FOR PNEUMATIC SIMULATIONS

C

          IF(IV(35).EQ.2) THEN

C----------WHEN SORTING BY LAYER

           IF(IV(39).EQ.1) JJ1=1

C----------WHEN SORTING BY ROW

           IF(IV(39).EQ.2) JJ1=0

C----------WHEN SORTING BY COLUMN

           IF(IV(39).EQ.3) JJ1=0

          END IF

C

C---------VALUE OF J AT END FOR HYDRAULIC SIMULATIONS

C

          IF(IV(35).EQ.1) THEN

C----------WHEN SORTING BY LAYER

           IF(IV(39).EQ.1) JJ2=NROW+1

C----------WHEN SORTING BY ROW

           IF(IV(39).EQ.2) JJ2=NLAY+1

C----------WHEN SORTING BY COLUMN

           IF(IV(39).EQ.3) JJ2=NLAY+1

          END IF

C

C---------VALUE OF J AT END FOR PNEUMATIC SIMULATIONS

C

          IF(IV(35).EQ.2) THEN

C----------WHEN SORTING BY LAYER

           IF(IV(39).EQ.1) JJ2=NROW+1

C----------WHEN SORTING BY ROW

           IF(IV(39).EQ.2) JJ2=NLAY

C----------WHEN SORTING BY COLUMN

           IF(IV(39).EQ.3) JJ2=NLAY

          END IF

C

C---------LOOP FOR J VALUES

C

          DO 72 J = JJ1,JJ2

C

C----------INNER LOOPS FOR K VALUES

C

C          NOTES :

C          1. IF OUTPUT IS BEING SORTED BY LAYER (IV(39)=1), THEN

C              K = COLUMN #

C          2. IF OUTPUT IS BEING SORTED BY ROW (IV(39)=2), THEN

C              K = COLUMN #

C          3. IF OUTPUT IS BEING SORTED BY COLUMN (IV(39)=3), THEN

C              K = ROW #

C          4. KK1= STARTING VALUE FOR LOOP K

C             KK2= ENDING VALUE FOR LOOP K

C

C

C----------VALUE OF K AT START FOR HYDRAULIC/PNEUMATIC SIMULATIONS

C

           KK1=1

C

C----------VALUE OF K AT END FOR HYDRAULIC/PNEUMATIC SIMULATIONS

C

C----------WHEN SORTING BY LAYER

           IF(IV(39).EQ.1) KK2=NCOL

C----------WHEN SORTING BY ROW

           IF(IV(39).EQ.2) KK2=NCOL

C----------WHEN SORTING BY COLUMN

           IF(IV(39).EQ.3) KK2=NROW

C

C----------SEVERAL LOOPS FOR K VALUES

C

C----------TEMPORARY STORAGE OF SPATIAL AND NODAL COORDINATES

C          IN ARRAY

           IF(J.GT.JJ1) THEN

            DO 73 K = KK1,KK2

             SCRD(1,K)=SCRD(2,K)

             SCRD(3,K)=SCRD(4,K)

             NCRD(1,K)=NCRD(2,K)

             NCRD(3,K)=NCRD(4,K)

 73         CONTINUE

           END IF

C

C----------INPUT DATA ONCE FOR CELL FOR K LOOP

C

C----------ONLY READ IN DATA FROM JJ2-1 LINES ONLY

           IVN4 = IV(43)

           IF((IV(39).EQ.1).AND.(IV(35).EQ.2)) IVN4 = IVN4-1

           IF((J.LT.JJ2).AND.((IV(43).EQ.0).OR.(IVN4.EQ.I)))THEN

            DO 74 K = KK1,KK2

C

C------------SETUP FILNAM FOR INPUT BY LAYERS

C

             IF((IV(39).EQ.1).AND.(ICI1.NE.I)) THEN

              ICI1=I

              ISKP=0

C-------------SPECIFY UNIT NUMBER FOR INPUT OF FLOW

C             VECTORS IN X-DIRECTION (RIGHT FACE)

              IUN =29

              IC1 =2

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

C-------------SPECIFY UNIT NUMBER FOR INPUT OF FLOW

C             VECTORS IN Y-DIRECTION (FRONT FACE)

              IUN =30

              IC1 =3

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

C-------------SPECIFY UNIT NUMBER FOR OUTPUT OF

C             RESULTANT FLOW VECTORS IN X-Y PLANE THROUGH CELL FACE

              IUN =28

              IC1 =7

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

C-------------SPECIFY UNIT NUMBER FOR OUTPUT OF

C             RESULTANT FLOW VECTORS IN X-Y PLANE PER UNIT AREA

              IUN =33

              IC1 =10

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

             END IF

C

C------------SETUP FILNAM FOR INPUT BY ROWS

C

             IF((IV(39).EQ.2).AND.(ICI1.NE.I)) THEN

              ICI1=I

C-------------SPECIFY UNIT NUMBER FOR INPUT OF FLOW

C             VECTORS IN X-DIRECTION (RIGHT FACE)

              IUN =29

              IC1 =2

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

C-------------SPECIFY UNIT NUMBER FOR INPUT OF FLOW

C             VECTORS IN Z-DIRECTION (LOWER FACE)

              IUN =30

              IC1 =4

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

C-------------SPECIFY UNIT NUMBER FOR OUTPUT OF

C             RESULTANT FLOW VECTORS IN Z-X PLANE THROUGH CELL FACE

              IUN =28

              IC1 =5

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

C-------------SPECIFY UNIT NUMBER FOR OUTPUT OF

C             RESULTANT FLOW VECTORS IN Z-X PLANE PER UNIT AREA

              IUN =33

              IC1 =8

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

             END IF

C

C------------SETUP FILNAM FOR INPUT BY COLUMN

C

             IF((IV(39).EQ.3).AND.(ICI1.NE.I)) THEN

              ICI1=I

C-------------SPECIFY UNIT NUMBER FOR INPUT OF FLOW

C             VECTORS IN Y-DIRECTION (FRONT FACE)

              IUN =29

              IC1 =3

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

C-------------SPECIFY UNIT NUMBER FOR INPUT OF FLOW

C             VECTORS IN Z-DIRECTION (LOWER FACE)

              IUN =30

              IC1 =4

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

C-------------SPECIFY UNIT NUMBER FOR OUTPUT OF

C             RESULTANT FLOW VECTORS IN Z-Y PLANE THROUGH CELL FACE

              IUN =28

              IC1 =6

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

C-------------SPECIFY UNIT NUMBER FOR OUTPUT OF

C             RESULTANT FLOW VECTORS IN Z-Y PLANE PER UNIT AREA

              IUN =33

              IC1 =9

              CALL FILNAM(IUN,I,IC1,IS,ISKP)

             END IF

C

C------------CORRECT ARRAY VALUE J FOR ATMOSPHERIC LAYER IN 

C            Z-X AND Z-Y PLANES

             JN = J

             IF((IV(35).EQ.2).AND.(IV(39).NE.1)) JN = J+1

C

C------------READ IN FLOW RATES IN EACH DIRECTION

C

             READ(29,140) CD11,CD21,BUFF(K,JN,1),ND11,ND21

             READ(30,140) CD12,CD22,BUFF(K,JN,2),ND12,ND22

 140         FORMAT(2F15.5,E20.8,2I5)

             IV(98)=INT(CD11)

             IV(98)=INT(CD22)

C------------STORE REQUIRED SPATIAL COORDINATE VALUES

C

C------------DIRECTION 1

             SCRD(2,K) = CD12

C------------DIRECTION 2

             SCRD(4,K) = CD21

C

C------------STORE NODAL COORDINATE VALUE

C

             NCRD(2,K)=-10

             NCRD(4,K)=-10

C------------DIRECTION 1

             IF(ND11.EQ.ND12) NCRD(2,K) = ND11

C------------DIRECTION 2

             IF(ND21.EQ.ND22) NCRD(4,K) = ND21

C------------CHECK FOR ERROR

             IF(NCRD(2,K).EQ.-10) THEN

              WRITE(IOUT,145)1

              STOP

             END IF

             IF(NCRD(4,K).EQ.-10) THEN

              WRITE(IOUT,145)2

              STOP

             END IF

 145         FORMAT(///////////,T10,'INCONSISTENCY IN NODAL ',

     1       'COORDINATES IN DIRECTION ',I2)

 74         CONTINUE

           END IF

C

C----------OUTPUT DATA ONCE FOR EACH COLUMN (IE. ALONG ROW)

C

C----------WRITE OUT DATA FROM 2 TO NROW+1 ONLY

           IF((J.GT.JJ1).AND.((IV(43).EQ.0).OR.(IVN4.EQ.I)))THEN

            DO 75 K = KK1,KK2

C

C------------ASSIGN COORDINATES

C

             CR1 = SCRD(1,K)

             CR2 = SCRD(3,K)

             NR1 = NCRD(1,K)

             NR2 = NCRD(3,K)

C

C------------CORRECT ARRAY VALUE J FOR ATMOSPHERIC LAYER IN 

C            Z-X AND Z-Y PLANES

             JN = J

             IF((IV(35).EQ.2).AND.(IV(39).NE.1)) JN = J+1

C

C------------CORRECTION FACTOR TO AVERAGE FLOW RATES

C

C------------AVERAGE FLOW RATES IN EACH DIRECTION

C

C------------DIRECTION 1

C

             IF(K.EQ.KK1) THEN

              FA1 = (BUFF(K,JN-1,1))

             END IF

             IF((K.GT.KK1).AND.(K.LT.KK2)) THEN

              FA1 = (BUFF(K-1,JN-1,1)+BUFF(K,JN-1,1))/2.0

             END IF

             IF(K.EQ.KK2) THEN

              FA1 = (BUFF(K-1,JN-1,1))

             END IF

C

C------------DIRECTION 2

C

             IF(J.EQ.JJ1+1) THEN

              FA2 = (BUFF(K,JN-1,2))

             END IF

             IF((J.GT.JJ1+1).AND.(J.LT.JJ2)) THEN

              FA2 = (BUFF(K,JN-2,2)+BUFF(K,JN-1,2))/2.0

             END IF

             IF(J.EQ.JJ2) THEN

              FA2 = (BUFF(K,JN-2,2))

             END IF

C

C------------CONVERT FLOW THROUGH CELL FACE TO FLOW PER UNIT AREA

C

C------------CORRECT AREA TO APPROPRIATE UNIT SYSTEM

             AREAU = XU2(1,IU1(1))*XU2(1,IU1(1))

C

C------------BY LAYER

             IF(IV(39).EQ.1) THEN

              IF(I.EQ.1) DM1 = DELL(-1)

              IF(I.GT.1) DM1 = DELL(I+1)-DELL(I)

              DM2 = DELC(JN)

              DM3 = DELR(K)

              AREA1 = DM1*DM2*AREAU

              AREA2 = DM1*DM3*AREAU

             END IF

C------------BY ROW

             IF(IV(39).EQ.2) THEN

              DM1 = DELC(I)

              IF(JN.EQ.2) DM2 = DELL(-1)

              IF(JN.GT.2) DM2 = DELL(JN-1)-DELL(JN-2)

              DM3 = DELR(K)

              AREA1 = DM1*DM2*AREAU

              AREA2 = DM1*DM3*AREAU

             END IF

C------------BY COLUMN

             IF(IV(39).EQ.3) THEN

              DM1 = DELR(I)

              IF(JN.EQ.2) DM2 = DELL(-1)

              IF(JN.GT.2) DM2 = DELL(JN-1)-DELL(JN-2)

              DM3 = DELC(K)

              AREA1 = DM1*DM2*AREAU

              AREA2 = DM1*DM3*AREAU

             END IF

C------------MAGNITUDE OF RESULTANT FLOW RATE THROUGH CELL FACE

             FR1 = SQRT(FA1*FA1+FA2*FA2)

C------------MAGNITUDE OF RESULTANT FLOW RATE PER UNIT AREA

             IF((AREA1.LE.0.0).OR.(AREA2.LE.0.0)) THEN

              WRITE(IOUT,148)

              STOP

             END IF

 148         FORMAT(///////,T10,'ERROR IN AREA OF CELL IN R2FLOW')

             FB1 = FA1/AREA1

             FB2 = FA2/AREA2

             FN1 = SQRT(FB1*FB1+FB2*FB2)

C------------DIRECTION OF RESULTANT FLOW RATE

             ASHIFT = 0.0

C            ISYMBL = 92

             IF(((FA1.LT.1.0E-10).AND.(FA1.GT.-1.0E-10)).AND.

     1          ((FA2.LT.1.0E-10).AND.(FA2.GT.-1.0E-10))) THEN

              FD1 = ASHIFT

             END IF

             IF(((FA1.LT.1.0E-10).AND.(FA1.GT.-1.0E-10)).AND.

     1           (FA2.LT.0.0)) THEN

              FD1 = ASHIFT + 90.0

             END IF

             IF(((FA1.LT.1.0E-10).AND.(FA1.GT.-1.0E-10)).AND.

     1           (FA2.GT.0.0)) THEN

              FD1 = ASHIFT + 270.0

             END IF

             IF((FA1.GT.0.0).AND.((FA2.LT.1.0E-10).AND.

     1          (FA2.GT.-1.0E-10))) THEN

              FD1 = ASHIFT

             END IF

             IF((FA1.LT.0.0).AND.((FA2.LT.1.0E-10).AND.

     1          (FA2.GT.-1.0E-10))) THEN

              FD1 = ASHIFT + 180.0

             END IF

C------------FIRST QUADRANT

             IF((FA1.GT.0.0).AND.(FA2.LT.0.0)) THEN

              FD1 = ASHIFT + PIRD*ABS(ATAN(FA2/FA1))

              FD2 = ASHIFT + PIRD*ABS(ATAN(FB2/FB1))

             END IF

C------------SECOND QUADRANT

             IF((FA1.LT.0.0).AND.(FA2.LT.0.0)) THEN

              FD1 = ASHIFT + 180 - PIRD*ATAN(FA2/FA1)

              FD2 = ASHIFT + 180 - PIRD*ATAN(FB2/FB1)

             END IF

C------------THIRD QUADRANT

             IF((FA1.LT.0.0).AND.(FA2.GT.0.0)) THEN

              FD1 = ASHIFT + 180 + PIRD*ABS(ATAN(FA2/FA1))

              FD2 = ASHIFT + 180 + PIRD*ABS(ATAN(FB2/FB1))

             END IF

C------------FORTH QUADRANT

             IF((FA1.GT.0.0).AND.(FA2.GT.0.0)) THEN

              FD1 = ASHIFT + 360 - PIRD*ATAN(FA2/FA1)

              FD2 = ASHIFT + 360 - PIRD*ATAN(FB2/FB1)

             END IF

C

C------------WRITE OUT RESULTANTS

C

             WRITE(28,150) CR1,CR2,FA1,FA2,FR1,FD1,NR1,NR2

             WRITE(33,150) CR1,CR2,FB1,FB2,FN1,FD2,NR1,NR2

 150         FORMAT(2F10.2,3E15.6,F10.2,2I5)

 75         CONTINUE

           END IF

 72       CONTINUE

 71      CONTINUE

 70     CONTINUE

 69    CONTINUE

C

C5----CLOSE FILES

C

      CLOSE(28)

      CLOSE(29)

C

C6----RETURN

C

      RETURN

      END

C

C     *****************

      SUBROUTINE R3FLOW(DELR,DELC,DELL,BUFH,BUFF,BUFP,BUFR,TEXTH,

C     *****************

     1 TEXTF,NROW,NCOL,NLAY,LRC,LCC,LLC,DATUM,TAIR,IQ1,CLEN)

C

C1----NOTES :

C

C     1. USE THIS ROUTINE TO GENERATE 3D VOLUMETRIC AND MASS

C        OUTPUT FROM MODFLOW BINARY FLOW FILE

C

C2----SPECIFICATIONS:

C

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(25)

      DIMENSION DELR(NCOL),DELC(NROW),DELL(-1:NLAY),

     1 BUFH(NCOL,NROW),BUFF(LCC,LRC,LLC),BUFP(LCC,LRC,LLC),

     2 BUFR(LCC,LRC,LLC),TEXTH(4),TEXTF(4)

      CHARACTER FNAME*12,IU3*6,TEXTH*4,TEXTF*4

      CHARACTER*1 KN1,KN2,KN3,KN4,KN5,KN6,KN7,KN9,KN10,KN11,KN12

C-----ASSIGN VARIABLES

      ISS = IV(90)

      XW1 = XU2(1,IU1(1))

      XW2 = XU2(2,IU1(2))

      XW3 = XU2(3,IU1(3))

C     XW4 = XU2(4,IU1(4))

      XW6 = XU2(6,IU1(6))

C

C3----DEFINE PHYSICAL CONSTANTS REQUIRED IN PNEUMATIC ANALYSES

C

      IF(IV(35).EQ.2) THEN

       VAS    = 1.76E-4

       TVAS   = 283.15

       VA     = VAS*(TAIR/TVAS)**0.5

       RG     = 8.314E7

       WAIR   = 28.8

      END IF

C-----REWIND HEAD FILE

      REWIND 17

C-----REWIND FLOW FILE

      REWIND 18

C-----ONCE FOR EACH TIME STEP

      DO 50 IS = 1,IV(60)

C------INITIALIZE BUFR

       DO 51 II = 1,LLC

        DO 52 JJ = 1,LRC

         DO 53 KK = 1,LCC

          BUFR(KK,JJ,II) = 0.0

 53      CONTINUE

 52     CONTINUE

 51    CONTINUE

C------GENERATE OUTPUT FILE EXTENSION USING TIME STEP

       CALL FILCNT(IV(40),KN6,KN7)

       CALL FILCNT(IS,KN11,KN12)

       KN1='3'

       KN2='D'

       KN3='Q'

       KN4='R'

       KN5='V'

       KN9='.'

       KN10='T'

C------OPEN TEXT FILE FOR CONTINUOUS OUTPUT OF 3D VOLUMETRIC FLOW

C      PER UNIT AREA

       FNAME(16)=KN1//KN2//KN3//KN4//KN5//KN6//KN7//KN9//KN10//

     1          KN11//KN12

       OPEN(UNIT=26,FILE=FNAME(16),STATUS='UNKNOWN')

C------OPEN TEXT FILE FOR CONTINUOUS OUTPUT OF 3D MASS FLOW PER

C      UNIT AREA

       KN5='M'

       FNAME(17)=KN1//KN2//KN3//KN4//KN5//KN6//KN7//KN9//KN10//

     1          KN11//KN12

       OPEN(UNIT=27,FILE=FNAME(17),STATUS='UNKNOWN')

C------STORE HEAD VALUES TO BUFP FOR TRANSIENT SIMULATIONS

       IF (ISS.EQ.0) THEN 

        DO 57 II = 1,NLAY

         READ(17) KSTPH,KPERH,PERTIMH,TOTIMH,TEXTH,NHCOL,NHROW,NHLAY

         READ(17) ((BUFH(ICL,IRL),ICL=1,NCOL),IRL=1,NROW)

         IV(98)=KSTPH

         IV(98)=KPERH

         IV(98)=PERTIMH

         IV(98)=INT(TOTIMH)

         IV(98)=NHCOL

         IV(98)=NHROW

         IV(98)=NHLAY

         DO 58 JJ = 1,NROW

          DO 59 KK = 1,NCOL

           BUFP(KK,JJ,II)=BUFH(KK,JJ)

 59       CONTINUE

 58      CONTINUE

 57     CONTINUE

       END IF

C

C------ONCE FOR EACH FLOW SET (STORAGE (TRANSIENT ONLY), CONSTANT

C      HEAD, RIGHT, FRONT, LOWER)

       ICSS = 1

       IF(ISS.EQ.0) ICSS = 0

       DO 60 IC = ICSS,4

C-------REWIND HEAD/PRESSURE FILE (17) WITH EACH LOOP

        IF (ISS.NE.0) REWIND 17

C-------READ IN IDENTIFYING INFORMATION FOR FLOW FILE (18)

        READ(18) KSTPF,KPERF,TEXTF,NFCOL,NFROW,NFLAY

C-------READ IN FLOW VALUES

        READ(18) BUFF

        IV(98)=KSTPF

        IV(98)=KPERF

        IV(98)=NFCOL

        IV(98)=NFROW

        IV(98)=NFLAY

C

C6------PNEUMATIC OUTPUT

C

        IF(IC.GT.0) THEN

         DO 71 I=1,NLAY

C---------VOLUMETRIC FLOW DETERMINATION

          IF(IQ1.EQ.1) THEN

C----------NEED PRESSURE FOR CORRECTION TO VOLUMETRIC FLOW ONLY

           IF(ISS.NE.0) THEN

            READ(17) KSTPH,KPERH,PERTIMH,TOTIMH,TEXTH,NHCOL,NHROW,

     1               NHLAY

            READ(17) ((BUFH(ICL,IRL),ICL=1,NCOL),IRL=1,NROW)

           END IF

           DO 72 J = 1,NROW

            DO 73 K = 1,NCOL

             IF (ISS.NE.0) VR1 = 2.0*VA*SQRT(BUFH(K,J))*(XW3/XW2)

             IF (ISS.EQ.0) VR1 = 2.0*VA*SQRT(BUFP(K,J,I))*(XW3/XW2)

             BUFF(K,J,I) = BUFF(K,J,I)/VR1

 73         CONTINUE

 72        CONTINUE

          END IF

C---------MASS FLOW DETERMINATION

          IF(IQ1.EQ.2) THEN

           DO 74 J = 1,NROW

            DO 75 K = 1,NCOL

             VR2 = (XW6/XW3)*WAIR/(2.0*VA*RG*TAIR)

             BUFF(K,J,I) = BUFF(K,J,I)*VR2

 75         CONTINUE

 74        CONTINUE

          END IF

 71      CONTINUE

C--------CALCULATE 3D RESULTANT FLOW PER UNIT AREA

         DO 81 II = 1,LLC

          DO 82 JJ = 1,LRC

           DO 83 KK = 1,LCC

C-----------CELL DIMENSIONS

            DM1 = DELL(II+1)-DELL(II)

            DM2 = DELC(JJ)

            DM3 = DELR(KK)

C-----------AREA OF BOUNDARY CELL FACES

            AREA = 1.0

            IF(IC.EQ.1) THEN

             IF(II.EQ.1) AREA = DM2*DM3

             IF((II.GT.1).AND.((JJ.EQ.1).OR.(JJ.EQ.LRC)))

     1                    AREA = DM1*DM3

             IF((II.GT.1).AND.((KK.EQ.1).OR.(KK.EQ.LCC)))

     1                    AREA = DM1*DM2

            END IF

C-----------AREA OF INTERIOR CELL FACES

            IF(IC.EQ.2) AREA = DM1*DM2

            IF(IC.EQ.3) AREA = DM1*DM3

            IF(IC.EQ.4) AREA = DM2*DM3

C-----------FOR FLOW THROUGH CELL FACE

C           AREA=1.0

C-----------3D RESULTANT FLOW PER UNIT AREA

            Q3D = (BUFF(KK,JJ,II)/AREA)**2

            BUFR(KK,JJ,II) = BUFR(KK,JJ,II) + Q3D

 83        CONTINUE

 82       CONTINUE

 81      CONTINUE

        END IF

 60    CONTINUE

C------OUTPUT 3D RESULTANT FLOW - BY LAYER

       DO 86 II = 1,LLC

        DO 87 JJ = 1,LRC

         DO 88 KK = 1,LCC

C---------3D RESULTANT FLOW 

          FCOR = SQRT(BUFR(KK,JJ,II))

C---------DETERMINE SPATIAL COORDINATES

          CALL XYCORD(DELR,DELC,XC1,YC1,XR1,YR1,XF1,YF1,

     1    XL1,YL1,JJ,J3,KK,NROW,NCOL,CLEN)

          CALL ZCORD(DELL,ZC1,ZR1,ZF1,ZL1,II,NLAY,DATUM)

C---------WRITE OUT 3D RESULTANTS PER UNIT AREA FOR VOLUMETRIC FLOW

          IF(IQ1.EQ.1) THEN

           WRITE(26,131) XC1*XW1,YC1*XW1,ZC1*XW1,FCOR*XW2/XW3,

     1                   KK,JJ,II-1

 131       FORMAT(3F15.5,E20.8,3I5)

          END IF

C---------WRITE OUT 3D RESULTANTS PER UNIT AREA FOR MASS FLOW

          IF(IQ1.EQ.2) THEN

           WRITE(27,131) XC1*XW1,YC1*XW1,ZC1*XW1,FCOR*XW6/XW3,

     1                   KK,JJ,II-1

          END IF

 88      CONTINUE

 87     CONTINUE

 86    CONTINUE

 50   CONTINUE

C

C10---RETURN

C

      RETURN

      END

C

C     ****************

      SUBROUTINE DFLOW(DELR,DELC,DELL,BUFH,BUFF,TEXTF,

C     ****************

     1 NROW,NCOL,NLAY,NRC,NCC,NLC)

C

C1----NOTES :

C

C     1. USE THIS ROUTINE TO CALCULATE FLOW DIVERGENCE

C

C2----SPECIFICATIONS:

C

      COMMON/IUNITS/IU1(7),XU2(7,10),IU3(7,10)

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(25)

      DIMENSION DELR(NCOL),DELC(NROW),

     1 DELL(-1:NLAY),BUFH(NCOL,NROW),BUFF(NCC,NRC,NLC),

     2 TEXTF(4)

      CHARACTER FNAME*12,IU3*6,TEXTF*4

      CHARACTER*1 KN1,KN2,KN3,KN4,KN5,KN5A,KN5B,KN6,

     1  KN7,KN9,KN10,KN11,KN12

C-----ASSIGN VARIABLES

      ISS   = IV(90)

C     INBAS = IV(81)

      IOUT  = IV(82)

C     XW1   = XU2(1,IU1(1))

      XW2   = XU2(2,IU1(2))

      XW3   = XU2(3,IU1(3))

C     XW4   = XU2(4,IU1(4))

C     XW6   = XU2(6,IU1(6))

C

C3----INPUT VOLUMETRIC AIR FLOWS FROM BINARY FILE (UNIT 26)

C

      REWIND 26

C-----ONCE FOR EACH TIME STEP

      DO 50 IS = 1,IV(60)

C------SETUP FILES FOR FLOW DIVERGENCE OUTPUT

C------GENERATE OUTPUT FILE EXTENSION USING TIME STEP

       CALL FILCNT(IV(40),KN6,KN7)

       CALL FILCNT(IS,KN11,KN12)

       KN1='F'

       KN2='L'

       KN3='O'

       KN4='W'

       KN5='D'

       KN5B='C'

       KN9='.'

       KN10='B'

C------OPEN BINARY FILE FOR CONTINUOUS OUTPUT OF VOLUMETRIC FLOW

       FNAME(20)=KN1//KN2//KN3//KN4//KN5//KN6//KN7//KN9//KN10//

     1           KN11//KN12

       FNAME(21)=KN1//KN2//KN3//KN4//KN5//KN5B//KN6//KN7//KN9//

     1           KN10//KN11//KN12

       OPEN(UNIT=30,FILE=FNAME(20),FORM='UNFORMATTED',

     1      ACCESS='SEQUENTIAL',STATUS='UNKNOWN')

C------ONCE FOR EACH FLOW SET (STORAGE (TRANSIENT ONLY), CONSTANT

C      HEAD, RIGHT, FRONT, LOWER)

       ICSS = 1

       IF(ISS.EQ.0) ICSS = 0

       DO 60 IC = ICSS,4

        IFL1= 0

        IFL2= 0

        IFL3= 0

        IF(IC.EQ.0) KN5A='S'

        IF(IC.EQ.1) KN5A='C'

        IF(IC.EQ.2) KN5A='X'

        IF(IC.EQ.3) KN5A='Y'

        IF(IC.EQ.4) KN5A='Z'

        FNAME(22)=KN1//KN2//KN3//KN4//KN5//KN5A//KN6//KN7//KN9//

     1            KN10//KN11//KN12

        OPEN(UNIT=31,FILE=FNAME(22),FORM='UNFORMATTED',

     1            ACCESS='SEQUENTIAL',STATUS='UNKNOWN')

        IF(IC.GT.1) THEN

         OPEN(UNIT=33,FILE=FNAME(21),FORM='UNFORMATTED',

     1       ACCESS='SEQUENTIAL',STATUS='OLD')

        END IF

C-------READ IN IDENTIFYING INFORMATION FROM AIR FLOW FILE (26)

        READ(26) KSTPF,KPERF,TEXTF,NFCOL,NFROW,NFLAY

C-------READ IN AIR FLOW VALUES

        READ(26) BUFF

C

C4------CALCULATE FLOW DIVERGENCE

C

C4a-----dqx/dx IN X-DIRECTION (THROUGH RIGHT FACE)

C

        IF(IC.EQ.2) THEN

         DO 71 I=1,NLAY

C---------Z-COMPONENT OF CROSS-SECTIONAL AREA (HYDRAULIC)

          IF(IV(35).EQ.1) THEN

           IF (I.EQ.1) ZX = DELL(1)

           IF (I.GT.1) ZX = DELL(I)-DELL(I-1)

          END IF

C---------Z-COMPONENT OF CROSS-SECTIONAL AREA (PNEUMATIC)

          IF(IV(35).EQ.2) THEN

           IF (I.EQ.1) ZX = DELL(-1)

           IF (I.GT.1) ZX = DELL(I)-DELL(I-1)

          END IF

C---------ENTER SPECFIC DISCHARGE AT BOUNDARY NODES

          READ(33) ((BUFH(IIC,IIR),IIC=1,NCOL),IIR=1,NROW)

          DO 72 J = 1,NROW

C----------Y-COMPONENT OF CROSS-SECTIONAL AREA

           YX = DELC(J)

C----------CROSS-SECTIONAL AREA WITH VOLUMETRIC FLOW UNIT CORRECTION

           XAREA = ZX*YX*XW2/XW3

C----------TEST CROSS SECTIONAL AREA NOT EQUAL TO ZERO

           IF((XAREA.LT.1.0E-20).AND.(XAREA.GT.-1.0E-20))THEN

            WRITE (IOUT,850)

            WRITE (IOUT,851)

            STOP

           END IF

 850       FORMAT(///////,T10,'XAREA = 0 RESULTS IN ZERO DIVIDE')

 851       FORMAT(//,T10,'CHECK SETUPOF NODAL SPACING IN FLOW GRID',

     1            ////)

           DO 73 K = 1,NCOL

C-----------AT COLUMN 1 (ASSUME : DIV Q |1 = DIV Q |2)

            IF(K.EQ.1) THEN

             BUFF(K,J,I)=BUFH(K,J)

             QX1 = BUFF(K,J,I)/XAREA

             QX2 = BUFF(K+1,J,I)/XAREA

             L2  = DELR(K+1)

             DQDX= (QX2-QX1)/(L2*XW3)

            END IF

C-----------AT COLUMN NCOL, ASSIGN BOUNDARY FLOWS TO NODES

c           REVERSE SIGN OF FLOW THROUGH RHS FACE TO MAKE

c           CONSISTENT WITH INTERIOR CELL FLOW CONVENTION

c           BOUNDARY NODE : FLOW OUT < 0, FLOW IN > 0

c           INTERIOR NODE : FLOW TO RIGHT >0, FLOW TO LEFT < 0

c           IF(K.EQ.NCOL) BUFF(K,J,I)=-BUFH(K,J)

            IF(K.EQ.NCOL) BUFF(K,J,I)=BUFF(K-1,J,I)

C-----------AT COLUMNS GREATER THAN 1

            IF((K.GT.1).AND.(K.LT.NCOL)) THEN

             QX0 = QX00/XAREA

             QX1 = BUFF(K,J,I)/XAREA

C------------TEST FOR ACTIVE (NON-WELL) CELL

             IFL1= 0

             IFL2= 0

             IF((QX1.LE.-1.0E-20).OR.(QX1.GE.1.0E-20)) IFL1=1

             IF((QX0.LE.-1.0E-20).OR.(QX0.GE.1.0E-20)) IFL2=1

             IF(((IFL1.EQ.1).AND.(IFL2.EQ.1)).OR.(K.EQ.2)) IFL3=0

             L1  = DELR(K)

             DQDX= (QX1-QX0)/(L1*XW3)

C------------TEST FOR CONSTANT HEAD (WELL) CELLS

             IF((IFL1.EQ.0).OR.(IFL2.EQ.0)) THEN

              IFL3 = IFL3 + 1

              DQDX = BUFF(K-IFL3,J,I)

             END IF

            END IF

            QX00 = BUFF(K,J,I)

            BUFF(K,J,I) = DQDX

 73        CONTINUE

 72       CONTINUE

 71      CONTINUE

         CLOSE (33)

C--------END OF FLOW DIV IN X-DIRN

        END IF

C

C4b-----dqy/dy IN Y-DIRECTION (THROUGH FRONT FACE)

C

        IF(IC.EQ.3) THEN

         DO 81 I=1,NLAY

C---------Z-COMPONENT OF CROSS-SECTIONAL AREA (HYDRAULIC)

          IF(IV(35).EQ.1) THEN

           IF (I.EQ.1) ZX = DELL(1)

           IF (I.GT.1) ZX = DELL(I)-DELL(I-1)

          END IF

C---------Z-COMPONENT OF CROSS-SECTIONAL AREA (PNEUMATIC)

          IF(IV(35).EQ.2) THEN

           IF (I.EQ.1) ZX = DELL(-1)

           IF (I.EQ.2) ZX = DELL(2)

           IF (I.GT.2) ZX = DELL(I)-DELL(I-1)

          END IF

C---------ENTER SPECFIC DISCHARGE AT BOUNDARY NODES

          READ(33) ((BUFH(IIC,IIR),IIC=1,NCOL),IIR=1,NROW)

          DO 82 K = 1,NCOL

C----------X-COMPONENT OF CROSS-SECTIONAL AREA

           XX = DELR(K)

C----------CROSS-SECTIONAL AREA WITH VOLUMETRIC FLOW UNIT CORRECTION

           XAREA = ZX*XX*XW2/XW3

C----------TEST CROSS SECTIONAL AREA NOT EQUAL TO ZERO

           IF((XAREA.LT.1.0E-20).AND.(XAREA.GT.-1.0E-20))THEN

            WRITE (IOUT,850)

            WRITE (IOUT,851)

            STOP

           END IF

           DO 83 J = 1,NROW

C-----------AT ROW 1 (ASSUME : DIV Q |1 = DIV Q |2)

            IF(J.EQ.1) THEN

             BUFF(K,J,I)=BUFH(K,J)

             QY1 = BUFF(K,J,I)/XAREA

             QY2 = BUFF(K,J+1,I)/XAREA

             L2  = DELC(J+1)

             DQDY= (QY2-QY1)/(L2*XW3)

            END IF

C-----------AT ROW NROW, ASSIGN BOUNDARY FLOW TO NODE

c           REVERSE SIGN OF FLOW THROUGH FRONT FACE TO MAKE

c           CONSISTENT WITH INTERIOR CELL FLOW CONVENTION

c           BOUNDARY NODE : FLOW OUT < 0, FLOW IN > 0

c           INTERIOR NODE : FLOW TO FRONT >0, FLOW TO REAR < 0

c           IF(J.EQ.NROW) BUFF(K,J,I)=-BUFH(K,J)

            IF(J.EQ.NROW) BUFF(K,J,I)=BUFF(K,J-1,I)

C-----------AT ROWS GREATER THAN ROW 1

            IF((J.GT.1).AND.(J.LT.NROW)) THEN

             QY0 = QY00/XAREA

             QY1 = BUFF(K,J,I)/XAREA

C------------TEST FOR ACTIVE (NON-WELL) CELL

             IFL1= 0

             IFL2= 0

             IF((QY1.LE.-1.0E-20).OR.(QY1.GE.1.0E-20)) IFL1=1

             IF((QY0.LE.-1.0E-20).OR.(QY0.GE.1.0E-20)) IFL2=1

             IF(((IFL1.EQ.1).AND.(IFL2.EQ.1)).OR.(J.EQ.2)) IFL3=0

             L1  = DELC(J)

             DQDY= (QY1-QY0)/(L1*XW3)

C------------TEST FOR CONSTANT HEAD (WELL) CELLS

             IF((IFL1.EQ.0).OR.(IFL2.EQ.0)) THEN

              IFL3 = IFL3 + 1

              DQDY = BUFF(K,J-IFL3,I)

             END IF

            END IF

            QY00 = BUFF(K,J,I)

            BUFF(K,J,I) = DQDY

 83        CONTINUE

 82       CONTINUE

 81      CONTINUE

         CLOSE (33)

C--------END OF FLOW DIV IN Y-DIRN

        END IF

C

C4c-----dqz/dz IN Z-DIRECTION (THROUGH LOWER FACE)

C

        IF(IC.EQ.4) THEN

C--------ENTER SPECFIC DISCHARGE AT BOUNDARY NODES

C        ASSUME PNEUMATIC BC APPLY (MAY NEED TO MODIFY FOR HYDRAULIC)

         READ(33) ((BUFH(IIC,IIR),IIC=1,NCOL),IIR=1,NROW)

         DO 91 J=1,NROW

C---------Y-COMPONENT OF CROSS-SECTIONAL AREA

          YX = DELC(J)

          DO 92 K = 1,NCOL

C----------X-COMPONENT OF CROSS-SECTIONAL AREA

           XX = DELR(K)

C----------CROSS-SECTIONAL AREA WITH VOLUMETRIC FLOW UNIT CORRECTION

           XAREA = YX*XX*XW2/XW3

C----------TEST CROSS SECTIONAL AREA NOT EQUAL TO ZERO

           IF((XAREA.LT.1.0E-20).AND.(XAREA.GT.-1.0E-20))THEN

            WRITE (IOUT,850)

            WRITE (IOUT,851)

            STOP

           END IF

           DO 93 I = 1,NLAY

C-----------AT LAYER 1 (ASSUME : DIV Q |1 = DIV Q |2)

            IF(I.EQ.1) THEN

C            BUFF(K,J,I)=BUFH(K,J)

             QZ1 = BUFH(K,J)/XAREA

             QZ2 = BUFF(K,J,2)/XAREA

             L2 = DELL(I+1)-DELL(1)

             DQDZ= (QZ2-QZ1)/(L2*XW3)

            END IF

C-----------AT LAYER NLAY (ASSUME : DIV Q |nlay = DIV Q |nlay-1)

            IF(I.EQ.NLAY) THEN

             DQDZ= BUFF(K,J,I-1)

            END IF

C-----------AT INTERMEDIATE LAYERS

            IF((I.GT.1).AND.(I.LT.NLAY)) THEN

             QZ0 = QZ00/XAREA

             QZ1 = BUFF(K,J,I)/XAREA

C------------TEST FOR ACTIVE (NON-WELL) CELL

             IFL1= 0

             IFL2= 0

             IF((QZ1.LE.-1.0E-20).OR.(QZ1.GE.1.0E-20)) IFL1=1

             IF((QZ0.LE.-1.0E-20).OR.(QZ0.GE.1.0E-20)) IFL2=1

             IF(((IFL1.EQ.1).AND.(IFL2.EQ.1)).OR.(I.EQ.2)) IFL3=0

             L1  = DELL(I)-DELL(I-1)

             DQDZ= (QZ1-QZ0)/(L1*XW3)

C------------TEST FOR CONSTANT HEAD (WELL) CELLS

             IF((IFL1.EQ.0).OR.(IFL2.EQ.0)) THEN

              IFL3 = IFL3 + 1

              DQDZ = BUFF(K,J,I-IFL3)

             END IF

            END IF

            QZ00 = BUFF(K,J,I)

            BUFF(K,J,I) = DQDZ

 93        CONTINUE

 92       CONTINUE

 91      CONTINUE

         CLOSE (33)

C--------END OF FLOW DIV IN Z-DIRN

        END IF

C-------WRITE qc AND dqx/dx, dqy/dy, dqz/dz TO 2D BINARY FILE

        DO 101 I=1,NLAY

         DO 102 J = 1,NROW

          DO 103 K = 1,NCOL

C----------ASSIGN BUFF TO BUFH

           BUFH(K,J) = BUFF(K,J,I)

 103      CONTINUE

 102     CONTINUE

C--------WRITE dq/dl TO FLOWDxxx.Bxx BINARY FILE



         WRITE(31) ((BUFH(IIC,IIR),IIC=1,NCOL),IIR=1,NROW)

c        WRITE(32,*) i

c        WRITE(32,*) ((BUFH(IIC,IIR),IIC=1,NCOL),IIR=1,NROW)

 101    CONTINUE

        CLOSE(31)

C-------Qc, Qx, Qy, Qz LOOP

 60    CONTINUE

C------CREATE AND WRITE 3D BINARY FLOW DIV FILE

C------INITIALZE BUFF ARRAY

       DO 121 I = 1,NLAY

        DO 122 J = 1,NROW

         DO 123 K = 1,NCOL

C---------ASSIGN BUFF TO BUFH

          BUFF(K,J,I) = 0.0

 123     CONTINUE

 122    CONTINUE

 121   CONTINUE

C------INPUT dqx/dx + dqy/dy + dqz/dz INTO BUFF

       DO 140 IC = 1,3

        IF(IC.EQ.1) KN5A='X'

        IF(IC.EQ.2) KN5A='Y'

        IF(IC.EQ.3) KN5A='Z'

        FNAME(21)=KN1//KN2//KN3//KN4//KN5//KN5A//KN6//KN7//KN9//

     1            KN10//KN11//KN12

        FNAME(24)='FLOWDIV.T01'

        OPEN(UNIT=31,FILE=FNAME(21),FORM='UNFORMATTED',

     1            ACCESS='SEQUENTIAL',STATUS='UNKNOWN')

        OPEN(UNIT=34,FILE=FNAME(24),ACCESS='SEQUENTIAL',

     1            STATUS='UNKNOWN')

        DO 151 I = 1,NLAY

C--------READ dq/dl FROM FLOWDxxx.Bxx BINARY FILE AND ADD TO BUFF

         READ(31) ((BUFH(IIC,IIR),IIC=1,NCOL),IIR=1,NROW)

         DO 152 J = 1,NROW

          DO 153 K = 1,NCOL

           BUFF(K,J,I) = BUFF(K,J,I) + BUFH(K,J)

 153      CONTINUE

 152     CONTINUE

 151    CONTINUE

 140   CONTINUE

C------DIVERGENT FLOW OUTPUT TO BINARY FILE FOR TIME STEP IS

       WRITE(30) KSTPF,KPERF,TEXTF,NFCOL,NFROW,NFLAY

       WRITE(30) BUFF

       DO 160 IIL = 1,NLAY

        WRITE(34,*) IIL

        WRITE(34,*) ((BUFF(IIC,IIR,IIL),IIC=1,NCOL),IIR=1,NROW)

 160   CONTINUE

C------TIME LOOP

 50   CONTINUE

C

C10---RETURN

C

      RETURN

      END

C

C     *****************

      SUBROUTINE AIREND

C     *****************

C

C1----NOTES :

C

C     1. USE THIS ROUTINE TO WRITE ENDING MESSAGE TO USER

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      COMMON/AVALUE/FNAME(25)

      CHARACTER*12 FNAME

C-----INITIALIZE VARIABLES

      IOUT = IV(82)

C

C3----MESSAGE TO USER

C

      WRITE(IOUT,201)

      WRITE(IOUT,202)

      WRITE(IOUT,220)

C

C4----SINGLE FILE OUTPUT

C

C-----HEAD OUTPUT

      IF((IV(35).EQ.1).AND.(IV(41).EQ.1)) WRITE(IOUT,203)

      IF((IV(35).EQ.1).AND.(IV(41).EQ.-1)) WRITE(IOUT,204)

C-----PRESSURE OUTPUT

      IF((IV(35).EQ.2).AND.(IV(41).EQ.1)) WRITE(IOUT,205)

      IF((IV(35).EQ.2).AND.(IV(41).EQ.-1)) WRITE(IOUT,206)

C-----VOLUMETRIC FLOW OUTPUT

      IF((IV(38).EQ.2).AND.(IV(41).EQ.1)) WRITE(IOUT,207)

      IF((IV(38).EQ.2).AND.(IV(41).EQ.-1)) WRITE(IOUT,208)

C-----MASS FLOW OUTPUT

      IF((IV(35).EQ.2).AND.(IV(38).EQ.2).AND.(IV(41).EQ.1))

     1    WRITE(IOUT,209)

      IF((IV(35).EQ.2).AND.(IV(38).EQ.2).AND.(IV(41).EQ.-1))

     1    WRITE(IOUT,210)

C-----MASS FLOW OUTPUT

      IF((IV(35).EQ.2).AND.(IV(38).EQ.2).AND.(IV(41).EQ.-1))

     1    WRITE(IOUT,211)

C

C5----MULTIPLE FILE OUTPUT

C

C-----HEAD OUTPUT

      IF((IV(35).EQ.1).AND.(IV(41).GT.1)) WRITE(IOUT,213)

C-----PRESSURE OUTPUT

      IF((IV(35).EQ.2).AND.(IV(41).GT.1)) WRITE(IOUT,214)

C-----VOLUMETRIC FLOW OUTPUT

      IF((IV(35).EQ.1).AND.(IV(38).EQ.2).AND.(IV(41).GT.1))

     1    WRITE(IOUT,215)

      IF((IV(35).EQ.2).AND.(IV(38).EQ.2).AND.(IV(41).GT.1))

     1    WRITE(IOUT,216)

C

C6----2-D FLOW RESULTANTS

C

C-----GROUND WATER FLOW

      IF((IV(35).EQ.1).AND.(IV(38).EQ.2).AND.(IV(39).GT.3)) 

     1    WRITE(IOUT,217)

C-----AIR FLOW

      IF((IV(35).EQ.2).AND.(IV(38).EQ.2).AND.(IV(39).GT.3)) 

     1    WRITE(IOUT,218)

C

C7----MASS BALANCE / WELL / UNIT FILE OUTPUT

C

C-----MASS / WELL OUTPUT

      IF((IV(35).EQ.2).AND.(IV(38).EQ.2).AND.(IV(41).GT.1)

     1    .AND.(IV(42).EQ.1)) WRITE(IOUT,219)

      WRITE(IOUT,220)

C

C

 201  FORMAT(////////////////////////,T20,'POSTAIR - AN AIRFLOW',

     1   ' POSTPROCESSOR (Ver 1.1)')

 202  FORMAT(T20,'=======   == ======= =============')

 203  FORMAT(/,T10,'POSTAIR has generated HEAD',

     1       ' text file               : HEADxx.Txx')

 204  FORMAT(/,T10,'POSTAIR has generated HEAD',

     1       ' binary file             : HEADxx.Bxx')

 205  FORMAT(/,T10,'POSTAIR has generated PRESSURE',

     1       ' text file           : PRESxx.Txx')

 206  FORMAT(/,T10,'POSTAIR has generated PRESSURE',

     1       ' binary file         : PRESxx.Bxx')

 207  FORMAT(/,T10,'POSTAIR has generated VOLUMETRIC',

     1       ' FLOW text file    : FLOWVxx.Txx')

 208  FORMAT(/,T10,'POSTAIR has generated VOLUMETRIC',

     1       ' FLOW binary file  : FLOWVxx.Bxx')

 209  FORMAT(/,T10,'POSTAIR has generated MASS',

     1       ' FLOW text file          : FLOWMxx.Bxx')

 210  FORMAT(/,T10,'POSTAIR has generated MASS',

     1       ' FLOW binary file        : FLOWMxx.Bxx')

 211  FORMAT(/,T10,'POSTAIR has generated FLOW',

     1       ' DIVERGENCE binary file  : FLOWDxx.Bxx')

 213  FORMAT(/,T10,'POSTAIR has generated HEAD',

     1       ' text files              : GHxxxxxx.Txx')

 214  FORMAT(/,T10,'POSTAIR has generated PRESSURE',

     1       ' text files          : APxxxxxx.Txx')

 215  FORMAT(/,T10,'POSTAIR has generated VOLUMETRIC',

     1       ' FLOW text files   : GVxxxxxx.Txx')

 216  FORMAT(/,T10,'POSTAIR has generated VOLUMETRIC',

     1       ' FLOW text files   : AVxxxxxx.Txx')

 217  FORMAT(/,T10,'POSTAIR has generated 2-D RESULTANT',

     1       ' FLOW text files : GVxxxxxx.Txx')

 218  FORMAT(/,T10,'POSTAIR has generated 2-D RESULTANT',

     1       ' FLOW text files : AVxxxxxx.Txx')

 219  FORMAT(/,T10,'POSTAIR has generated MASS BALANCE/WELL',

     1       ' text file  : MASSxx.Txx')

 220  FORMAT(//)

C

C7----END

C

      RETURN

      END

C

C     *****************

      SUBROUTINE U1DREL(A,JJ)

C     *****************

C

C1----NOTES :

C     1. ROUTINE TO INPUT 1-D REAL DATA MATRICES

C     2. ARRAYS ARE AS FOLLOWS :

C        A IS ARRAY TO INPUT

C     3. VARIABLES :

C        JJ     = NO. OF ELEMENTS

C

C2----SPECIFICATIONS :

C

      COMMON/IVALUE/IV(100)

      DIMENSION A(JJ),FMTIN(5)

      CHARACTER*12 AVAR,FMTIN*4

C-----ASSIGN VARIABLES

      INBAS=IV(81)

      IOUT =IV(82)

C

C

C3----READ ARRAY CONTROL RECORD

      READ (15,1) LOCAT,CNSTNT,FMTIN,IPRN

    1 FORMAT(I10,F10.0,5A4,I10)

      IV(98)=IPRN

C

C2----USE LOCAT TO SEE WHERE ARRAY VALUES COME FROM

      ISEL4 = 0

      IF(LOCAT.GT.0) GO TO 90

C

C3----IF LOCAT=0 THEN SET ALL ARRAY VALUES EQUAL TO CNSTNT. RETURN

      DO 80 J=1,JJ

   80 A(J)=CNSTNT

      RETURN

C

C4----IF LOCAT>0 THEN READ FORMATTED RECORDS USING FORMAT FMTIN

C

C

C-----CHECK IF DATA IS LOCATED IN BCF FILE

C     ELSE INPUT NEW FILE NAME

C

 90   CONTINUE

      IF((LOCAT.NE.IV(20)).OR.(ISEL4.NE.0)) THEN

       IF(JJ.EQ.IV(3)) THEN

        WRITE(IOUT,130)

       END IF

       IF(JJ.EQ.IV(2)) THEN

        WRITE(IOUT,131)

       END IF

       IF(JJ.EQ.IV(1)) THEN

        WRITE(IOUT,132)

       END IF

       WRITE(IOUT,133)

       READ(INBAS,134)AVAR

       OPEN(UNIT=30,FILE=AVAR,STATUS='UNKNOWN')

       REWIND 30

       READ (30,FMTIN,IOSTAT=K1,ERR=412,END=413) (A(J),J=1,JJ)

       IF (K1.EQ.0) GO TO 414

 412   CALL ERRMES(AVAR,IER1)

       IF(IER1.EQ.1) THEN

        ISEL4 = 1

        GO TO 90

       END IF

 413   CALL ENDMES(AVAR,IER1)

       IF(IER1.EQ.1) THEN

        ISEL4 = 1

        GO TO 90

       END IF

 414   CONTINUE

      END IF

 130  FORMAT(//,T10,'ANISOTROPY INFORMATION IS NOT SAVED IN',

     1 ' BCF FILE')

 131  FORMAT(//,T10,'INFORMATION ON CELL WIDTH ALONG ROWS IS',

     1 ' NOT SAVED IN BCF FILE')

 132  FORMAT(//,T10,'INFORMATION ON CELL WIDTH ALONG COLUMNS IS',

     1 ' NOT SAVED IN BCF FILE')

 133  FORMAT(//,T10,'ENTER NAME OF INPUT FILE STORING',

     1 ' INFORMATION :  ')

 134  FORMAT(A12)

C

      IF((LOCAT.EQ.IV(20)).OR.(ISEL4.EQ.0)) THEN

       READ (15,FMTIN,IOSTAT=K1,ERR=415,END=416) (A(J),J=1,JJ)

       IF (K1.EQ.0) GO TO 417

 415   CALL ERRMES(AVAR,IER1)

       IF(IER1.EQ.1) THEN

        ISEL4 = 1

        GO TO 90

       END IF

 416   CALL ENDMES(AVAR,IER1)

       IF(IER1.EQ.1) THEN

        ISEL4 = 1

        GO TO 90

       END IF

 417   CONTINUE

      END IF

C

Ci5---IF CNSTNT NOT ZERO THEN MULTIPLY ARRAY VALUES BY CNSTNT

C

      IF ((CNSTNT.GT.1.0E-20).OR.(CNSTNT.LT.-1.0E-20)) THEN

       DO 100 J=1,JJ

 100    A(J)=A(J)*CNSTNT

      END IF

      RETURN

      END

C

C     ****************

      SUBROUTINE XYCORD(A,B,XC1,YC1,XR1,YR1,XF1,YF1,XL1,YL1,NR,

C     ****************

     1 NRM,NC,NROW,NCOL,CLEN)

C

C1----NOTES :

C     1. ROUTINE TO DETERMINE X- AND Y- COORDINATES 

C         CORRESPONDING TO THE CENTER AND/OR FACE OF A

C         SPECIFIED NODE

C     2. THE SUBROUTINE HAS THREE OPTIONS :

C        IV(36)=1 -> SPATIAL ORIGIN COINCIDES WITH MODFLOW DEF

C                 -> NODAL ORIGIN COINCIDES WITH MODFLOW DEFINITION

C

C                     SPATIAL          NODAL

C                           X

C                  O----------     1,1    1,2   1,3...

C                  |               2,1    2,2   2,3...

C                  |               3,1    3,2   3,3...

C                 Y|               4,1    4,2   4,3...

C

C

C        IV(36)=2 -> SPATIAL ORIGIN COINCIDES WITH GRAPHICAL DEF

C                 -> NODAL ORIGIN COINCIDES WITH MODFLOW DEFINITION

C

C                     SPATIAL          NODAL

C                            

C                 Y|               1,1    1,2   1,3...

C                  |               2,1    2,2   2,3...

C                  |               3,1    3,2   3,3...

C                  0-----------    4,1    4,2   4,3...

C                           X

C

C

C        IV(36)=3 -> SPATIAL ORIGIN COINCIDES WITH GRAPHICAL DEF

C                 -> NODAL ORIGIN COINCIDES WITH GRAPHICAL DEF

C

C                 Y|               4,1    4,2   4,3...

C                  |               3,1    3,2   3,3...

C                  |               2,1    2,2   2,3...

C                  O-----------    1,1    1,2   1,3...

C                           X

C

C        NOTE THAT IN BOTH OPTIONS, X IS DEFINED IN THE SAME

C        WAY.  THE Y-COORDINATES ARE HOWEVER REVERSED.

C     3. ARRAYS ARE AS FOLLOWS :

C        A IS ARRAY STORING CELL WIDTH ALONG ROWS

C          IE. WIDTH OF CELL IN X-DIRECTION

C        B IS ARRAY STORING CELL WIDTH ALONG COLUMNS

C          IE. WIDTH OF CELL IN Y-DIRECTION

C     4. VARIABLES :

C        XC1 = X-COORDINATE AT CENTER OF NODE NC

C        YC1 = Y-COORDINATE AT CENTER OF NODE NR

C        XR1 = X-COORDINATE AT RIGHT FACE OF NODE NC

C        YR1 = Y-COORDINATE AT RIGHT FACE OF NODE NR

C        XF1 = X-COORDINATE AT FRONT FACE OF NODE NC

C        YF1 = Y-COORDINATE AT FRONT FACE OF NODE NR

C        XL1 = X-COORDINATE AT LOWER FACE OF NODE NC

C        YL1 = Y-COORDINATE AT LOWER FACE OF NODE NR

C        NR  = ROW NUMBER (IE. IN Y-DIRECTION)

C        NRM = ROW NUMBER MODIFIED FOR COORD OPTION 3

C        NC  = COLUMN NUMBER (IE. IN X-DIRECTION)

C        IV(1) = NROW  = NUMBER OF ROWS

C        IV(2) = NCOL  = NUMBER OF COLUMNS

C        IV(3) = NLAY  = NUMBER OF LAYERS

C        IV(36)= IOPT  = FLAG SPECIFYING COORDINATE SYSTEM

C

C2----SPECIFICATIONS :

C

      COMMON/IVALUE/IV(100)

      DIMENSION A(NCOL),B(NROW)

C-----ASSIGN VARIABLES

C     INBAS=IV(81)

      IOUT =IV(82)

C

C3----CHECK NODE POSITION WITHIN DOMAIN

C

C-----CHECK SPECIFIED NODE DOES NOT EXCEED NCOLS

C

      IF(NC.GT.IV(2))THEN

       WRITE(IOUT,100)NC,IV(2)

       STOP

      END IF

 100  FORMAT(/////,T10,'NODE',I3,'EXCEEDS NCOLS IE.',I3)

C

C-----CHECK SPECIFIED NODE DOES NOT EXCEED NROWS

C

      IF(NR.GT.IV(1))THEN

       WRITE(IOUT,101)NR,IV(1)

       STOP

      END IF

 101  FORMAT(/////,T10,'NODE',I3,'EXCEEDS NROWS IE.',I3)

C

C

C4----DETERMINE X-COORDINATE AT CENTER OF CELL (NR,NC)

C

C     NOTES :

C     1. THIS ALGORITHM GENERATES THE DISTANCE FROM THE 

C         LEFT HAND EDGE OF THE MODEL DOMAIN TO THE CENTER

C         OF A NODE LYING WITHIN A SPECIFIED COLUMN.

C         IE DISTANCE ALONG ROW IN X-DIRECTION.

C     2. SINCE THE CONVENTION FOR THE X-AXIS IS STANDARDIZED

C         (ZERO AT THE LEFT INCREASING TO THE RIGHT), NO OPTIONS

C         ARE NEEDED TO CORRECT FOR COORDINATE SYSTEMS.

C         (ONE SIZE FITS ALL !)

C

C-----SUM CELL WIDTHS ALONG ROWS

C

      XC1  = 0.0

      L1M = NC-1

      DO 20 I = 1,L1M

       XC1 = XC1 + A(I)

 20   CONTINUE

      XC1  = XC1 + A(NC)/2.0

C

C4----DETERMINE X-COORDINATE AT RIGHT FACE OF CELL (NR,NC)

C

      XR1  = XC1 + A(NC)/2.0

C

C5----DETERMINE X-COORDINATE AT FRONT FACE OF CELL (NR,NC)

C

      XF1  = XC1

C

C6----DETERMINE X-COORDINATE AT LOWER FACE OF CELL (NR,NC)

C

      XL1  = XC1

C

C7----DETERMINE Y-COORDINATE AT CENTER OF CELL (NR,NC)

C

C     NOTES :

C     1. THIS ALGORITHM GENERATES THE DISTANCE FROM THE

C         BACK (OPTION 1) OR FRONT (OPTION 2 OR 3) EDGES

C         OF THE MODEL DOMAIN TO THE CENTER OF A NODE

C         LYING WITHIN A SPECIFIED ROW.

C         IE DISTANCE ALONG COLUMN IN Y-DIRECTION.

C     2. OPTIONS EXIST FOR GENERATING DISTANCES USING A 

C         VARIETY OF COORDINATE SYSTEMS.

C

C-----SUM CELL WIDTHS ALONG COLUMNS

C-----OPTION 1 :  (MODFLOW SPATIAL ORIGIN)

C                 (MODFLOW NODAL ORIGIN)

C

      IF (IV(36).EQ.1) THEN

       YC1  = 0.0

       L1M = NR-1

       DO 21 I = 1,L1M

        YC1 = YC1 + B(I)

 21    CONTINUE

       YC1  = YC1 + B(NR)/2.0

       NRM  = NR

      END IF

C

C-----SUM CELL WIDTHS ALONG COLUMNS

C-----OPTION 2 :  (GRAPHICAL SPATIAL ORIGIN)

C                 (MODFLOW NODAL ORIGIN)

C

C-----LAYER OUTPUT

      IF ((IV(36).EQ.2).AND.(IV(39).EQ.1)) THEN

       YC1  = CLEN

       L1M = NR - 1

       DO 22 I = 1,L1M

        YC1 = YC1 - B(I)

 22    CONTINUE

       YC1  = YC1 - B(NR)/2.0

       NRM  = NR

      END IF

C-----ROW / COLUMN OUTPUT

      IF ((IV(36).EQ.2).AND.(IV(39).NE.1)) THEN

       YC1  = 0.0

       L1M = NR - 1

       DO 23 I = 1,L1M

        YC1 = YC1 + B(I)

 23    CONTINUE

       YC1  = YC1 + B(NR)/2.0

       NRM  = NR

      END IF

C

C-----SUM CELL WIDTHS ALONG COLUMNS

C-----OPTION 3 :  (GRAPHICAL SPATIAL ORIGIN)

C                 (GRAPHICAL NODAL ORIGIN)

C

      IF ((IV(36).EQ.3).AND.(IV(39).EQ.1)) THEN

       YC1  = CLEN

       L1M = NR - 1 

       DO 25 I = 1,L1M

        YC1 = YC1 - B(I)

 25    CONTINUE

       YC1  = YC1 - B(NR)/2.0

       NRM  = NROW - NR + 1

      END IF

C-----ROW / COLUMN OUTPUT

      IF ((IV(36).EQ.3).AND.(IV(39).NE.1)) THEN

       YC1  = 0.0

       L1M = NR - 1

       DO 26 I = 1,L1M

        YC1 = YC1 + B(I)

 26    CONTINUE

       YC1  = YC1 + B(NR)/2.0

       NRM  = NR

      END IF

C

C8----DETERMINE Y-COORDINATE AT RIGHT FACE OF CELL (NR,NC)

C

C     NOTES :

C     1. YR1 COINCIDES WITH YC1 IN ALL THREE CASES

C

       YR1  = YC1

C

C9----DETERMINE Y-COORDINATE AT FRONT FACE OF CELL (NR,NC)

C

C-----OPTION 1 :  (MODFLOW SPATIAL ORIGIN)

C                 (MODFLOW NODAL ORIGIN)

C

      IF(IV(36).EQ.1) THEN

       YF1  = YC1 + B(NR)/2.0

      END IF

C

C-----OPTION 2 :  (GRAPHICAL SPATIAL ORIGIN)

C                 (MODFLOW NODAL ORIGIN)

C-----LAYER OUTPUT

      IF((IV(36).EQ.2).AND.(IV(39).EQ.1)) THEN

       YF1  = YC1 - B(NR)/2.0

      END IF

C-----ROW / COLUMN OUPUT

      IF((IV(36).EQ.2).AND.(IV(39).NE.1)) THEN

       YF1  = YC1 + B(NR)/2.0

      END IF

C

C-----OPTION 3 :  (GRAPHICAL SPATIAL ORIGIN)

C                 (GRAPHICAL NODAL ORIGIN)

C

C-----LAYER OUTPUT

      IF((IV(36).EQ.3).AND.(IV(39).EQ.1)) THEN

       YF1  = YC1 - B(NR)/2.0

      END IF

C-----ROW / COLUMN OUPUT

      IF((IV(36).EQ.2).AND.(IV(39).NE.1)) THEN

       YF1  = YC1 + B(NR)/2.0

      END IF

C

C10---DETERMINE Y-COORDINATE AT LOWER FACE OF CELL (NR,NC)

C

C     NOTES :

C     1. YL1 COINCIDES WITH YC1 IN ALL THREE CASES

C

       YL1  = YC1

C

C

      RETURN

      END

C

C     ****************

      SUBROUTINE ZCORD(A,ZC1,ZR1,ZF1,ZL1,NL,NLAY,DATUM)

C     ****************

C

C1----NOTES :

C     1. ROUTINE TO DETERMINE Z COORDINATES IN SPECIFIED NODES

C     2. SURFACE LAYER IS DESIGNATED AS LAYER 1 WITH LAYER 

C         NUMBERS INCREASING CONSECUTIVELY WITH DEPTH

C         IE. MODFLOW COORDINATE SYSTEM ASSUMED

C

C2----SPECIFICATIONS :

C

      COMMON/IVALUE/IV(100)

      DIMENSION A(-1:NLAY)

C-----ASSIGN VARIABLES

C     INBAS=IV(81)

      IOUT =IV(82)

C

C3----CHECK NODE POSITION WITHIN DOMAIN

C

C-----CHECK SPECIFIED NODE DOES NOT EXCEED NCOLS

C

      IF(NL.GT.IV(3))THEN

       WRITE(IOUT,100)NL,IV(3)

       STOP

      END IF

 100  FORMAT(/////,T10,'NODE',I3,'EXCEEDS NLAYS IE.',I3)

C

C4----DETERMINE Z-COORDINATE AT CENTER OF CELL (LAYER NL)

C

C     NOTES :

C     1. THIS ALGORITHM GENERATES THE DISTANCE FROM THE 

C         GROUND SURFACE OF THE MODEL DOMAIN TO THE CENTER

C         OF A NODE LYING WITHIN A SPECIFIED LAYER.

C

C-----SUM CELL THICKNESSES ALONG LAYERS

C

      ZC1 = 0.0

      L1M = NL-1

      ZC1 = (A(L1M) + A(NL))/2.0

      ZC1 = DATUM - ZC1

      IF((IV(35).EQ.2).AND.(NL.EQ.1)) ZC1 = DATUM + A(-1)/2.0

C

C5----DETERMINE Z-COORDINATE AT RIGHT FACE OF CELL (NR,NC)

C

      ZR1  = ZC1

C

C5----DETERMINE X-COORDINATE AT FRONT FACE OF CELL (NR,NC)

C

      ZF1  = ZC1

C

C6----DETERMINE X-COORDINATE AT LOWER FACE OF CELL (NR,NC)

C

      ZL1  = A(NL)

      ZL1  = DATUM - A(NL)

C

      RETURN

      END

C

C     *****************

      SUBROUTINE ERRMES(AERROR,IER1)

C     *****************

C

C1----NOTES :

C

C     1. THIS SUBROUTINE PRINTS OUT MESSAGE TO USER THAT

C         AN INPUT ERROR HAS OCCURED.

C     2. THE USER MAY THEN RENAME THE DATA FILE OR END THE

C         PROGRAM.

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      CHARACTER*12 AERROR

C-----ASSIGN VARIABLES

      INBAS=IV(81)

      IOUT =IV(82)

C

C3----MENU SELECTION

C

 200  CONTINUE

      WRITE(IOUT,100)

      WRITE(IOUT,101)

      WRITE(IOUT,102)

      WRITE(IOUT,103)AERROR

      WRITE(IOUT,104)

      WRITE(IOUT,105)

      WRITE(IOUT,106)

      WRITE(IOUT,107)

      WRITE(IOUT,108)

      WRITE(IOUT,109)

      READ(INBAS,110,ERR=200)IER1

      IF((IER1.EQ.1).OR.(IER1.EQ.2).OR.(IER1.EQ.3)) GOTO 201

      GOTO 200

 201  CONTINUE

C-----RESPECIFY FILE NAME

      IF(IER1.EQ.1) THEN

       WRITE(IOUT,120)AERROR

       READ(INBAS,121)AERROR

      END IF

C-----END PROGRAM

      IF(IER1.EQ.3) THEN

       STOP

      END IF

 100  FORMAT(///////////////,T25,'FORMAT ERROR MESSAGE')

 101  FORMAT(T25,'====== ===== =======')

 102  FORMAT(///,T10,'THE DATA BEING INPUT FROM THE DATA')

 103  FORMAT(T10,'FILE ',A12,'IS NOT COMPATIBLE WITH THE')

 104  FORMAT(T10,'PROGRAM FORMAT STATEMENTS.')

 105  FORMAT(//,T10,'SELECT  :')

 106  FORMAT(/,T10,'1.  TO SPECIFY ANOTHER FILE NAME')

 107  FORMAT(/,T10,'2.  TO INPUT FILE NAMES INTERACTIVELY')

 108  FORMAT(/,T10,'3.  TO END PROGRAM')

 109  FORMAT(//,T10,'PLEASE SELECT NUMBER  1,  2  OR  3  :  ')

 110  FORMAT(I1)

 120  FORMAT(////,T10,'PLEASE ENTER NAME FOR FILE',A12,':  ')

 121  FORMAT(A12)

C-----RETURN

      RETURN

      END

C

C     *****************

      SUBROUTINE ENDMES(AERROR,IER1)

C     *****************

C

C1----NOTES :

C

C     1. THIS SUBROUTINE PRINTS OUT MESSAGE TO USER THAT

C         AN UNEXPECTED END OF THE INPUT FILE HAS BEEN

C         ENCOUTERED.

C     2. THE USER MAY THEN RENAME THE DATA FILE OR END THE

C         PROGRAM.

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      CHARACTER*12 AERROR

C-----ASSIGN VARIABLES

      INBAS=IV(81)

      IOUT =IV(82)

C

C3----MENU SELECTION

C

 200  CONTINUE

      WRITE(IOUT,100)

      WRITE(IOUT,101)

      WRITE(IOUT,102)

      WRITE(IOUT,103)AERROR

      WRITE(IOUT,104)

      WRITE(IOUT,105)

      WRITE(IOUT,106)

      WRITE(IOUT,107)

      WRITE(IOUT,108)

      WRITE(IOUT,109)

      WRITE(IOUT,110)

      WRITE(IOUT,111)

      READ(INBAS,112,ERR=200)IER1

      IF((IER1.EQ.1).OR.(IER1.EQ.2).OR.(IER1.EQ.3)) GOTO 201

      GOTO 200

 201  CONTINUE

C-----RESPECIFY FILE NAME

      IF(IER1.EQ.1) THEN

       WRITE(IOUT,120)AERROR

       READ(INBAS,121)AERROR

      END IF

C-----END PROGRAM

      IF(IER1.EQ.3) THEN

       STOP

      END IF

 100  FORMAT(///////////////,T25,'END OF FILE ERROR MESSAGE')

 101  FORMAT(T25,'=== == ==== ===== =======')

 102  FORMAT(///,T10,'THE PROGRAM HAS ENCOUNTERED AN UNEXPECTED')

 103  FORMAT(T10,'END OF FILE WHILE READING THE FILE ',A12)

 104  FORMAT(/,T10,'THIS ERROR MAY BE CAUSED BY   :')

 105  FORMAT(T10,'  -  AN INCORRECT FILE NAME')

 106  FORMAT(T10,'  -  INSUFFICIENT OR INCORRECT DATA IN THE ',

     1 'SPECIFIED FILE')

 107  FORMAT(//,T10,'SELECT  :')

 108  FORMAT(/,T10,'1.  TO SPECIFY ANOTHER FILE NAME')

 109  FORMAT(/,T10,'2.  TO INPUT FILE NAMES INTERACTIVELY')

 110  FORMAT(/,T10,'3.  TO END PROGRAM')

 111  FORMAT(//,T10,'PLEASE SELECT NUMBER  1,  2  OR  3  :  ')

 112  FORMAT(I1)

 120  FORMAT(////,T10,'PLEASE ENTER NAME FOR FILE',A12,':  ')

 121  FORMAT(A12)

C-----RETURN

      RETURN

      END

C

C     *****************

      SUBROUTINE FILNAM(IUNUM,I,IC1,IC3,ISKP)

C     *****************

C

C1----NOTES

C     1. SUBROUTINE FILNAM IS USED TO CALCULATE PARAMETERS

C         USED IN SPECIFYING NAMES OF OUTPUT FILES (EXCLUDING

C         FILE EXTENSIONS).

C     2. HEAD AND FLOW OUTPUT IS GENERATED FOR EACH TIME STEP.

C         THE EXTENTION OF THE FILE NAME REPRESENTS THE TIME

C         STEP OF THE PARTICULAR DATA SET (SEE SUBROUTINE 

C         FILEXTN).

C     3. HEAD AND FLOW OUTPUT MAY ALSO BE SORTED ACCORDING TO 

C         LAYER, ROW, COLUMN DEPENDING ON USER SELECTIONS.

C     4. THE FOLLOWING CONVENTIONS ARE USED TO DESIGNATE THE

C         PARTICULAR DATA SET  :

C

C         abcdeZ01  =  FILE NAME OUTPUT FOR LAYER ONE

C         abcdeZ02  =  FILE NAME OUTPUT FOR LAYER TWO ETC....

C

C         abcdeX01  =  FILE NAME OUTPUT FOR ROW ONE

C         abcdeX02  =  FILE NAME OUTPUT FOR ROW TWO ETC....

C

C         abcdeY01  =  FILE NAME OUTPUT FOR COLUMN ONE

C         abcdeY02  =  FILE NAME OUTPUT FOR COLUMN TWO ETC....

C

C         WHERE,

C

C         a         =  A FOR AIR FLOW SIMULATION, OR,

C                   =  G FOR GROUND WATER FLOW SIMULATION

C

C         b         =  P FOR PRESSURE OUTPUT, OR,

C                      H FOR HEAD OUTPUT, OR,

C                      V FOR VOLUMETRIC FLOW OUTPUT, OR,

C                      M FOR MASS FLOW OUTPUT

C

C         c         =  S FOR CENTER OF CELL (STORAGE), OR,

C                      C FOR CENTER OF CELL, OR,

C                      R FOR RIGHT FACE OF CELL, OR,

C                      F FOR FRONT FACE OF CELL, OR,

C                      L FOR LOWER FACE OF CELL

C

C                      I FOR RESULTANT FLOW IN ROWS THROUGH CELL FACE

C                      J FOR RESULTANT FLOW IN COLUMNS THROUGH CELL FACE

C                      K FOR RESULTANT FLOW IN LAYRES THROUGH CELL FACE

C

C                      U FOR RESULTANT FLOW PER UNIT AREA IN ROWS 

C                      V FOR RESULTANT FLOW PER UNIT AREA IN COLUMNS

C                      W FOR RESULTANT FLOW PER UNIT AREA IN LAYERS

C

C

C         de        =  2 DIGIT IDENTIFICATION NUMBER

C                      (SPECIFIED BY USER) CORRESPONDING

C                      TO SIMULATION

C

C         Z         =  Z FOR LAYER NUMBER, OR,

C         X         =  X FOR ROW NUMBER, OR,

C         Y         =  Y FOR COLUMN NUMBER

C

C         01...     =  2 DIGIT NUMBER DESIGNATING LAYER,

C                      ROW OR COLUMN

C

C     5. THE FOLLOWING CONVENTIONS ARE USED TO DESIGNATE THE

C         PARTICULAR TIME STEP  :

C

C         .ijk      =  EXTENTION OUTPUT FOR TIME STEP

C

C         WHERE,

C

C          i        =  T FOR TIME STEP

C

C          jk       =  2 DIGIT NUMBER DESIGNATING TIME STEP

C

C

C     6. EXAMPLE OF AN OUTPUT FILE NAME IS  :

C

C         AMR06L02.T01    - A    =  AIRFLOW SIMULATION

C                         - M    =  MASS FLOW OUTPUT

C                         - R    =  FLOW THROUGH RIGH FACE

C                         - 06   =  USER ASSIGNED ID NUMBER 6

C                         - L02  =  LAYER NUMBER 2

C                         - T01  =  TIME STEP NUMBER 1

C

C     7. VARIABLE ASSIGNMENTS :

C

C        IV(39) = OUTPUT BY LAYER (1), ROW (2), COLUMN (3)

C        IV(40) = USER ASSIGNED ID NUMBER FOR SIMULATION

C        IV(45) = STORAGE TERM FOR PRESSURE (1), HEAD (2),

C                 VOLUMETRIC FLOW (3) OR MASS FLOW (4).

C        KNFN   = OUTPUT FILE NAME

C        I      = COUNTER USED TO RECORD LAYER, ROW, OR

C                  COLUMN NUMBER

C        IC1    = COUNTER USED TO DETERMINE SORAGE, CENTER,

C                  RIGHT, FRONT OR LOWER SIDE OF CELL

C        IC2    = COUNTER USED TO RECORD USER ASSIGNED ID

C        IC3    = COUNTER USED TO RECORD STEP NUMBER

C                  

C

C2----SPECIFICATIONS

C

      COMMON/IVALUE/IV(100)

      CHARACTER*1 KN1,KN2,KN3,KN4,KN5,KN6,KN7,KN8,KN9,KN10,KN11,KN12

      CHARACTER*12 KNFN

C

C3----DETERMINE LETTER FOR GROUND WATER (1) OR AIR FLOW (2)

C

C     NOTES :

C     1. IV(35) STORES FLAG

C     2. VARIABLES :

C        -  G  DESIGNATES GROUND WATER FLOW SIMULATION

C        -  A  DESIGNATES AIR FLOW SIMULATION

C

      IF(IV(35).EQ.1) KN1='G'

      IF(IV(35).EQ.2) KN1='A'

C

C4----DETERMINE LETTER FOR HEAD/PRESSURE (1), VOLUMETRIC

C      FLOW (2), OR MASS FLOW (3)

C

C     NOTES :

C     1. IV(45) STORES FLAG

C     2. VARIABLES :

C        -  P  DESIGNATES PRESSURE OUTPUT 

C        -  H  DESIGNATES HEAD OUTPUT 

C        -  V  DESIGNATES VOLUMETRIC FLOW OUTPUT

C        -  M  DESIGNATES MASS FLOW OUTPUT

C

      IF(IV(45).EQ.1) KN2='P'

      IF(IV(45).EQ.2) KN2='H'

      IF(IV(45).EQ.3) KN2='V'

      IF(IV(45).EQ.4) KN2='M'

C

C5----DETERMINE LETTER FOR PARAMETER LOCATED AT CELL

C      CENTER - STORAGE (0), CENTER (1), RIGHT FACE (2),

C      FRONT FACE (3), OR, LOWER FACE (4)

C

C     NOTES :

C     1. IC1 STORES FLAG

C     2. VARIABLES :

C        -  S  DESIGNATES CENTER OF CELL FOR STORAGE TERM

C        -  C  DESIGNATES CENTER OF CELL

C        -  R  DESIGNATES RIGHT FACE OF CELL

C        -  F  DESIGNATES FRONT FACE OF CELL

C        -  L  DESIGNATES LOWER FACE OF CELL

C        -  I  DESIGNATES RESULTANT FLOW IN ROWS THROUGH CELL FACE

C        -  J  DESIGNATES RESULTANT FLOW IN COLUMNS THROUGH CELL FACE

C        -  K  DESIGNATES RESULTANT FLOW IN LAYRES THROUGH CELL FACE

C        -  U  DESIGNATES RESULTANT FLOW IN ROWS PER UNIT AREA

C        -  V  DESIGNATES RESULTANT FLOW IN COLUMNS PER UNIT AREA

C        -  W  DESIGNATES RESULTANT FLOW IN LAYRES PER UNIT AREA

C

      IF(IC1.EQ.0) KN3='S'

      IF(IC1.EQ.1) KN3='C'

      IF(IC1.EQ.2) KN3='R'

      IF(IC1.EQ.3) KN3='F'

      IF(IC1.EQ.4) KN3='L'

      IF(IC1.EQ.5) KN3='I'

      IF(IC1.EQ.6) KN3='J'

      IF(IC1.EQ.7) KN3='K'

      IF(IC1.EQ.8) KN3='U'

      IF(IC1.EQ.9) KN3='V'

      IF(IC1.EQ.10) KN3='W'

C

C6----GENERATE CHARACTER EQUIVALENTS TO USER SPECIFIED

C      ID NUMBER FOR SIMULATION

C

C     NOTES :

C     1. IV(40) STORES USER DEFINED ID NUMBER

C

      IF(IV(40).LE.0) THEN

       KN4='0'

       KN5='0'

      END IF

      IF(IV(40).GT.0) THEN

       IC2=IV(40)

       CALL FILCNT(IC2,KN4,KN5)

      END IF

C

C7----DETERMINE OUTPUT BY LAYER (1), ROW (2) OR COLUMN (3)

C

C     NOTES :

C     1. IV(39)

C     2. VARIABLES :

C        -  Z  DESIGNATES OUTPUT BY LAYER

C        -  X  DESIGNATES OUTPUT BY ROW

C        -  Y  DESIGNATES OUTPUT BY COLUMN

C

      IF(IV(39).EQ.1) KN6='Z'

      IF(IV(39).EQ.2) KN6='X'

      IF(IV(39).EQ.3) KN6='Y'

C

C8----GENERATE CHARACTER EQUIVALENTS TO LAYER, ROW OR

C      COLUMN NUMBER

C

C     NOTES :

C     1. I STORES LAYER, ROW OR COLUMN NUMBER

C

      IF(I.LE.0) THEN

       KN7='0'

       KN8='0'

      END IF

      IF(I.GT.0) THEN

       CALL FILCNT(I,KN7,KN8)

      END IF

C

C9----SPECIFY EXTENSION

C

C     NOTES :

C     1. EXTENSION RECORDS TIME STEP

C     2. VARIABLES :

C        -  T  DESIGNATES TIME STEP FOR OUTPUT

C

      KN9='.'

      KN10='T'

C

C10---GENERATE CHARACTER EQUIVALENTS TO STEP NUMBER

C

C     NOTES :

C     1. IC3 STORES STEP NUMBER

C

      IF(IC3.LE.0) THEN

       KN11='0'

       KN12='0'

      END IF

      IF(IC3.GT.0) THEN

       CALL FILCNT(IC3,KN11,KN12)

      END IF

C

C11---DETERMINE FILE NAME FOR PREVAILINING PARAMETERS

C

       KNFN=KN1//KN2//KN3//KN4//KN5//KN6//KN7//KN8//

     1      KN9//KN10//KN11//KN12

C

C12---OPENFILE FOR INPUT/OUTPUT OF DATA

C

      OPEN(IUNUM,FILE=KNFN,STATUS='UNKNOWN')

C

C13---SKIP RECORDS IF NECESSARY

C

      DO 40 ISK = 1,ISKP

       READ(IUNUM,120)CV1,CV2,HV,NV1,NV2

 40   CONTINUE

      IV(98)=INT(CV1)

      IV(98)=INT(CV2)

      IV(98)=INT(HV)

      IV(98)=NV1

      IV(98)=NV2

 120  FORMAT(2F15.5,E20.8,2I5)

C

C14---RETURN

C

      RETURN

      END

C

C     *****************

      SUBROUTINE FILCNT(I,KNA,KNB)

C     *****************

C

C1----NOTES

C     1. SUBROUTINE FILCNT IS USED TO GENERATE CHARACTERS

C         FOR A SPECIFIED NUMBER

C     2. THE CHARACTERS ARE USED IN SETTING UP THE OUTPUT

C         FILE NAMES

C

C2----SPECIFICATIONS

C

      COMMON/KVALUE/KN(10)

      CHARACTER*1 KN,KNA,KNB

C

C3----SET UP FILE NUMERICAL TERMS

C

      IF(I.LT.0) KNA = '0'

      IF(I.LE.0) KNB = '0'

      IF((I.GE.0).AND.(I.LT.10))  KNA = '0'

      IF((I.GE.1).AND.(I.LT.11))  KNB = KN(I)

      IF((I.GE.10).AND.(I.LT.20)) KNA = '1'

      IF((I.GE.11).AND.(I.LT.21)) KNB = KN(I-10)

      IF((I.GE.20).AND.(I.LT.30)) KNA = '2'

      IF((I.GE.21).AND.(I.LT.31)) KNB = KN(I-20)

      IF((I.GE.30).AND.(I.LT.40)) KNA = '3'

      IF((I.GE.31).AND.(I.LT.41)) KNB = KN(I-30)

      IF((I.GE.40).AND.(I.LT.50)) KNA = '4'

      IF((I.GE.41).AND.(I.LT.51)) KNB = KN(I-40)

      IF((I.GE.50).AND.(I.LT.60)) KNA = '5'

      IF((I.GE.51).AND.(I.LT.61)) KNB = KN(I-50)

      IF((I.GE.60).AND.(I.LT.70)) KNA = '6'

      IF((I.GE.61).AND.(I.LT.71)) KNB = KN(I-60)

      IF((I.GE.70).AND.(I.LT.80)) KNA = '7'

      IF((I.GE.71).AND.(I.LT.81)) KNB = KN(I-70)

      IF((I.GE.80).AND.(I.LT.90)) KNA = '8'

      IF((I.GE.81).AND.(I.LT.91)) KNB = KN(I-80)

      IF((I.GE.90).AND.(I.LT.100)) KNA = '9'

      IF((I.GE.91).AND.(I.LT.101)) KNB = KN(I-90)

      IF(I.GE.100) KNA = '0'

      IF(I.GE.101) KNB = '1'

C

C4----RETURN

C

      RETURN

      END







 